@@ -4,41 +4,28 @@
  * Galileo E1 signals with coherent integration time = 8 ms (two codes)
  * \author Marc Molina, 2013. marc.molina.pena(at)gmail.com
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "galileo_pcps_8ms_acquisition_cc.h"
-#include "control_message_factory.h"
+#include "MATH_CONSTANTS.h"
+#include "gnss_sdr_make_unique.h"
 #include <glog/logging.h>
 #include <gnuradio/io_signature.h>
 #include <volk/volk.h>
 #include <volk_gnsssdr/volk_gnsssdr.h>
+#include <array>
+#include <exception>
 #include <sstream>
-#include <utility>
 
-using google::LogMessage;
 
 galileo_pcps_8ms_acquisition_cc_sptr galileo_pcps_8ms_make_acquisition_cc(
     uint32_t sampled_ms,
@@ -47,13 +34,16 @@ galileo_pcps_8ms_acquisition_cc_sptr galileo_pcps_8ms_make_acquisition_cc(
     int64_t fs_in,
     int32_t samples_per_ms,
     int32_t samples_per_code,
-    bool dump, std::string dump_filename)
+    bool dump,
+    const std::string &dump_filename,
+    bool enable_monitor_output)
 {
     return galileo_pcps_8ms_acquisition_cc_sptr(
         new galileo_pcps_8ms_acquisition_cc(sampled_ms, max_dwells, doppler_max, fs_in, samples_per_ms,
-            samples_per_code, dump, std::move(dump_filename)));
+            samples_per_code, dump, dump_filename, enable_monitor_output));
 }
 
+
 galileo_pcps_8ms_acquisition_cc::galileo_pcps_8ms_acquisition_cc(
     uint32_t sampled_ms,
     uint32_t max_dwells,
@@ -62,9 +52,10 @@ galileo_pcps_8ms_acquisition_cc::galileo_pcps_8ms_acquisition_cc(
     int32_t samples_per_ms,
     int32_t samples_per_code,
     bool dump,
-    std::string dump_filename) : gr::block("galileo_pcps_8ms_acquisition_cc",
-                                     gr::io_signature::make(1, 1, sizeof(gr_complex) * sampled_ms * samples_per_ms),
-                                     gr::io_signature::make(0, 0, sizeof(gr_complex) * sampled_ms * samples_per_ms))
+    const std::string &dump_filename,
+    bool enable_monitor_output) : gr::block("galileo_pcps_8ms_acquisition_cc",
+                                      gr::io_signature::make(1, 1, static_cast<int>(sizeof(gr_complex) * sampled_ms * samples_per_ms)),
+                                      gr::io_signature::make(0, 1, sizeof(Gnss_Synchro)))
 {
     this->message_port_register_out(pmt::mp("events"));
     d_sample_counter = 0ULL;  // SAMPLE COUNTER
@@ -82,24 +73,31 @@ galileo_pcps_8ms_acquisition_cc::galileo_pcps_8ms_acquisition_cc(
     d_input_power = 0.0;
     d_num_doppler_bins = 0;
 
-    d_fft_code_A = static_cast<gr_complex *>(volk_gnsssdr_malloc(d_fft_size * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
-    d_fft_code_B = static_cast<gr_complex *>(volk_gnsssdr_malloc(d_fft_size * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
-    d_magnitude = static_cast<float *>(volk_gnsssdr_malloc(d_fft_size * sizeof(float), volk_gnsssdr_get_alignment()));
+    d_fft_code_A = std::vector<gr_complex>(d_fft_size, lv_cmake(0.0F, 0.0F));
+    d_fft_code_B = std::vector<gr_complex>(d_fft_size, lv_cmake(0.0F, 0.0F));
+    d_magnitude = std::vector<float>(d_fft_size, 0.0F);
 
+#if GNURADIO_FFT_USES_TEMPLATES
     // Direct FFT
-    d_fft_if = new gr::fft::fft_complex(d_fft_size, true);
-
+    d_fft_if = std::make_unique<gr::fft::fft_complex_fwd>(d_fft_size);
     // Inverse FFT
-    d_ifft = new gr::fft::fft_complex(d_fft_size, false);
+    d_ifft = std::make_unique<gr::fft::fft_complex_rev>(d_fft_size);
+#else
+    // Direct FFT
+    d_fft_if = std::make_unique<gr::fft::fft_complex>(d_fft_size, true);
+    // Inverse FFT
+    d_ifft = std::make_unique<gr::fft::fft_complex>(d_fft_size, false);
+#endif
 
     // For dumping samples into a file
     d_dump = dump;
-    d_dump_filename = std::move(dump_filename);
+    d_dump_filename = dump_filename;
+
+    d_enable_monitor_output = enable_monitor_output;
 
     d_doppler_resolution = 0;
     d_threshold = 0;
     d_doppler_step = 0;
-    d_grid_doppler_wipeoffs = nullptr;
     d_gnss_synchro = nullptr;
     d_code_phase = 0;
     d_doppler_freq = 0;
@@ -110,25 +108,20 @@ galileo_pcps_8ms_acquisition_cc::galileo_pcps_8ms_acquisition_cc(
 
 galileo_pcps_8ms_acquisition_cc::~galileo_pcps_8ms_acquisition_cc()
 {
-    if (d_num_doppler_bins > 0)
+    try
         {
-            for (uint32_t i = 0; i < d_num_doppler_bins; i++)
+            if (d_dump)
                 {
-                    volk_gnsssdr_free(d_grid_doppler_wipeoffs[i]);
+                    d_dump_file.close();
                 }
-            delete[] d_grid_doppler_wipeoffs;
         }
-
-    volk_gnsssdr_free(d_fft_code_A);
-    volk_gnsssdr_free(d_fft_code_B);
-    volk_gnsssdr_free(d_magnitude);
-
-    delete d_ifft;
-    delete d_fft_if;
-
-    if (d_dump)
+    catch (const std::ofstream::failure &e)
         {
-            d_dump_file.close();
+            std::cerr << "Problem closing Acquisition dump file: " << d_dump_filename << '\n';
+        }
+    catch (const std::exception &e)
+        {
+            std::cerr << e.what() << '\n';
         }
 }
 
@@ -140,8 +133,8 @@ void galileo_pcps_8ms_acquisition_cc::set_local_code(std::complex<float> *code)
 
     d_fft_if->execute();  // We need the FFT of local code
 
-    //Conjugate the local code
-    volk_32fc_conjugate_32fc(d_fft_code_A, d_fft_if->get_outbuf(), d_fft_size);
+    // Conjugate the local code
+    volk_32fc_conjugate_32fc(d_fft_code_A.data(), d_fft_if->get_outbuf(), d_fft_size);
 
     // code B: two replicas of a primary code; the second replica is inverted.
     volk_32fc_s32fc_multiply_32fc(&(d_fft_if->get_inbuf())[d_samples_per_code],
@@ -150,8 +143,8 @@ void galileo_pcps_8ms_acquisition_cc::set_local_code(std::complex<float> *code)
 
     d_fft_if->execute();  // We need the FFT of local code
 
-    //Conjugate the local code
-    volk_32fc_conjugate_32fc(d_fft_code_B, d_fft_if->get_outbuf(), d_fft_size);
+    // Conjugate the local code
+    volk_32fc_conjugate_32fc(d_fft_code_B.data(), d_fft_if->get_outbuf(), d_fft_size);
 }
 
 
@@ -167,7 +160,7 @@ void galileo_pcps_8ms_acquisition_cc::init()
     d_gnss_synchro->Acq_samplestamp_samples = 0ULL;
     d_mag = 0.0;
     d_input_power = 0.0;
-    const double GALILEO_TWO_PI = 6.283185307179600;
+
     // Count the number of bins
     d_num_doppler_bins = 0;
     for (auto doppler = static_cast<int32_t>(-d_doppler_max);
@@ -176,17 +169,14 @@ void galileo_pcps_8ms_acquisition_cc::init()
         {
             d_num_doppler_bins++;
         }
-
     // Create the carrier Doppler wipeoff signals
-    d_grid_doppler_wipeoffs = new gr_complex *[d_num_doppler_bins];
+    d_grid_doppler_wipeoffs = std::vector<std::vector<gr_complex>>(d_num_doppler_bins, std::vector<gr_complex>(d_fft_size));
     for (uint32_t doppler_index = 0; doppler_index < d_num_doppler_bins; doppler_index++)
         {
-            d_grid_doppler_wipeoffs[doppler_index] = static_cast<gr_complex *>(volk_gnsssdr_malloc(d_fft_size * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
             int32_t doppler = -static_cast<int32_t>(d_doppler_max) + d_doppler_step * doppler_index;
-            float phase_step_rad = static_cast<float>(GALILEO_TWO_PI) * doppler / static_cast<float>(d_fs_in);
-            float _phase[1];
-            _phase[0] = 0;
-            volk_gnsssdr_s32f_sincos_32fc(d_grid_doppler_wipeoffs[doppler_index], -phase_step_rad, _phase, d_fft_size);
+            float phase_step_rad = static_cast<float>(TWO_PI) * doppler / static_cast<float>(d_fs_in);
+            std::array<float, 1> _phase{};
+            volk_gnsssdr_s32f_sincos_32fc(d_grid_doppler_wipeoffs[doppler_index].data(), -phase_step_rad, _phase.data(), d_fft_size);
         }
 }
 
@@ -217,9 +207,9 @@ void galileo_pcps_8ms_acquisition_cc::set_state(int32_t state)
 
 int galileo_pcps_8ms_acquisition_cc::general_work(int noutput_items,
     gr_vector_int &ninput_items, gr_vector_const_void_star &input_items,
-    gr_vector_void_star &output_items __attribute__((unused)))
+    gr_vector_void_star &output_items)
 {
-    int32_t acquisition_message = -1;  //0=STOP_CHANNEL 1=ACQ_SUCCEES 2=ACQ_FAIL
+    int32_t acquisition_message = -1;  // 0=STOP_CHANNEL 1=ACQ_SUCCEES 2=ACQ_FAIL
 
     switch (d_state)
         {
@@ -227,7 +217,7 @@ int galileo_pcps_8ms_acquisition_cc::general_work(int noutput_items,
             {
                 if (d_active)
                     {
-                        //restart acquisition variables
+                        // restart acquisition variables
                         d_gnss_synchro->Acq_delay_samples = 0.0;
                         d_gnss_synchro->Acq_doppler_hz = 0.0;
                         d_gnss_synchro->Acq_samplestamp_samples = 0ULL;
@@ -256,7 +246,7 @@ int galileo_pcps_8ms_acquisition_cc::general_work(int noutput_items,
                 float magt = 0.0;
                 float magt_A = 0.0;
                 float magt_B = 0.0;
-                const auto *in = reinterpret_cast<const gr_complex *>(input_items[0]);  //Get the input samples pointer
+                const auto *in = reinterpret_cast<const gr_complex *>(input_items[0]);  // Get the input samples pointer
                 float fft_normalization_factor = static_cast<float>(d_fft_size) * static_cast<float>(d_fft_size);
                 d_input_power = 0.0;
                 d_mag = 0.0;
@@ -272,8 +262,8 @@ int galileo_pcps_8ms_acquisition_cc::general_work(int noutput_items,
                            << ", doppler_step: " << d_doppler_step;
 
                 // 1- Compute the input signal power estimation
-                volk_32fc_magnitude_squared_32f(d_magnitude, in, d_fft_size);
-                volk_32f_accumulator_s32f(&d_input_power, d_magnitude, d_fft_size);
+                volk_32fc_magnitude_squared_32f(d_magnitude.data(), in, d_fft_size);
+                volk_32f_accumulator_s32f(&d_input_power, d_magnitude.data(), d_fft_size);
                 d_input_power /= static_cast<float>(d_fft_size);
 
                 // 2- Doppler frequency search loop
@@ -283,7 +273,7 @@ int galileo_pcps_8ms_acquisition_cc::general_work(int noutput_items,
                         doppler = -static_cast<int32_t>(d_doppler_max) + d_doppler_step * doppler_index;
 
                         volk_32fc_x2_multiply_32fc(d_fft_if->get_inbuf(), in,
-                            d_grid_doppler_wipeoffs[doppler_index], d_fft_size);
+                            d_grid_doppler_wipeoffs[doppler_index].data(), d_fft_size);
 
                         // 3- Perform the FFT-based convolution  (parallel time search)
                         // Compute the FFT of the carrier wiped--off incoming signal
@@ -293,14 +283,14 @@ int galileo_pcps_8ms_acquisition_cc::general_work(int noutput_items,
                         // with the local FFT'd code A reference using SIMD operations with
                         // VOLK library
                         volk_32fc_x2_multiply_32fc(d_ifft->get_inbuf(),
-                            d_fft_if->get_outbuf(), d_fft_code_A, d_fft_size);
+                            d_fft_if->get_outbuf(), d_fft_code_A.data(), d_fft_size);
 
                         // compute the inverse FFT
                         d_ifft->execute();
 
                         // Search maximum
-                        volk_32fc_magnitude_squared_32f(d_magnitude, d_ifft->get_outbuf(), d_fft_size);
-                        volk_gnsssdr_32f_index_max_32u(&indext_A, d_magnitude, d_fft_size);
+                        volk_32fc_magnitude_squared_32f(d_magnitude.data(), d_ifft->get_outbuf(), d_fft_size);
+                        volk_gnsssdr_32f_index_max_32u(&indext_A, d_magnitude.data(), d_fft_size);
 
                         // Normalize the maximum value to correct the scale factor introduced by FFTW
                         magt_A = d_magnitude[indext_A] / (fft_normalization_factor * fft_normalization_factor);
@@ -309,14 +299,14 @@ int galileo_pcps_8ms_acquisition_cc::general_work(int noutput_items,
                         // with the local FFT'd code B reference using SIMD operations with
                         // VOLK library
                         volk_32fc_x2_multiply_32fc(d_ifft->get_inbuf(),
-                            d_fft_if->get_outbuf(), d_fft_code_B, d_fft_size);
+                            d_fft_if->get_outbuf(), d_fft_code_B.data(), d_fft_size);
 
                         // compute the inverse FFT
                         d_ifft->execute();
 
                         // Search maximum
-                        volk_32fc_magnitude_squared_32f(d_magnitude, d_ifft->get_outbuf(), d_fft_size);
-                        volk_gnsssdr_32f_index_max_32u(&indext_B, d_magnitude, d_fft_size);
+                        volk_32fc_magnitude_squared_32f(d_magnitude.data(), d_ifft->get_outbuf(), d_fft_size);
+                        volk_gnsssdr_32f_index_max_32u(&indext_B, d_magnitude.data(), d_fft_size);
 
                         // Normalize the maximum value to correct the scale factor introduced by FFTW
                         magt_B = d_magnitude[indext_B] / (fft_normalization_factor * fft_normalization_factor);
@@ -350,16 +340,16 @@ int galileo_pcps_8ms_acquisition_cc::general_work(int noutput_items,
                                 std::streamsize n = 2 * sizeof(float) * (d_fft_size);  // complex file write
                                 filename.str("");
                                 filename << "../data/test_statistics_" << d_gnss_synchro->System
-                                         << "_" << d_gnss_synchro->Signal << "_sat_"
+                                         << "_" << d_gnss_synchro->Signal[0] << d_gnss_synchro->Signal[1] << "_sat_"
                                          << d_gnss_synchro->PRN << "_doppler_" << doppler << ".dat";
                                 d_dump_file.open(filename.str().c_str(), std::ios::out | std::ios::binary);
-                                d_dump_file.write(reinterpret_cast<char *>(d_ifft->get_outbuf()), n);  //write directly |abs(x)|^2 in this Doppler bin?
+                                d_dump_file.write(reinterpret_cast<char *>(d_ifft->get_outbuf()), n);  // write directly |abs(x)|^2 in this Doppler bin?
                                 d_dump_file.close();
                             }
                     }
 
                 // 5- Compute the test statistics and compare to the threshold
-                //d_test_statistics = 2 * d_fft_size * d_mag / d_input_power;
+                // d_test_statistics = 2 * d_fft_size * d_mag / d_input_power;
                 d_test_statistics = d_mag / d_input_power;
 
                 if (d_test_statistics > d_threshold)
@@ -398,6 +388,16 @@ int galileo_pcps_8ms_acquisition_cc::general_work(int noutput_items,
                 acquisition_message = 1;
                 this->message_port_pub(pmt::mp("events"), pmt::from_long(acquisition_message));
 
+                // Copy and push current Gnss_Synchro to monitor queue
+                if (d_enable_monitor_output)
+                    {
+                        auto **out = reinterpret_cast<Gnss_Synchro **>(&output_items[0]);
+                        Gnss_Synchro current_synchro_data = Gnss_Synchro();
+                        current_synchro_data = *d_gnss_synchro;
+                        *out[0] = current_synchro_data;
+                        noutput_items = 1;  // Number of Gnss_Synchro objects produced
+                    }
+
                 break;
             }
 
