@@ -1,46 +1,33 @@
 /*!
  * \file channel_fsm.cc
  * \brief Implementation of a State Machine for channel
- * \authors Antonio Ramos, 2017. antonio.ramos(at)cttc.es
+ * \authors Javier Arribas, 2019. javiarribas@gmail.com
+ *          Antonio Ramos, 2017. antonio.ramos(at)cttc.es
  *          Luis Esteve,   2011. luis(at)epsilon-formacion.com
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "channel_fsm.h"
-#include "control_message_factory.h"
+#include "channel_event.h"
 #include <glog/logging.h>
-
-using google::LogMessage;
+#include <utility>
 
 ChannelFsm::ChannelFsm()
 {
     acq_ = nullptr;
     trk_ = nullptr;
     channel_ = 0U;
-    d_state = 0U;
+    state_ = 0U;
+    queue_ = nullptr;
 }
 
 
@@ -48,24 +35,25 @@ ChannelFsm::ChannelFsm(std::shared_ptr<AcquisitionInterface> acquisition) : acq_
 {
     trk_ = nullptr;
     channel_ = 0U;
-    d_state = 0U;
+    state_ = 0U;
+    queue_ = nullptr;
 }
 
 
 bool ChannelFsm::Event_stop_channel()
 {
-    std::lock_guard<std::mutex> lk(mx);
+    std::lock_guard<std::mutex> lk(mx_);
     DLOG(INFO) << "CH = " << channel_ << ". Ev stop channel";
-    switch (d_state)
+    switch (state_)
         {
-        case 0:  //already in stanby
+        case 0:  // already in stanby
             break;
-        case 1:  //acquisition
-            d_state = 0;
+        case 1:  // acquisition
+            state_ = 0;
             stop_acquisition();
             break;
-        case 2:  //tracking
-            d_state = 0;
+        case 2:  // tracking
+            state_ = 0;
             stop_tracking();
             break;
         default:
@@ -74,14 +62,28 @@ bool ChannelFsm::Event_stop_channel()
     return true;
 }
 
-bool ChannelFsm::Event_start_acquisition()
+
+bool ChannelFsm::Event_start_acquisition_fpga()
 {
-    std::lock_guard<std::mutex> lk(mx);
-    if ((d_state == 1) || (d_state == 2))
+    std::lock_guard<std::mutex> lk(mx_);
+    if ((state_ == 1) || (state_ == 2))
         {
             return false;
         }
-    d_state = 1;
+    state_ = 1;
+    DLOG(INFO) << "CH = " << channel_ << ". Ev start acquisition FPGA";
+    return true;
+}
+
+
+bool ChannelFsm::Event_start_acquisition()
+{
+    std::lock_guard<std::mutex> lk(mx_);
+    if ((state_ == 1) || (state_ == 2))
+        {
+            return false;
+        }
+    state_ = 1;
     start_acquisition();
     DLOG(INFO) << "CH = " << channel_ << ". Ev start acquisition";
     return true;
@@ -90,12 +92,12 @@ bool ChannelFsm::Event_start_acquisition()
 
 bool ChannelFsm::Event_valid_acquisition()
 {
-    std::lock_guard<std::mutex> lk(mx);
-    if (d_state != 1)
+    std::lock_guard<std::mutex> lk(mx_);
+    if (state_ != 1)
         {
             return false;
         }
-    d_state = 2;
+    state_ = 2;
     start_tracking();
     DLOG(INFO) << "CH = " << channel_ << ". Ev valid acquisition";
     return true;
@@ -104,12 +106,12 @@ bool ChannelFsm::Event_valid_acquisition()
 
 bool ChannelFsm::Event_failed_acquisition_repeat()
 {
-    std::lock_guard<std::mutex> lk(mx);
-    if (d_state != 1)
+    std::lock_guard<std::mutex> lk(mx_);
+    if (state_ != 1)
         {
             return false;
         }
-    d_state = 1;
+    state_ = 1;
     start_acquisition();
     DLOG(INFO) << "CH = " << channel_ << ". Ev failed acquisition repeat";
     return true;
@@ -118,12 +120,12 @@ bool ChannelFsm::Event_failed_acquisition_repeat()
 
 bool ChannelFsm::Event_failed_acquisition_no_repeat()
 {
-    std::lock_guard<std::mutex> lk(mx);
-    if (d_state != 1)
+    std::lock_guard<std::mutex> lk(mx_);
+    if (state_ != 1)
         {
             return false;
         }
-    d_state = 3;
+    state_ = 3;
     request_satellite();
     DLOG(INFO) << "CH = " << channel_ << ". Ev failed acquisition no repeat";
     return true;
@@ -132,12 +134,12 @@ bool ChannelFsm::Event_failed_acquisition_no_repeat()
 
 bool ChannelFsm::Event_failed_tracking_standby()
 {
-    std::lock_guard<std::mutex> lk(mx);
-    if (d_state != 2)
+    std::lock_guard<std::mutex> lk(mx_);
+    if (state_ != 2)
         {
             return false;
         }
-    d_state = 0U;
+    state_ = 0U;
     notify_stop_tracking();
     DLOG(INFO) << "CH = " << channel_ << ". Ev failed tracking standby";
     return true;
@@ -146,28 +148,35 @@ bool ChannelFsm::Event_failed_tracking_standby()
 
 void ChannelFsm::set_acquisition(std::shared_ptr<AcquisitionInterface> acquisition)
 {
-    std::lock_guard<std::mutex> lk(mx);
+    std::lock_guard<std::mutex> lk(mx_);
     acq_ = std::move(acquisition);
 }
 
 
 void ChannelFsm::set_tracking(std::shared_ptr<TrackingInterface> tracking)
 {
-    std::lock_guard<std::mutex> lk(mx);
+    std::lock_guard<std::mutex> lk(mx_);
     trk_ = std::move(tracking);
 }
 
 
-void ChannelFsm::set_queue(gr::msg_queue::sptr queue)
+void ChannelFsm::set_telemetry(std::shared_ptr<TelemetryDecoderInterface> telemetry)
 {
-    std::lock_guard<std::mutex> lk(mx);
-    queue_ = std::move(queue);
+    std::lock_guard<std::mutex> lk(mx_);
+    nav_ = std::move(telemetry);
+}
+
+
+void ChannelFsm::set_queue(Concurrent_Queue<pmt::pmt_t>* queue)
+{
+    std::lock_guard<std::mutex> lk(mx_);
+    queue_ = queue;
 }
 
 
 void ChannelFsm::set_channel(uint32_t channel)
 {
-    std::lock_guard<std::mutex> lk(mx);
+    std::lock_guard<std::mutex> lk(mx_);
     channel_ = channel;
 }
 
@@ -177,6 +186,7 @@ void ChannelFsm::stop_acquisition()
     acq_->stop_acquisition();
 }
 
+
 void ChannelFsm::stop_tracking()
 {
     trk_->stop_tracking();
@@ -186,35 +196,24 @@ void ChannelFsm::stop_tracking()
 void ChannelFsm::start_acquisition()
 {
     acq_->reset();
+    nav_->reset();
 }
 
 
 void ChannelFsm::start_tracking()
 {
     trk_->start_tracking();
-    std::unique_ptr<ControlMessageFactory> cmf(new ControlMessageFactory());
-    if (queue_ != gr::msg_queue::make())
-        {
-            queue_->handle(cmf->GetQueueMessage(channel_, 1));
-        }
+    queue_->push(pmt::make_any(channel_event_make(channel_, 1)));
 }
 
 
 void ChannelFsm::request_satellite()
 {
-    std::unique_ptr<ControlMessageFactory> cmf(new ControlMessageFactory());
-    if (queue_ != gr::msg_queue::make())
-        {
-            queue_->handle(cmf->GetQueueMessage(channel_, 0));
-        }
+    queue_->push(pmt::make_any(channel_event_make(channel_, 0)));
 }
 
 
 void ChannelFsm::notify_stop_tracking()
 {
-    std::unique_ptr<ControlMessageFactory> cmf(new ControlMessageFactory());
-    if (queue_ != gr::msg_queue::make())
-        {
-            queue_->handle(cmf->GetQueueMessage(channel_, 2));
-        }
+    queue_->push(pmt::make_any(channel_event_make(channel_, 2)));
 }
