@@ -3,31 +3,34 @@
  * \brief Adapts a std::complex<signed char> stream into two 16-bits (short) streams
  * \author Carles Fernandez Prades, cfernandez(at)cttc.es
  *
- * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #ifndef GNSS_SDR_COMPLEX_BYTE_TO_FLOAT_X2_H
 #define GNSS_SDR_COMPLEX_BYTE_TO_FLOAT_X2_H
 
-
-#include <boost/shared_ptr.hpp>
+#include "gnss_block_interface.h"
 #include <gnuradio/sync_block.h>
 #include <gnuradio/types.h>  // for gr_vector_const_void_star
 
+/** \addtogroup Algorithms_Library
+ * \{ */
+/** \addtogroup Algorithm_libs algorithms_libs
+ * \{ */
+
+
 class complex_byte_to_float_x2;
 
-using complex_byte_to_float_x2_sptr = boost::shared_ptr<complex_byte_to_float_x2>;
+using complex_byte_to_float_x2_sptr = gnss_shared_ptr<complex_byte_to_float_x2>;
 
 complex_byte_to_float_x2_sptr make_complex_byte_to_float_x2();
 
@@ -37,14 +40,17 @@ complex_byte_to_float_x2_sptr make_complex_byte_to_float_x2();
  */
 class complex_byte_to_float_x2 : public gr::sync_block
 {
-private:
-    friend complex_byte_to_float_x2_sptr make_complex_byte_to_float_x2();
-    complex_byte_to_float_x2();
-
 public:
     int work(int noutput_items,
         gr_vector_const_void_star &input_items,
         gr_vector_void_star &output_items);
+
+private:
+    friend complex_byte_to_float_x2_sptr make_complex_byte_to_float_x2();
+    complex_byte_to_float_x2();
 };
 
-#endif
+
+/** \} */
+/** \} */
+#endif  // GNSS_SDR_COMPLEX_BYTE_TO_FLOAT_X2_H
