@@ -6,13 +6,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -21,21 +18,19 @@
 #ifndef GNSS_SDR_CONJUGATE_CC_H
 #define GNSS_SDR_CONJUGATE_CC_H
 
-#if GNURADIO_USES_STD_POINTERS
-#include <memory>
-#else
-#include <boost/shared_ptr.hpp>
-#endif
+#include "gnss_block_interface.h"
 #include <gnuradio/sync_block.h>
 #include <gnuradio/types.h>  // for gr_vector_const_void_star
 
+/** \addtogroup Algorithms_Library
+ * \{ */
+/** \addtogroup Algorithm_libs algorithms_libs
+ * \{ */
+
+
 class conjugate_cc;
 
-#if GNURADIO_USES_STD_POINTERS
-using conjugate_cc_sptr = std::shared_ptr<conjugate_cc>;
-#else
-using conjugate_cc_sptr = boost::shared_ptr<conjugate_cc>;
-#endif
+using conjugate_cc_sptr = gnss_shared_ptr<conjugate_cc>;
 
 conjugate_cc_sptr make_conjugate_cc();
 
@@ -55,4 +50,7 @@ private:
     conjugate_cc();
 };
 
-#endif
+
+/** \} */
+/** \} */
+#endif  // GNSS_SDR_CONJUGATE_CC_H
