@@ -5,48 +5,35 @@
  * \author Carlos Aviles, 2010. carlos.avilesr(at)googlemail.com
  *
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "pass_through.h"
 #include "configuration_interface.h"
 #include <glog/logging.h>
-#include <volk/volk.h>
-#include <complex>
+#include <gnuradio/gr_complex.h>
+#include <volk/volk_complex.h>
+#include <cstdint>  // for int8_t
+#include <ostream>  // for operator<<
 
-using google::LogMessage;
 
-Pass_Through::Pass_Through(ConfigurationInterface* configuration, const std::string& role,
+Pass_Through::Pass_Through(const ConfigurationInterface* configuration, const std::string& role,
     unsigned int in_streams,
     unsigned int out_streams) : role_(role),
                                 in_streams_(in_streams),
                                 out_streams_(out_streams)
 {
-    std::string default_item_type = "gr_complex";
-    std::string input_type = configuration->property(role + ".input_item_type", default_item_type);
-    std::string output_type = configuration->property(role + ".output_item_type", default_item_type);
+    const std::string default_item_type("gr_complex");
+    const std::string input_type = configuration->property(role + ".input_item_type", default_item_type);
+    const std::string output_type = configuration->property(role + ".output_item_type", default_item_type);
     if (input_type != output_type)
         {
             LOG(WARNING) << "input_item_type and output_item_type are different in a Pass_Through implementation! Taking "
@@ -69,11 +56,7 @@ Pass_Through::Pass_Through(ConfigurationInterface* configuration, const std::str
                     conjugate_cc_ = make_conjugate_cc();
                 }
         }
-    else if (item_type_ == "short")
-        {
-            item_size_ = sizeof(int16_t);
-        }
-    else if (item_type_ == "ishort")
+    else if ((item_type_ == "short") || (item_type_ == "ishort"))
         {
             item_size_ = sizeof(int16_t);
         }
@@ -85,11 +68,7 @@ Pass_Through::Pass_Through(ConfigurationInterface* configuration, const std::str
                     conjugate_sc_ = make_conjugate_sc();
                 }
         }
-    else if (item_type_ == "byte")
-        {
-            item_size_ = sizeof(int8_t);
-        }
-    else if (item_type_ == "ibyte")
+    else if ((item_type_ == "byte") || (item_type_ == "ibyte"))
         {
             item_size_ = sizeof(int8_t);
         }
@@ -108,21 +87,26 @@ Pass_Through::Pass_Through(ConfigurationInterface* configuration, const std::str
         }
 
     kludge_copy_ = gr::blocks::copy::make(item_size_);
+    const uint64_t max_source_buffer_samples = configuration->property("GNSS-SDR.max_source_buffer_samples", 0);
+    if (max_source_buffer_samples > 0)
+        {
+            kludge_copy_->set_max_output_buffer(max_source_buffer_samples);
+            LOG(INFO) << "Set signal conditioner max output buffer to " << max_source_buffer_samples;
+        }
     DLOG(INFO) << "kludge_copy(" << kludge_copy_->unique_id() << ")";
     if (in_streams_ > 1)
         {
             LOG(ERROR) << "This implementation only supports one input stream";
+            LOG(ERROR) << in_streams_;
         }
     if (out_streams_ > 1)
         {
             LOG(ERROR) << "This implementation only supports one output stream";
+            LOG(ERROR) << out_streams_;
         }
 }
 
 
-Pass_Through::~Pass_Through() = default;
-
-
 void Pass_Through::connect(gr::top_block_sptr top_block)
 {
     if (top_block)
