@@ -8,27 +8,12 @@
  *
  * VOLK_GNSSSDR kernel that computes the sine and cosine of a vector of floats.
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  *
  * Copyright (C) 2007  Julien Pommier
  *
- *  This software is provided 'as-is', without any express or implied
- *  warranty.  In no event will the authors be held liable for any damages
- *  arising from the use of this software.
+ * SPDX-License-Identifier: Zlib
  *
- *  Permission is granted to anyone to use this software for any purpose,
- *  including commercial applications, and to alter it and redistribute it
- *  freely, subject to the following restrictions:
- *
- *  1. The origin of this software must not be misrepresented; you must not
- *     claim that you wrote the original software. If you use this software
- *     in a product, an acknowledgment in the product documentation would be
- *     appreciated but is not required.
- *  2. Altered source versions must be plainly marked as such, and must not be
- *     misrepresented as being the original software.
- *  3. This notice may not be removed or altered from any source distribution.
- *
- *  (this is the zlib license)
  */
 
 /*!
@@ -52,14 +37,16 @@
  * \b Outputs
  * \li out:            Vector of the form lv_32fc_t out[n] = lv_cmake(cos(in[n]), sin(in[n]))
  *
+ * Adapted from http://gruntthepeon.free.fr/ssemath/sse_mathfun.h, original code from Julien Pommier
+ * Based on algorithms from the cephes library https://www.netlib.org/cephes/
  */
 
 #ifndef INCLUDED_volk_gnsssdr_32f_sincos_32fc_H
 #define INCLUDED_volk_gnsssdr_32f_sincos_32fc_H
 
-#include <math.h>
 #include <volk_gnsssdr/volk_gnsssdr_common.h>
 #include <volk_gnsssdr/volk_gnsssdr_complex.h>
+#include <math.h>
 
 #ifdef LV_HAVE_SSE4_1
 #include <smmintrin.h>
@@ -97,7 +84,7 @@ static inline void volk_gnsssdr_32f_sincos_32fc_u_sse4_1(lv_32fc_t* out, const f
     cp4 = _mm_set1_ps(0.49603e-4);
     cp5 = _mm_set1_ps(0.551e-6);
 
-    for(;number < quarterPoints; number++)
+    for (; number < quarterPoints; number++)
         {
             aVal = _mm_loadu_ps(aPtr);
             __VOLK_GNSSSDR_PREFETCH(aPtr + 8);
@@ -108,12 +95,12 @@ static inline void volk_gnsssdr_32f_sincos_32fc_u_sse4_1(lv_32fc_t* out, const f
             s = _mm_sub_ps(s, _mm_mul_ps(_mm_cvtepi32_ps(r), pio4A));
             s = _mm_sub_ps(s, _mm_mul_ps(_mm_cvtepi32_ps(r), pio4B));
 
-            s = _mm_div_ps(s, _mm_set1_ps(8.0));    // The constant is 2^N, for 3 times argument reduction
+            s = _mm_div_ps(s, _mm_set1_ps(8.0));  // The constant is 2^N, for 3 times argument reduction
             s = _mm_mul_ps(s, s);
             // Evaluate Taylor series
             s = _mm_mul_ps(_mm_add_ps(_mm_mul_ps(_mm_sub_ps(_mm_mul_ps(_mm_add_ps(_mm_mul_ps(_mm_sub_ps(_mm_mul_ps(s, cp5), cp4), s), cp3), s), cp2), s), cp1), s);
 
-            for(i = 0; i < 3; i++)
+            for (i = 0; i < 3; i++)
                 {
                     s = _mm_mul_ps(s, _mm_sub_ps(ffours, s));
                 }
@@ -145,10 +132,10 @@ static inline void volk_gnsssdr_32f_sincos_32fc_u_sse4_1(lv_32fc_t* out, const f
         }
 
     number = quarterPoints * 4;
-    for(;number < num_points; number++)
+    for (; number < num_points; number++)
         {
             float _in = *aPtr++;
-            *bPtr++ = lv_cmake(cos(_in), sin(_in));
+            *bPtr++ = lv_cmake(cosf(_in), sinf(_in));
         }
 }
 
@@ -191,7 +178,7 @@ static inline void volk_gnsssdr_32f_sincos_32fc_a_sse4_1(lv_32fc_t* out, const f
     cp4 = _mm_set1_ps(0.49603e-4);
     cp5 = _mm_set1_ps(0.551e-6);
 
-    for(;number < quarterPoints; number++)
+    for (; number < quarterPoints; number++)
         {
             aVal = _mm_load_ps(aPtr);
             __VOLK_GNSSSDR_PREFETCH(aPtr + 8);
@@ -202,12 +189,12 @@ static inline void volk_gnsssdr_32f_sincos_32fc_a_sse4_1(lv_32fc_t* out, const f
             s = _mm_sub_ps(s, _mm_mul_ps(_mm_cvtepi32_ps(r), pio4A));
             s = _mm_sub_ps(s, _mm_mul_ps(_mm_cvtepi32_ps(r), pio4B));
 
-            s = _mm_div_ps(s, _mm_set1_ps(8.0));    // The constant is 2^N, for 3 times argument reduction
+            s = _mm_div_ps(s, _mm_set1_ps(8.0));  // The constant is 2^N, for 3 times argument reduction
             s = _mm_mul_ps(s, s);
             // Evaluate Taylor series
             s = _mm_mul_ps(_mm_add_ps(_mm_mul_ps(_mm_sub_ps(_mm_mul_ps(_mm_add_ps(_mm_mul_ps(_mm_sub_ps(_mm_mul_ps(s, cp5), cp4), s), cp3), s), cp2), s), cp1), s);
 
-            for(i = 0; i < 3; i++)
+            for (i = 0; i < 3; i++)
                 {
                     s = _mm_mul_ps(s, _mm_sub_ps(ffours, s));
                 }
@@ -239,10 +226,10 @@ static inline void volk_gnsssdr_32f_sincos_32fc_a_sse4_1(lv_32fc_t* out, const f
         }
 
     number = quarterPoints * 4;
-    for(;number < num_points; number++)
+    for (; number < num_points; number++)
         {
             float _in = *aPtr++;
-            *bPtr++ = lv_cmake(cos(_in), sin(_in));
+            *bPtr++ = lv_cmake(cosf(_in), sinf(_in));
         }
 }
 
@@ -251,8 +238,7 @@ static inline void volk_gnsssdr_32f_sincos_32fc_a_sse4_1(lv_32fc_t* out, const f
 
 #ifdef LV_HAVE_SSE2
 #include <emmintrin.h>
-/* Adapted from http://gruntthepeon.free.fr/ssemath/sse_mathfun.h, original code from Julien Pommier  */
-/* Based on algorithms from the cephes library http://www.netlib.org/cephes/   */
+
 static inline void volk_gnsssdr_32f_sincos_32fc_a_sse2(lv_32fc_t* out, const float* in, unsigned int num_points)
 {
     lv_32fc_t* bPtr = out;
@@ -265,31 +251,49 @@ static inline void volk_gnsssdr_32f_sincos_32fc_a_sse2(lv_32fc_t* out, const flo
     __m128 sine, cosine, aux, x;
     __m128 xmm1, xmm2, xmm3 = _mm_setzero_ps(), sign_bit_sin, y;
 
-    __m128i  emm0, emm2, emm4;
+    __m128i emm0, emm2, emm4;
 
     /* declare some SSE constants */
-    __VOLK_ATTR_ALIGNED(16) static const int _ps_inv_sign_mask[4] = { ~0x80000000, ~0x80000000, ~0x80000000, ~0x80000000 };
-    __VOLK_ATTR_ALIGNED(16) static const int _ps_sign_mask[4] = { (int)0x80000000, (int)0x80000000, (int)0x80000000, (int)0x80000000 };
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _ps_inv_sign_mask[4] = {~0x80000000, ~0x80000000, ~0x80000000, ~0x80000000};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _ps_sign_mask[4] = {(int)0x80000000, (int)0x80000000, (int)0x80000000, (int)0x80000000};
 
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_cephes_FOPI[4] = { 1.27323954473516, 1.27323954473516, 1.27323954473516, 1.27323954473516 };
-    __VOLK_ATTR_ALIGNED(16) static const int _pi32_1[4] = { 1, 1, 1, 1 };
-    __VOLK_ATTR_ALIGNED(16) static const int _pi32_inv1[4] = { ~1, ~1, ~1, ~1 };
-    __VOLK_ATTR_ALIGNED(16) static const int _pi32_2[4] = { 2, 2, 2, 2};
-    __VOLK_ATTR_ALIGNED(16) static const int _pi32_4[4] = { 4, 4, 4, 4};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_cephes_FOPI[4] = {1.27323954473516, 1.27323954473516, 1.27323954473516, 1.27323954473516};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _pi32_1[4] = {1, 1, 1, 1};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _pi32_inv1[4] = {~1, ~1, ~1, ~1};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _pi32_2[4] = {2, 2, 2, 2};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _pi32_4[4] = {4, 4, 4, 4};
 
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_minus_cephes_DP1[4] = { -0.78515625, -0.78515625, -0.78515625, -0.78515625 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_minus_cephes_DP2[4] = { -2.4187564849853515625e-4, -2.4187564849853515625e-4, -2.4187564849853515625e-4, -2.4187564849853515625e-4 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_minus_cephes_DP3[4] = { -3.77489497744594108e-8, -3.77489497744594108e-8, -3.77489497744594108e-8, -3.77489497744594108e-8 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_coscof_p0[4] = { 2.443315711809948E-005, 2.443315711809948E-005, 2.443315711809948E-005, 2.443315711809948E-005 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_coscof_p1[4] = { -1.388731625493765E-003, -1.388731625493765E-003, -1.388731625493765E-003, -1.388731625493765E-003 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_coscof_p2[4] = { 4.166664568298827E-002, 4.166664568298827E-002, 4.166664568298827E-002, 4.166664568298827E-002 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_sincof_p0[4] = { -1.9515295891E-4, -1.9515295891E-4, -1.9515295891E-4, -1.9515295891E-4 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_sincof_p1[4] = { 8.3321608736E-3, 8.3321608736E-3, 8.3321608736E-3, 8.3321608736E-3 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_sincof_p2[4] = { -1.6666654611E-1, -1.6666654611E-1, -1.6666654611E-1, -1.6666654611E-1 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_0p5[4] = { 0.5f, 0.5f, 0.5f, 0.5f };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_1[4] = { 1.0f, 1.0f, 1.0f, 1.0f };
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_minus_cephes_DP1[4] = {-0.78515625, -0.78515625, -0.78515625, -0.78515625};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_minus_cephes_DP2[4] = {-2.4187564849853515625e-4, -2.4187564849853515625e-4, -2.4187564849853515625e-4, -2.4187564849853515625e-4};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_minus_cephes_DP3[4] = {-3.77489497744594108e-8, -3.77489497744594108e-8, -3.77489497744594108e-8, -3.77489497744594108e-8};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_coscof_p0[4] = {2.443315711809948E-005, 2.443315711809948E-005, 2.443315711809948E-005, 2.443315711809948E-005};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_coscof_p1[4] = {-1.388731625493765E-003, -1.388731625493765E-003, -1.388731625493765E-003, -1.388731625493765E-003};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_coscof_p2[4] = {4.166664568298827E-002, 4.166664568298827E-002, 4.166664568298827E-002, 4.166664568298827E-002};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_sincof_p0[4] = {-1.9515295891E-4, -1.9515295891E-4, -1.9515295891E-4, -1.9515295891E-4};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_sincof_p1[4] = {8.3321608736E-3, 8.3321608736E-3, 8.3321608736E-3, 8.3321608736E-3};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_sincof_p2[4] = {-1.6666654611E-1, -1.6666654611E-1, -1.6666654611E-1, -1.6666654611E-1};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_0p5[4] = {0.5f, 0.5f, 0.5f, 0.5f};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_1[4] = {1.0f, 1.0f, 1.0f, 1.0f};
 
-    for(;number < sse_iters; number++)
+    for (; number < sse_iters; number++)
         {
             x = _mm_load_ps(aPtr);
             __VOLK_GNSSSDR_PREFETCH(aPtr + 8);
@@ -307,19 +311,19 @@ static inline void volk_gnsssdr_32f_sincos_32fc_a_sse2(lv_32fc_t* out, const flo
             emm2 = _mm_cvttps_epi32(y);
 
             /* j=(j+1) & (~1) (see the cephes sources) */
-            emm2 = _mm_add_epi32(emm2, *(__m128i *)_pi32_1);
-            emm2 = _mm_and_si128(emm2, *(__m128i *)_pi32_inv1);
+            emm2 = _mm_add_epi32(emm2, *(__m128i*)_pi32_1);
+            emm2 = _mm_and_si128(emm2, *(__m128i*)_pi32_inv1);
             y = _mm_cvtepi32_ps(emm2);
 
             emm4 = emm2;
 
             /* get the swap sign flag for the sine */
-            emm0 = _mm_and_si128(emm2, *(__m128i *)_pi32_4);
+            emm0 = _mm_and_si128(emm2, *(__m128i*)_pi32_4);
             emm0 = _mm_slli_epi32(emm0, 29);
             __m128 swap_sign_bit_sin = _mm_castsi128_ps(emm0);
 
             /* get the polynom selection mask for the sine*/
-            emm2 = _mm_and_si128(emm2, *(__m128i *)_pi32_2);
+            emm2 = _mm_and_si128(emm2, *(__m128i*)_pi32_2);
             emm2 = _mm_cmpeq_epi32(emm2, _mm_setzero_si128());
             __m128 poly_mask = _mm_castsi128_ps(emm2);
 
@@ -335,15 +339,15 @@ static inline void volk_gnsssdr_32f_sincos_32fc_a_sse2(lv_32fc_t* out, const flo
             x = _mm_add_ps(x, xmm2);
             x = _mm_add_ps(x, xmm3);
 
-            emm4 = _mm_sub_epi32(emm4, *(__m128i *)_pi32_2);
-            emm4 = _mm_andnot_si128(emm4, *(__m128i *)_pi32_4);
+            emm4 = _mm_sub_epi32(emm4, *(__m128i*)_pi32_2);
+            emm4 = _mm_andnot_si128(emm4, *(__m128i*)_pi32_4);
             emm4 = _mm_slli_epi32(emm4, 29);
             __m128 sign_bit_cos = _mm_castsi128_ps(emm4);
 
             sign_bit_sin = _mm_xor_ps(sign_bit_sin, swap_sign_bit_sin);
 
             /* Evaluate the first polynom  (0 <= x <= Pi/4) */
-            __m128 z = _mm_mul_ps(x,x);
+            __m128 z = _mm_mul_ps(x, x);
             y = *(__m128*)_ps_coscof_p0;
 
             y = _mm_mul_ps(y, z);
@@ -371,11 +375,11 @@ static inline void volk_gnsssdr_32f_sincos_32fc_a_sse2(lv_32fc_t* out, const flo
             xmm3 = poly_mask;
             __m128 ysin2 = _mm_and_ps(xmm3, y2);
             __m128 ysin1 = _mm_andnot_ps(xmm3, y);
-            y2 = _mm_sub_ps(y2,ysin2);
+            y2 = _mm_sub_ps(y2, ysin2);
             y = _mm_sub_ps(y, ysin1);
 
-            xmm1 = _mm_add_ps(ysin1,ysin2);
-            xmm2 = _mm_add_ps(y,y2);
+            xmm1 = _mm_add_ps(ysin1, ysin2);
+            xmm2 = _mm_add_ps(y, y2);
 
             /* update the sign */
             sine = _mm_xor_ps(xmm1, sign_bit_sin);
@@ -392,20 +396,18 @@ static inline void volk_gnsssdr_32f_sincos_32fc_a_sse2(lv_32fc_t* out, const flo
             aPtr += 4;
         }
 
-    for(number = sse_iters * 4; number < num_points; number++)
+    for (number = sse_iters * 4; number < num_points; number++)
         {
             _in = *aPtr++;
-            *bPtr++ = lv_cmake((float)cos(_in), (float)sin(_in) );
+            *bPtr++ = lv_cmake((float)cosf(_in), (float)sinf(_in));
         }
-
 }
 #endif /* LV_HAVE_SSE2  */
 
 
 #ifdef LV_HAVE_SSE2
 #include <emmintrin.h>
-/* Adapted from http://gruntthepeon.free.fr/ssemath/sse_mathfun.h, original code from Julien Pommier  */
-/* Based on algorithms from the cephes library http://www.netlib.org/cephes/   */
+
 static inline void volk_gnsssdr_32f_sincos_32fc_u_sse2(lv_32fc_t* out, const float* in, unsigned int num_points)
 {
     lv_32fc_t* bPtr = out;
@@ -418,31 +420,49 @@ static inline void volk_gnsssdr_32f_sincos_32fc_u_sse2(lv_32fc_t* out, const flo
     __m128 sine, cosine, aux, x;
     __m128 xmm1, xmm2, xmm3 = _mm_setzero_ps(), sign_bit_sin, y;
 
-    __m128i  emm0, emm2, emm4;
+    __m128i emm0, emm2, emm4;
 
     /* declare some SSE constants */
-    __VOLK_ATTR_ALIGNED(16) static const int _ps_inv_sign_mask[4] = { ~0x80000000, ~0x80000000, ~0x80000000, ~0x80000000 };
-    __VOLK_ATTR_ALIGNED(16) static const int _ps_sign_mask[4] = { (int)0x80000000, (int)0x80000000, (int)0x80000000, (int)0x80000000 };
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _ps_inv_sign_mask[4] = {~0x80000000, ~0x80000000, ~0x80000000, ~0x80000000};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _ps_sign_mask[4] = {(int)0x80000000, (int)0x80000000, (int)0x80000000, (int)0x80000000};
 
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_cephes_FOPI[4] = { 1.27323954473516, 1.27323954473516, 1.27323954473516, 1.27323954473516 };
-    __VOLK_ATTR_ALIGNED(16) static const int _pi32_1[4]  = { 1, 1, 1, 1 };
-    __VOLK_ATTR_ALIGNED(16) static const int _pi32_inv1[4] = { ~1, ~1, ~1, ~1 };
-    __VOLK_ATTR_ALIGNED(16) static const int _pi32_2[4] = { 2, 2, 2, 2};
-    __VOLK_ATTR_ALIGNED(16) static const int _pi32_4[4] = { 4, 4, 4, 4};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_cephes_FOPI[4] = {1.27323954473516, 1.27323954473516, 1.27323954473516, 1.27323954473516};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _pi32_1[4] = {1, 1, 1, 1};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _pi32_inv1[4] = {~1, ~1, ~1, ~1};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _pi32_2[4] = {2, 2, 2, 2};
+    __VOLK_ATTR_ALIGNED(16)
+    static const int _pi32_4[4] = {4, 4, 4, 4};
 
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_minus_cephes_DP1[4] = { -0.78515625, -0.78515625, -0.78515625, -0.78515625 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_minus_cephes_DP2[4] = { -2.4187564849853515625e-4, -2.4187564849853515625e-4, -2.4187564849853515625e-4, -2.4187564849853515625e-4 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_minus_cephes_DP3[4] = { -3.77489497744594108e-8, -3.77489497744594108e-8, -3.77489497744594108e-8, -3.77489497744594108e-8 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_coscof_p0[4] = { 2.443315711809948E-005, 2.443315711809948E-005, 2.443315711809948E-005, 2.443315711809948E-005 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_coscof_p1[4] = { -1.388731625493765E-003, -1.388731625493765E-003, -1.388731625493765E-003, -1.388731625493765E-003 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_coscof_p2[4] = { 4.166664568298827E-002, 4.166664568298827E-002, 4.166664568298827E-002, 4.166664568298827E-002 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_sincof_p0[4] = { -1.9515295891E-4, -1.9515295891E-4, -1.9515295891E-4, -1.9515295891E-4 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_sincof_p1[4] = { 8.3321608736E-3, 8.3321608736E-3, 8.3321608736E-3, 8.3321608736E-3 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_sincof_p2[4] = { -1.6666654611E-1, -1.6666654611E-1, -1.6666654611E-1, -1.6666654611E-1 };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_0p5[4] = { 0.5f, 0.5f, 0.5f, 0.5f };
-    __VOLK_ATTR_ALIGNED(16) static const float _ps_1[4] = { 1.0f, 1.0f, 1.0f, 1.0f };
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_minus_cephes_DP1[4] = {-0.78515625, -0.78515625, -0.78515625, -0.78515625};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_minus_cephes_DP2[4] = {-2.4187564849853515625e-4, -2.4187564849853515625e-4, -2.4187564849853515625e-4, -2.4187564849853515625e-4};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_minus_cephes_DP3[4] = {-3.77489497744594108e-8, -3.77489497744594108e-8, -3.77489497744594108e-8, -3.77489497744594108e-8};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_coscof_p0[4] = {2.443315711809948E-005, 2.443315711809948E-005, 2.443315711809948E-005, 2.443315711809948E-005};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_coscof_p1[4] = {-1.388731625493765E-003, -1.388731625493765E-003, -1.388731625493765E-003, -1.388731625493765E-003};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_coscof_p2[4] = {4.166664568298827E-002, 4.166664568298827E-002, 4.166664568298827E-002, 4.166664568298827E-002};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_sincof_p0[4] = {-1.9515295891E-4, -1.9515295891E-4, -1.9515295891E-4, -1.9515295891E-4};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_sincof_p1[4] = {8.3321608736E-3, 8.3321608736E-3, 8.3321608736E-3, 8.3321608736E-3};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_sincof_p2[4] = {-1.6666654611E-1, -1.6666654611E-1, -1.6666654611E-1, -1.6666654611E-1};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_0p5[4] = {0.5f, 0.5f, 0.5f, 0.5f};
+    __VOLK_ATTR_ALIGNED(16)
+    static const float _ps_1[4] = {1.0f, 1.0f, 1.0f, 1.0f};
 
-    for(;number < sse_iters; number++)
+    for (; number < sse_iters; number++)
         {
             x = _mm_loadu_ps(aPtr);
             __VOLK_GNSSSDR_PREFETCH(aPtr + 8);
@@ -460,19 +480,19 @@ static inline void volk_gnsssdr_32f_sincos_32fc_u_sse2(lv_32fc_t* out, const flo
             emm2 = _mm_cvttps_epi32(y);
 
             /* j=(j+1) & (~1) (see the cephes sources) */
-            emm2 = _mm_add_epi32(emm2, *(__m128i *)_pi32_1);
-            emm2 = _mm_and_si128(emm2, *(__m128i *)_pi32_inv1);
+            emm2 = _mm_add_epi32(emm2, *(__m128i*)_pi32_1);
+            emm2 = _mm_and_si128(emm2, *(__m128i*)_pi32_inv1);
             y = _mm_cvtepi32_ps(emm2);
 
             emm4 = emm2;
 
             /* get the swap sign flag for the sine */
-            emm0 = _mm_and_si128(emm2, *(__m128i *)_pi32_4);
+            emm0 = _mm_and_si128(emm2, *(__m128i*)_pi32_4);
             emm0 = _mm_slli_epi32(emm0, 29);
             __m128 swap_sign_bit_sin = _mm_castsi128_ps(emm0);
 
             /* get the polynom selection mask for the sine*/
-            emm2 = _mm_and_si128(emm2, *(__m128i *)_pi32_2);
+            emm2 = _mm_and_si128(emm2, *(__m128i*)_pi32_2);
             emm2 = _mm_cmpeq_epi32(emm2, _mm_setzero_si128());
             __m128 poly_mask = _mm_castsi128_ps(emm2);
 
@@ -488,15 +508,15 @@ static inline void volk_gnsssdr_32f_sincos_32fc_u_sse2(lv_32fc_t* out, const flo
             x = _mm_add_ps(x, xmm2);
             x = _mm_add_ps(x, xmm3);
 
-            emm4 = _mm_sub_epi32(emm4, *(__m128i *)_pi32_2);
-            emm4 = _mm_andnot_si128(emm4, *(__m128i *)_pi32_4);
+            emm4 = _mm_sub_epi32(emm4, *(__m128i*)_pi32_2);
+            emm4 = _mm_andnot_si128(emm4, *(__m128i*)_pi32_4);
             emm4 = _mm_slli_epi32(emm4, 29);
             __m128 sign_bit_cos = _mm_castsi128_ps(emm4);
 
             sign_bit_sin = _mm_xor_ps(sign_bit_sin, swap_sign_bit_sin);
 
             /* Evaluate the first polynom  (0 <= x <= Pi/4) */
-            __m128 z = _mm_mul_ps(x,x);
+            __m128 z = _mm_mul_ps(x, x);
             y = *(__m128*)_ps_coscof_p0;
 
             y = _mm_mul_ps(y, z);
@@ -524,11 +544,11 @@ static inline void volk_gnsssdr_32f_sincos_32fc_u_sse2(lv_32fc_t* out, const flo
             xmm3 = poly_mask;
             __m128 ysin2 = _mm_and_ps(xmm3, y2);
             __m128 ysin1 = _mm_andnot_ps(xmm3, y);
-            y2 = _mm_sub_ps(y2,ysin2);
+            y2 = _mm_sub_ps(y2, ysin2);
             y = _mm_sub_ps(y, ysin1);
 
-            xmm1 = _mm_add_ps(ysin1,ysin2);
-            xmm2 = _mm_add_ps(y,y2);
+            xmm1 = _mm_add_ps(ysin1, ysin2);
+            xmm2 = _mm_add_ps(y, y2);
 
             /* update the sign */
             sine = _mm_xor_ps(xmm1, sign_bit_sin);
@@ -545,12 +565,11 @@ static inline void volk_gnsssdr_32f_sincos_32fc_u_sse2(lv_32fc_t* out, const flo
             aPtr += 4;
         }
 
-    for(number = sse_iters * 4; number < num_points; number++)
+    for (number = sse_iters * 4; number < num_points; number++)
         {
             _in = *aPtr++;
-            *bPtr++ = lv_cmake((float)cos(_in), (float)sin(_in) );
+            *bPtr++ = lv_cmake((float)cosf(_in), (float)sinf(_in));
         }
-
 }
 #endif /* LV_HAVE_SSE2  */
 
@@ -561,10 +580,10 @@ static inline void volk_gnsssdr_32f_sincos_32fc_generic(lv_32fc_t* out, const fl
 {
     float _in;
     unsigned int i;
-    for(i = 0; i < num_points; i++)
+    for (i = 0; i < num_points; i++)
         {
             _in = *in++;
-            *out++ = lv_cmake((float)cos(_in), (float)sin(_in) );
+            *out++ = lv_cmake((float)cosf(_in), (float)sinf(_in));
         }
 }
 
@@ -586,12 +605,12 @@ static inline void volk_gnsssdr_32f_sincos_32fc_generic_fxpt(lv_32fc_t* out, con
     const int32_t diffbits = bitlength - Nbits;
     uint32_t ux;
     unsigned int i;
-    for(i = 0; i < num_points; i++)
+    for (i = 0; i < num_points; i++)
         {
             _in = *in++;
             d = (int32_t)floor(_in / TWO_PI + 0.5);
             _in -= d * TWO_PI;
-            x = (int32_t) ((float)_in * TWO_TO_THE_31_DIV_PI);
+            x = (int32_t)((float)_in * TWO_TO_THE_31_DIV_PI);
 
             ux = x;
             sin_index = ux >> diffbits;
@@ -601,17 +620,16 @@ static inline void volk_gnsssdr_32f_sincos_32fc_generic_fxpt(lv_32fc_t* out, con
             cos_index = ux >> diffbits;
             c = sine_table_10bits[cos_index][0] * (ux >> 1) + sine_table_10bits[cos_index][1];
 
-            *out++ = lv_cmake((float)c, (float)s );
+            *out++ = lv_cmake((float)c, (float)s);
         }
 }
 
 #endif /* LV_HAVE_GENERIC  */
 
 
-#ifdef LV_HAVE_NEON
+#ifdef LV_HAVE_NEONV7
 #include <arm_neon.h>
-/* Adapted from http://gruntthepeon.free.fr/ssemath/neon_mathfun.h, original code from Julien Pommier  */
-/* Based on algorithms from the cephes library http://www.netlib.org/cephes/   */
+
 static inline void volk_gnsssdr_32f_sincos_32fc_neon(lv_32fc_t* out, const float* in, unsigned int num_points)
 {
     lv_32fc_t* bPtr = out;
@@ -637,7 +655,7 @@ static inline void volk_gnsssdr_32f_sincos_32fc_neon(lv_32fc_t* out, const float
 
     uint32x4_t emm2, poly_mask, sign_mask_sin, sign_mask_cos;
 
-    for(;number < neon_iters; number++)
+    for (; number < neon_iters; number++)
         {
             x = vld1q_f32(aPtr);
             __VOLK_GNSSSDR_PREFETCH(aPtr + 8);
@@ -677,7 +695,7 @@ static inline void volk_gnsssdr_32f_sincos_32fc_neon(lv_32fc_t* out, const float
 
             /* Evaluate the first polynom  (0 <= x <= Pi/4) in y1,
                     and the second polynom      (Pi/4 <= x <= 0) in y2 */
-            z = vmulq_f32(x,x);
+            z = vmulq_f32(x, x);
 
             y1 = vmulq_n_f32(z, c_coscof_p0);
             y2 = vmulq_n_f32(z, c_sincof_p0);
@@ -706,14 +724,14 @@ static inline void volk_gnsssdr_32f_sincos_32fc_neon(lv_32fc_t* out, const float
             aPtr += 4;
         }
 
-    for(number = neon_iters * 4; number < num_points; number++)
+    for (number = neon_iters * 4; number < num_points; number++)
         {
             _in = *aPtr++;
-            *bPtr++ = lv_cmake((float)cos(_in), (float)sin(_in) );
+            *bPtr++ = lv_cmake((float)cosf(_in), (float)sinf(_in));
         }
 }
 
-#endif /* LV_HAVE_NEON  */
+#endif /* LV_HAVE_NEONV7  */
 
 
 #endif /* INCLUDED_volk_gnsssdr_32f_sincos_32fc_H  */
