@@ -6,13 +6,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -24,6 +21,12 @@
 #include <cstdint>
 #include <string>
 
+/** \addtogroup Observables
+ * \{ */
+/** \addtogroup Observables_libs observables_libs
+ * Utilities for GNSS observables configuration.
+ * \{ */
+
 class Obs_Conf
 {
 public:
@@ -38,4 +41,6 @@ public:
     bool dump_mat;
 };
 
-#endif
+/** \} */
+/** \} */
+#endif  // GNSS_SDR_OBS_CONF_H
