@@ -5,13 +5,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -20,35 +17,16 @@
 #ifndef GNSS_SDR_SIGNAL_GENERATOR_C_H
 #define GNSS_SDR_SIGNAL_GENERATOR_C_H
 
-#include "gnss_signal.h"
+#include "gnss_block_interface.h"
 #include <gnuradio/block.h>
 #include <random>
 #include <string>
 #include <vector>
-#if GNURADIO_USES_STD_POINTERS
-#include <memory>
-#else
-#include <boost/shared_ptr.hpp>
-#endif
 
 
 class signal_generator_c;
 
-/*
-* We use std::shared_ptr's instead of raw pointers for all access
-* to gr_blocks (and many other data structures). The shared_ptr gets
-* us transparent reference counting, which greatly simplifies storage
-* management issues.
-*
-* See https://www.boost.org/doc/libs/release/libs/smart_ptr/doc/html/smart_ptr.html
-*
-* As a convention, the _sptr suffix indicates a std::shared_ptr
-*/
-#if GNURADIO_USES_STD_POINTERS
-using signal_generator_c_sptr = std::shared_ptr<signal_generator_c>;
-#else
-using signal_generator_c_sptr = boost::shared_ptr<signal_generator_c>;
-#endif
+using signal_generator_c_sptr = gnss_shared_ptr<signal_generator_c>;
 
 /*!
 * \brief Return a shared_ptr to a new instance of gen_source.
