@@ -5,61 +5,38 @@
  * \author Marc Molina, 2013. marc.molina.pena@gmail.com
  *
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "gen_signal_source.h"
 #include <boost/lexical_cast.hpp>
-#include <boost/thread/thread.hpp>
 #include <glog/logging.h>
 #include <gnuradio/io_signature.h>
 #include <gnuradio/message.h>
 #include <sstream>
 #include <utility>
 
-using google::LogMessage;
 
 // Constructor
-GenSignalSource::GenSignalSource(GNSSBlockInterface *signal_generator, GNSSBlockInterface *filter,
-    std::string role, boost::shared_ptr<gr::msg_queue> queue) : signal_generator_(signal_generator),
-                                                                filter_(filter),
-                                                                role_(std::move(role)),
-                                                                queue_(std::move(queue))
+GenSignalSource::GenSignalSource(std::shared_ptr<GNSSBlockInterface> signal_generator,
+    std::shared_ptr<GNSSBlockInterface> filter,
+    std::string role,
+    Concurrent_Queue<pmt::pmt_t> *queue __attribute__((unused))) : signal_generator_(std::move(signal_generator)),
+                                                                   filter_(std::move(filter)),
+                                                                   role_(std::move(role))
 {
     connected_ = false;
 }
 
 
-// Destructor
-GenSignalSource::~GenSignalSource()
-{
-    delete signal_generator_;
-    delete filter_;
-}
-
-
 void GenSignalSource::connect(gr::top_block_sptr top_block)
 {
     if (connected_)
