@@ -5,13 +5,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -24,11 +21,18 @@
 #include "concurrent_queue.h"
 #include "gnss_block_interface.h"
 #include <gnuradio/blocks/file_sink.h>
+#include <gnuradio/blocks/throttle.h>
 #include <gnuradio/hier_block2.h>
 #include <pmt/pmt.h>
 #include <memory>
 #include <string>
 
+/** \addtogroup Signal_Source
+ * \{ */
+/** \addtogroup Signal_Source_adapters
+ * \{ */
+
+
 class ConfigurationInterface;
 
 /*!
@@ -69,14 +73,22 @@ public:
 private:
     gr::block_sptr labsat23_source_;
     gr::blocks::file_sink::sptr file_sink_;
+    gr::blocks::throttle::sptr throttle_;
+
     std::string role_;
     std::string item_type_;
     std::string filename_;
     std::string dump_filename_;
+
+    size_t item_size_;
+
     unsigned int in_stream_;
     unsigned int out_stream_;
-    size_t item_size_;
+
+    bool enable_throttle_control_;
     bool dump_;
 };
 
+/** \} */
+/** \} */
 #endif  // GNSS_SDR_LABSAT_SIGNAL_SOURCE_H
