@@ -2,61 +2,54 @@
  * \file osmosdr_signal_source.h
  * \brief Signal source wrapper for OsmoSDR-compatible front-ends, such as
  * HackRF or Realtek's RTL2832U-based USB dongle DVB-T receivers
- * (see http://sdr.osmocom.org/trac/wiki/rtl-sdr for more information)
+ * (see https://osmocom.org/projects/rtl-sdr/wiki for more information)
  * \author Javier Arribas, 2012. jarribas(at)cttc.es
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
-#ifndef GNSS_SDR_OSMOSDR_SIGNAL_SOURCE_H_
-#define GNSS_SDR_OSMOSDR_SIGNAL_SOURCE_H_
+#ifndef GNSS_SDR_OSMOSDR_SIGNAL_SOURCE_H
+#define GNSS_SDR_OSMOSDR_SIGNAL_SOURCE_H
 
+#include "concurrent_queue.h"
 #include "gnss_block_interface.h"
-#include <boost/shared_ptr.hpp>
 #include <gnuradio/blocks/file_sink.h>
-#include <gnuradio/msg_queue.h>
+#include <pmt/pmt.h>
 #include <cstdint>
+#include <memory>
 #include <osmosdr/source.h>
 #include <stdexcept>
 #include <string>
 
+/** \addtogroup Signal_Source
+ * \{ */
+/** \addtogroup Signal_Source_adapters
+ * \{ */
+
+
 class ConfigurationInterface;
 
 /*!
  * \brief This class reads samples OsmoSDR-compatible front-ends, such as
  * HackRF or Realtek's RTL2832U-based USB dongle DVB-T receivers
- * (see http://sdr.osmocom.org/trac/wiki/rtl-sdr)
+ * (see https://osmocom.org/projects/rtl-sdr/wiki)
  */
 class OsmosdrSignalSource : public GNSSBlockInterface
 {
 public:
-    OsmosdrSignalSource(ConfigurationInterface* configuration,
+    OsmosdrSignalSource(const ConfigurationInterface* configuration,
         const std::string& role, unsigned int in_stream,
-        unsigned int out_stream, boost::shared_ptr<gr::msg_queue> queue);
+        unsigned int out_stream, Concurrent_Queue<pmt::pmt_t>* queue);
 
-    virtual ~OsmosdrSignalSource();
+    ~OsmosdrSignalSource() = default;
 
     inline std::string role() override
     {
@@ -83,34 +76,35 @@ public:
 
 private:
     void driver_instance();
+
+    osmosdr::source::sptr osmosdr_source_;
+    gnss_shared_ptr<gr::block> valve_;
+    gr::blocks::file_sink::sptr file_sink_;
+
     std::string role_;
+    std::string item_type_;
+    std::string dump_filename_;
+    std::string osmosdr_args_;
+    std::string antenna_;
 
     // Front-end settings
-    bool AGC_enabled_;
     double sample_rate_;
-
-    unsigned int in_stream_;
-    unsigned int out_stream_;
-
     double freq_;
     double gain_;
     double if_gain_;
     double rf_gain_;
 
-    std::string item_type_;
     size_t item_size_;
     int64_t samples_;
+
+    unsigned int in_stream_;
+    unsigned int out_stream_;
+
+    bool AGC_enabled_;
     bool dump_;
-    std::string dump_filename_;
-
-    osmosdr::source::sptr osmosdr_source_;
-    std::string osmosdr_args_;
-
-    std::string antenna_;
-
-    boost::shared_ptr<gr::block> valve_;
-    gr::blocks::file_sink::sptr file_sink_;
-    boost::shared_ptr<gr::msg_queue> queue_;
 };
 
-#endif /*GNSS_SDR_OSMOSDR_SIGNAL_SOURCE_H_*/
+
+/** \} */
+/** \} */
+#endif  // GNSS_SDR_OSMOSDR_SIGNAL_SOURCE_H
