@@ -3,29 +3,15 @@
  * \brief Universal Hardware Driver signal source
  * \author Javier Arribas, 2012. jarribas(at)cttc.es
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "uhd_signal_source.h"
@@ -40,16 +26,14 @@
 #include <utility>
 
 
-using google::LogMessage;
-
-UhdSignalSource::UhdSignalSource(ConfigurationInterface* configuration,
+UhdSignalSource::UhdSignalSource(const ConfigurationInterface* configuration,
     const std::string& role, unsigned int in_stream, unsigned int out_stream,
-    boost::shared_ptr<gr::msg_queue> queue) : role_(role), in_stream_(in_stream), out_stream_(out_stream), queue_(std::move(queue))
+    Concurrent_Queue<pmt::pmt_t>* queue) : role_(role), in_stream_(in_stream), out_stream_(out_stream)
 {
     // DUMP PARAMETERS
-    std::string empty = "";
-    std::string default_dump_file = "./data/signal_source.dat";
-    std::string default_item_type = "cshort";
+    const std::string empty;
+    const std::string default_dump_file("./data/signal_source.dat");
+    const std::string default_item_type("cshort");
 
     // UHD COMMON PARAMETERS
     uhd::device_addr_t dev_addr;
@@ -62,7 +46,7 @@ UhdSignalSource::UhdSignalSource(ConfigurationInterface* configuration,
         {
             dev_addr["addr"] = device_address_;
         }
-    //filter the device by serial number if required (useful for USB devices)
+    // filter the device by serial number if required (useful for USB devices)
     std::string device_serial = configuration->property(role + ".device_serial", empty);
     if (empty != device_serial)  // if not empty
         {
@@ -103,7 +87,7 @@ UhdSignalSource::UhdSignalSource(ConfigurationInterface* configuration,
                 }
         }
     // 1. Make the uhd driver instance
-    //uhd_source_= uhd::usrp::multi_usrp::make(dev_addr);
+    // uhd_source_= uhd::usrp::multi_usrp::make(dev_addr);
 
     // single source
     // param: device_addr the address to identify the hardware
@@ -162,34 +146,34 @@ UhdSignalSource::UhdSignalSource(ConfigurationInterface* configuration,
     // 2.2 set the sample rate for the usrp device
     uhd_source_->set_samp_rate(sample_rate_);
     // the actual sample rate may differ from the rate set
-    std::cout << boost::format("Sampling Rate for the USRP device: %f [sps]...") % (uhd_source_->get_samp_rate()) << std::endl;
-    LOG(INFO) << boost::format("Sampling Rate for the USRP device: %f [sps]...") % (uhd_source_->get_samp_rate());
+    std::cout << "Sampling Rate for the USRP device: " << uhd_source_->get_samp_rate() << " [sps]...\n";
+    LOG(INFO) << "Sampling Rate for the USRP device: " << uhd_source_->get_samp_rate() << " [sps]...";
 
     std::vector<std::string> sensor_names;
 
     for (int i = 0; i < RF_channels_; i++)
         {
-            std::cout << "UHD RF CHANNEL #" << i << " SETTINGS" << std::endl;
+            std::cout << "UHD RF CHANNEL #" << i << " SETTINGS\n";
             // 3. Tune the usrp device to the desired center frequency
             uhd_source_->set_center_freq(freq_.at(i), i);
-            std::cout << boost::format("Actual USRP center freq.: %f [Hz]...") % (uhd_source_->get_center_freq(i)) << std::endl;
-            LOG(INFO) << boost::format("Actual USRP center freq. set to: %f [Hz]...") % (uhd_source_->get_center_freq(i));
+            std::cout << "Actual USRP center freq.: " << uhd_source_->get_center_freq(i) << " [Hz]...\n";
+            LOG(INFO) << "Actual USRP center freq. set to: " << uhd_source_->get_center_freq(i) << " [Hz]...";
 
             // TODO: Assign the remnant IF from the PLL tune error
-            std::cout << boost::format("PLL Frequency tune error %f [Hz]...") % (uhd_source_->get_center_freq(i) - freq_.at(i)) << std::endl;
-            LOG(INFO) << boost::format("PLL Frequency tune error %f [Hz]...") % (uhd_source_->get_center_freq(i) - freq_.at(i));
+            std::cout << "PLL Frequency tune error: " << uhd_source_->get_center_freq(i) - freq_.at(i) << " [Hz]...\n";
+            LOG(INFO) << "PLL Frequency tune error: " << uhd_source_->get_center_freq(i) - freq_.at(i) << " [Hz]...";
 
             // 4. set the gain for the daughterboard
             uhd_source_->set_gain(gain_.at(i), i);
-            std::cout << boost::format("Actual daughterboard gain set to: %f dB...") % uhd_source_->get_gain(i) << std::endl;
-            LOG(INFO) << boost::format("Actual daughterboard gain set to: %f dB...") % uhd_source_->get_gain(i);
+            std::cout << "Actual daughterboard gain set to: " << uhd_source_->get_gain(i) << " dB...\n";
+            LOG(INFO) << "Actual daughterboard gain set to: " << uhd_source_->get_gain(i) << " dB...";
 
-            //5.  Set the bandpass filter on the RF frontend
-            std::cout << boost::format("Setting RF bandpass filter bandwidth to: %f [Hz]...") % IF_bandwidth_hz_.at(i) << std::endl;
+            // 5.  Set the bandpass filter on the RF frontend
+            std::cout << "Setting RF bandpass filter bandwidth to: " << IF_bandwidth_hz_.at(i) << " [Hz]...\n";
             uhd_source_->set_bandwidth(IF_bandwidth_hz_.at(i), i);
 
-            //set the antenna (optional)
-            //uhd_source_->set_antenna(ant);
+            // set the antenna (optional)
+            // uhd_source_->set_antenna(ant);
 
             // We should wait? #include <boost/thread.hpp>
             // boost::this_thread::sleep(boost::posix_time::seconds(1));
@@ -199,26 +183,25 @@ UhdSignalSource::UhdSignalSource(ConfigurationInterface* configuration,
             if (std::find(sensor_names.begin(), sensor_names.end(), "lo_locked") != sensor_names.end())
                 {
                     uhd::sensor_value_t lo_locked = uhd_source_->get_sensor("lo_locked", i);
-                    std::cout << boost::format("Check for front-end %s ...") % lo_locked.to_pp_string() << " is ";
+                    std::cout << "Check for front-end " << lo_locked.to_pp_string() << " is ... ";
                     if (lo_locked.to_bool() == true)
                         {
-                            std::cout << "Locked" << std::endl;
+                            std::cout << "Locked\n";
                         }
                     else
                         {
-                            std::cout << "UNLOCKED!" << std::endl;
+                            std::cout << "UNLOCKED!\n";
                         }
-                    //UHD_ASSERT_THROW(lo_locked.to_bool());
+                    // UHD_ASSERT_THROW(lo_locked.to_bool());
                 }
         }
 
-
     for (int i = 0; i < RF_channels_; i++)
         {
-            if (samples_.at(i) != 0)
+            if (samples_.at(i) != 0ULL)
                 {
                     LOG(INFO) << "RF_channel " << i << " Send STOP signal after " << samples_.at(i) << " samples";
-                    valve_.push_back(gnss_sdr_make_valve(item_size_, samples_.at(i), queue_));
+                    valve_.emplace_back(gnss_sdr_make_valve(item_size_, samples_.at(i), queue));
                     DLOG(INFO) << "valve(" << valve_.at(i)->unique_id() << ")";
                 }
 
@@ -240,14 +223,11 @@ UhdSignalSource::UhdSignalSource(ConfigurationInterface* configuration,
 }
 
 
-UhdSignalSource::~UhdSignalSource() = default;
-
-
 void UhdSignalSource::connect(gr::top_block_sptr top_block)
 {
     for (int i = 0; i < RF_channels_; i++)
         {
-            if (samples_.at(i) != 0)
+            if (samples_.at(i) != 0ULL)
                 {
                     top_block->connect(uhd_source_, i, valve_.at(i), 0);
                     DLOG(INFO) << "connected usrp source to valve RF Channel " << i;
@@ -271,9 +251,10 @@ void UhdSignalSource::connect(gr::top_block_sptr top_block)
 
 void UhdSignalSource::disconnect(gr::top_block_sptr top_block)
 {
+    uhd_source_->stop();
     for (int i = 0; i < RF_channels_; i++)
         {
-            if (samples_.at(i) != 0)
+            if (samples_.at(i) != 0ULL)
                 {
                     top_block->disconnect(uhd_source_, i, valve_.at(i), 0);
                     LOG(INFO) << "UHD source disconnected";
@@ -296,7 +277,7 @@ void UhdSignalSource::disconnect(gr::top_block_sptr top_block)
 gr::basic_block_sptr UhdSignalSource::get_left_block()
 {
     LOG(WARNING) << "Trying to get signal source left block.";
-    //return gr_basic_block_sptr();
+    // return gr_basic_block_sptr();
     return gr::uhd::usrp_source::sptr();
 }
 
@@ -309,8 +290,8 @@ gr::basic_block_sptr UhdSignalSource::get_right_block()
 
 gr::basic_block_sptr UhdSignalSource::get_right_block(int RF_channel)
 {
-    //TODO: There is a incoherence here: Multichannel UHD is a single block with multiple outputs, but if the sample limit is enabled, the output is a multiple block!
-    if (samples_.at(RF_channel) != 0)
+    // TODO: There is a incoherence here: Multichannel UHD is a single block with multiple outputs, but if the sample limit is enabled, the output is a multiple block!
+    if (samples_.at(RF_channel) != 0ULL)
         {
             return valve_.at(RF_channel);
         }
