@@ -3,15 +3,13 @@
  *
  * \brief Unpacks the Labsat 2 (ls2) and (ls3) capture files
  * \author Javier Arribas jarribas (at) cttc.es
+ *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -21,24 +19,22 @@
 #define GNSS_SDR_LABSAT23_SOURCE_H
 
 #include "concurrent_queue.h"
+#include "gnss_block_interface.h"
 #include <gnuradio/block.h>
 #include <pmt/pmt.h>
 #include <cstdint>
 #include <fstream>
 #include <string>
-#if GNURADIO_USES_STD_POINTERS
-#include <memory>
-#else
-#include <boost/shared_ptr.hpp>
-#endif
+
+/** \addtogroup Signal_Source
+ * \{ */
+/** \addtogroup Signal_Source_gnuradio_blocks
+ * \{ */
+
 
 class labsat23_source;
 
-#if GNURADIO_USES_STD_POINTERS
-using labsat23_source_sptr = std::shared_ptr<labsat23_source>;
-#else
-using labsat23_source_sptr = boost::shared_ptr<labsat23_source>;
-#endif
+using labsat23_source_sptr = gnss_shared_ptr<labsat23_source>;
 
 labsat23_source_sptr labsat23_make_source_sptr(
     const char *signal_file_basename,
@@ -84,4 +80,7 @@ private:
     bool d_header_parsed;
 };
 
+
+/** \} */
+/** \} */
 #endif  // GNSS_SDR_LABSAT23_SOURCE_H
