@@ -6,13 +6,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -27,13 +24,10 @@ BeidouB3iTelemetryDecoder::BeidouB3iTelemetryDecoder(
     unsigned int in_streams, unsigned int out_streams)
     : role_(role), in_streams_(in_streams), out_streams_(out_streams)
 {
-    const std::string default_dump_filename("./navigation.dat");
     DLOG(INFO) << "role " << role;
-    dump_ = configuration->property(role + ".dump", false);
-    dump_filename_ =
-        configuration->property(role + ".dump_filename", default_dump_filename);
+    tlm_parameters_.SetFromConfiguration(configuration, role);
     // make telemetry decoder object
-    telemetry_decoder_ = beidou_b3i_make_telemetry_decoder_gs(satellite_, dump_);
+    telemetry_decoder_ = beidou_b3i_make_telemetry_decoder_gs(satellite_, tlm_parameters_);
     DLOG(INFO) << "telemetry_decoder(" << telemetry_decoder_->unique_id() << ")";
     channel_ = 0;
     if (in_streams_ > 1)
