@@ -6,13 +6,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -25,10 +22,18 @@
 #include "gnss_satellite.h"  // for Gnss_Satellite
 #include "gnss_synchro.h"
 #include "telemetry_decoder_interface.h"
+#include "tlm_conf.h"
 #include <gnuradio/runtime_types.h>  // for basic_block_sptr, top_block_sptr
 #include <cstddef>                   // for size_t
 #include <string>
 
+
+/** \addtogroup Telemetry_Decoder
+ * \{ */
+/** \addtogroup Telemetry_Decoder_adapters
+ * \{ */
+
+
 class ConfigurationInterface;
 
 /*!
@@ -74,12 +79,13 @@ public:
 private:
     beidou_b3i_telemetry_decoder_gs_sptr telemetry_decoder_;
     Gnss_Satellite satellite_;
-    std::string dump_filename_;
+    Tlm_Conf tlm_parameters_;
     std::string role_;
     int channel_;
     unsigned int in_streams_;
     unsigned int out_streams_;
-    bool dump_;
 };
 
+/** \} */
+/** \} */
 #endif
