@@ -6,13 +6,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -26,10 +23,20 @@
 #include "gnss_synchro.h"
 #include "gps_l1_ca_telemetry_decoder_gs.h"
 #include "telemetry_decoder_interface.h"
+#include "tlm_conf.h"
 #include <gnuradio/runtime_types.h>  // for basic_block_sptr, top_block_sptr
 #include <cstddef>                   // for size_t
 #include <string>
 
+/** \addtogroup Telemetry_Decoder Telemetry Decoder
+ * Classes for the decoding of GNSS Navigation messages.
+ * \{ */
+/** \addtogroup Telemetry_Decoder_adapters telemetry_decoder_adapters
+ * Wrap GNU Radio blocs for the decoding of GNSS Navigation messages with a
+ * TelemetryDecoderInterface
+ * \{ */
+
+
 class ConfigurationInterface;
 
 /*!
@@ -79,12 +86,14 @@ public:
 private:
     gps_l1_ca_telemetry_decoder_gs_sptr telemetry_decoder_;
     Gnss_Satellite satellite_;
-    std::string dump_filename_;
+    Tlm_Conf tlm_parameters_;
     std::string role_;
     int channel_;
     unsigned int in_streams_;
     unsigned int out_streams_;
-    bool dump_;
 };
 
-#endif
+
+/** \} */
+/** \} */
+#endif  // GNSS_SDR_GPS_L1_CA_TELEMETRY_DECODER_H
