@@ -9,29 +9,15 @@
  * A Software-Defined GPS and Galileo Receiver. A Single-Frequency
  * Approach, Birkhauser, 2007
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 
@@ -42,14 +28,8 @@
 #include <glog/logging.h>
 
 
-using google::LogMessage;
-
-void GpsL1CaDllPllTrackingGPU::stop_tracking()
-{
-}
-
 GpsL1CaDllPllTrackingGPU::GpsL1CaDllPllTrackingGPU(
-    ConfigurationInterface* configuration, std::string role,
+    const ConfigurationInterface* configuration, std::string role,
     unsigned int in_streams, unsigned int out_streams) : role_(role), in_streams_(in_streams), out_streams_(out_streams)
 {
     DLOG(INFO) << "role " << role;
@@ -59,12 +39,12 @@ GpsL1CaDllPllTrackingGPU::GpsL1CaDllPllTrackingGPU(
     bool dump;
     std::string dump_filename;
     std::string item_type;
-    std::string default_item_type = "gr_complex";
+    const std::string default_item_type("gr_complex");
     float pll_bw_hz;
     float dll_bw_hz;
     float early_late_space_chips;
     item_type = configuration->property(role + ".item_type", default_item_type);
-    //vector_length = configuration->property(role + ".vector_length", 2048);
+    // vector_length = configuration->property(role + ".vector_length", 2048);
     int fs_in_deprecated = configuration->property("GNSS-SDR.internal_fs_hz", 2048000);
     fs_in = configuration->property("GNSS-SDR.internal_fs_sps", fs_in_deprecated);
     dump = configuration->property(role + ".dump", false);
@@ -73,11 +53,11 @@ GpsL1CaDllPllTrackingGPU::GpsL1CaDllPllTrackingGPU(
     dll_bw_hz = configuration->property(role + ".dll_bw_hz", 2.0);
     if (FLAGS_dll_bw_hz != 0.0) dll_bw_hz = static_cast<float>(FLAGS_dll_bw_hz);
     early_late_space_chips = configuration->property(role + ".early_late_space_chips", 0.5);
-    std::string default_dump_filename = "./track_ch";
+    const std::string default_dump_filename("./track_ch");
     dump_filename = configuration->property(role + ".dump_filename", default_dump_filename);
-    vector_length = std::round(fs_in / (GPS_L1_CA_CODE_RATE_HZ / GPS_L1_CA_CODE_LENGTH_CHIPS));
+    vector_length = std::round(fs_in / (GPS_L1_CA_CODE_RATE_CPS / GPS_L1_CA_CODE_LENGTH_CHIPS));
 
-    //################# MAKE TRACKING GNURadio object ###################
+    // ################# MAKE TRACKING GNURadio object ###################
     if (item_type.compare("gr_complex") == 0)
         {
             item_size_ = sizeof(gr_complex);
@@ -118,6 +98,12 @@ void GpsL1CaDllPllTrackingGPU::start_tracking()
     tracking_->start_tracking();
 }
 
+
+void GpsL1CaDllPllTrackingGPU::stop_tracking()
+{
+}
+
+
 /*
  * Set tracking channel unique ID
  */
@@ -127,32 +113,37 @@ void GpsL1CaDllPllTrackingGPU::set_channel(unsigned int channel)
     tracking_->set_channel(channel);
 }
 
+
 void GpsL1CaDllPllTrackingGPU::set_gnss_synchro(Gnss_Synchro* p_gnss_synchro)
 {
     tracking_->set_gnss_synchro(p_gnss_synchro);
 }
 
+
 void GpsL1CaDllPllTrackingGPU::connect(gr::top_block_sptr top_block)
 {
     if (top_block)
         { /* top_block is not null */
         };
-    //nothing to connect, now the tracking uses gr_sync_decimator
+    // nothing to connect, now the tracking uses gr_sync_decimator
 }
 
+
 void GpsL1CaDllPllTrackingGPU::disconnect(gr::top_block_sptr top_block)
 {
     if (top_block)
         { /* top_block is not null */
         };
-    //nothing to disconnect, now the tracking uses gr_sync_decimator
+    // nothing to disconnect, now the tracking uses gr_sync_decimator
 }
 
+
 gr::basic_block_sptr GpsL1CaDllPllTrackingGPU::get_left_block()
 {
     return tracking_;
 }
 
+
 gr::basic_block_sptr GpsL1CaDllPllTrackingGPU::get_right_block()
 {
     return tracking_;
