@@ -10,38 +10,29 @@
  * A Software-Defined GPS and Galileo Receiver. A Single-Frequency
  * Approach, Birkhauser, 2007
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
-#ifndef GNSS_SDR_GPS_L1_CA_TCP_CONNECTOR_TRACKING_H_
-#define GNSS_SDR_GPS_L1_CA_TCP_CONNECTOR_TRACKING_H_
+#ifndef GNSS_SDR_GPS_L1_CA_TCP_CONNECTOR_TRACKING_H
+#define GNSS_SDR_GPS_L1_CA_TCP_CONNECTOR_TRACKING_H
 
 #include "gps_l1_ca_tcp_connector_tracking_cc.h"
 #include "tracking_interface.h"
 #include <string>
 
+/** \addtogroup Tracking
+ * \{ */
+/** \addtogroup Tracking_adapters
+ * \{ */
+
 
 class ConfigurationInterface;
 
@@ -51,12 +42,13 @@ class ConfigurationInterface;
 class GpsL1CaTcpConnectorTracking : public TrackingInterface
 {
 public:
-    GpsL1CaTcpConnectorTracking(ConfigurationInterface* configuration,
+    GpsL1CaTcpConnectorTracking(
+        const ConfigurationInterface* configuration,
         const std::string& role,
         unsigned int in_streams,
         unsigned int out_streams);
 
-    virtual ~GpsL1CaTcpConnectorTracking();
+    ~GpsL1CaTcpConnectorTracking() = default;
 
     inline std::string role() override
     {
@@ -91,6 +83,7 @@ public:
     void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro) override;
 
     void start_tracking() override;
+
     /*!
      * \brief Stop running tracking
      */
@@ -99,12 +92,13 @@ public:
 private:
     gps_l1_ca_tcp_connector_tracking_cc_sptr tracking_;
     size_t item_size_;
-
     unsigned int channel_;
-
     std::string role_;
     unsigned int in_streams_;
     unsigned int out_streams_;
 };
 
-#endif  // GNSS_SDR_GPS_L1_CA_TCP_CONNECTOR_TRACKING_H_
+
+/** \} */
+/** \} */
+#endif  // GNSS_SDR_GPS_L1_CA_TCP_CONNECTOR_TRACKING_H
