@@ -11,38 +11,18 @@
  * and value. It's done this way because it works well on low-memory
  * embedded systems, but also because it makes for a KISS implementation.
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  * inih and INIReader are released under the New BSD license:
  *
  * Copyright (c) 2009, Brush Technology
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *    * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *    * Redistributions in binary form must reproduce the above copyright
- *      notice, this list of conditions and the following disclaimer in the
- *      documentation and/or other materials provided with the distribution.
- *    * Neither the name of Brush Technology nor the names of its contributors
- *      may be used to endorse or promote products derived from this software
- *      without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY BRUSH TECHNOLOGY ''AS IS'' AND ANY
- * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL BRUSH TECHNOLOGY BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: BSD-3-Clause
  *
  * Go to the project home page for more info:
  *
- * http://code.google.com/p/inih/
- * -------------------------------------------------------------------------
+ * https://github.com/benhoyt/inih
+ * -----------------------------------------------------------------------------
  */
 
 #include "INIReader.h"
@@ -58,13 +38,13 @@ INIReader::INIReader(const std::string& filename)
 }
 
 
-int INIReader::ParseError()
+int INIReader::ParseError() const
 {
     return _error;
 }
 
 
-std::string INIReader::Get(const std::string& section, const std::string& name, std::string default_value)
+std::string INIReader::Get(const std::string& section, const std::string& name, const std::string& default_value)
 {
     std::string key = MakeKey(section, name);
     return _values.count(key) ? _values[key] : default_value;
@@ -87,7 +67,9 @@ std::string INIReader::MakeKey(const std::string& section, const std::string& na
     std::string key = section + "." + name;
     // Convert to lower case to make lookups case-insensitive
     for (char& i : key)
-        i = tolower(i);
+        {
+            i = tolower(i);
+        }
     return key;
 }
 
