@@ -1,9 +1,9 @@
 /*-
- * Copyright (c) 2003, 2004 Lev Walkin <vlm@lionet.info>. All rights reserved.
- * Redistribution and modifications are permitted subject to BSD license.
+ * SPDX-FileCopyrightText: (c) 2003, 2004 Lev Walkin <vlm@lionet.info>. All rights reserved.
+ * SPDX-License-Identifier: BSD-1-Clause
  */
-#ifndef _UTCTime_H_
-#define _UTCTime_H_
+#ifndef _UTCTime_H
+#define _UTCTime_H
 
 #include <OCTET_STRING.h>
 
@@ -21,16 +21,17 @@ extern "C"
     xer_type_encoder_f UTCTime_encode_xer;
 
     /***********************
- * Some handy helpers. *
- ***********************/
+     * Some handy helpers. *
+     ***********************/
 
     struct tm; /* <time.h> */
 
     /* See asn_GT2time() in GeneralizedTime.h */
-    time_t asn_UT2time(const UTCTime_t *, struct tm *_optional_tm4fill, int as_gmt);
+    time_t asn_UT2time(const UTCTime_t * /*st*/, struct tm *_tm, int as_gmt);
 
     /* See asn_time2GT() in GeneralizedTime.h */
-    UTCTime_t *asn_time2UT(UTCTime_t *__opt_ut, const struct tm *, int force_gmt);
+    UTCTime_t *asn_time2UT(UTCTime_t *__opt_ut, const struct tm * /*tm*/,
+        int force_gmt);
 
 #ifdef __cplusplus
 }
