@@ -13,13 +13,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -58,6 +55,9 @@
 #include "galileo_e5b_dll_pll_tracking.h"
 #include "galileo_e5b_pcps_acquisition.h"
 #include "galileo_e5b_telemetry_decoder.h"
+#include "galileo_e6_dll_pll_tracking.h"
+#include "galileo_e6_pcps_acquisition.h"
+#include "galileo_e6_telemetry_decoder.h"
 #include "glonass_l1_ca_dll_pll_c_aid_tracking.h"
 #include "glonass_l1_ca_dll_pll_tracking.h"
 #include "glonass_l1_ca_pcps_acquisition.h"
@@ -216,46 +216,64 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetSignalConditioner(
         {
             LOG(WARNING) << e.what();
         }
-    std::string signal_conditioner = configuration->property(role_conditioner + ".implementation", empty_implementation);
+    const std::string signal_conditioner = configuration->property(role_conditioner + ".implementation", empty_implementation);
+
+    const std::string data_type_adapter = configuration->property(role_datatypeadapter + ".implementation", empty_implementation);
+    const std::string input_filter = configuration->property(role_inputfilter + ".implementation", empty_implementation);
+    const std::string resampler = configuration->property(role_resampler + ".implementation", empty_implementation);
 
-    std::string data_type_adapter;
-    std::string input_filter;
-    std::string resampler;
     if (signal_conditioner == "Pass_Through")
         {
-            data_type_adapter = "Pass_Through";
-            input_filter = "Pass_Through";
-            resampler = "Pass_Through";
-        }
-    else
-        {
-            data_type_adapter = configuration->property(role_datatypeadapter + ".implementation", empty_implementation);
-            input_filter = configuration->property(role_inputfilter + ".implementation", empty_implementation);
-            resampler = configuration->property(role_resampler + ".implementation", empty_implementation);
+            if (!data_type_adapter.empty() and (data_type_adapter != "Pass_Through"))
+                {
+                    LOG(WARNING) << "Configuration warning: if " << role_conditioner << ".implementation\n"
+                                 << "is set to Pass_Through, then the " << role_datatypeadapter << ".implementation\n"
+                                 << "parameter should be either not set or set to Pass_Through.\n"
+                                 << role_datatypeadapter << " configuration parameters will be ignored.";
+                }
+            if (!input_filter.empty() and (input_filter != "Pass_Through"))
+                {
+                    LOG(WARNING) << "Configuration warning: if " << role_conditioner << ".implementation\n"
+                                 << "is set to Pass_Through, then the " << role_inputfilter << ".implementation\n"
+                                 << "parameter should be either not set or set to Pass_Through.\n"
+                                 << role_inputfilter << " configuration parameters will be ignored.";
+                }
+            if (!resampler.empty() and (resampler != "Pass_Through"))
+                {
+                    LOG(WARNING) << "Configuration warning: if " << role_conditioner << ".implementation\n"
+                                 << "is set to Pass_Through, then the " << role_resampler << ".implementation\n"
+                                 << "parameter should be either not set or set to Pass_Through.\n"
+                                 << role_resampler << " configuration parameters will be ignored.";
+                }
+            LOG(INFO) << "Getting " << role_conditioner << " with Pass_Through implementation";
+
+            std::unique_ptr<GNSSBlockInterface> conditioner_ = std::make_unique<Pass_Through>(configuration, role_conditioner, 1, 1);
+
+            return conditioner_;
         }
 
-    LOG(INFO) << "Getting SignalConditioner with DataTypeAdapter implementation: "
-              << data_type_adapter << ", InputFilter implementation: "
-              << input_filter << ", and Resampler implementation: "
+    LOG(INFO) << "Getting " << role_conditioner << " with " << role_datatypeadapter << " implementation: "
+              << data_type_adapter << ", " << role_inputfilter << " implementation: "
+              << input_filter << ", and " << role_resampler << " implementation: "
               << resampler;
 
     if (signal_conditioner == "Array_Signal_Conditioner")
         {
             // instantiate the array version
-            std::unique_ptr<GNSSBlockInterface> conditioner_ = std::make_unique<ArraySignalConditioner>(configuration,
+            std::unique_ptr<GNSSBlockInterface> conditioner_ = std::make_unique<ArraySignalConditioner>(
                 GetBlock(configuration, role_datatypeadapter, 1, 1),
                 GetBlock(configuration, role_inputfilter, 1, 1),
                 GetBlock(configuration, role_resampler, 1, 1),
-                role_conditioner, "Signal_Conditioner");
+                role_conditioner);
             return conditioner_;
         }
 
     // single-antenna version
-    std::unique_ptr<GNSSBlockInterface> conditioner_ = std::make_unique<SignalConditioner>(configuration,
+    std::unique_ptr<GNSSBlockInterface> conditioner_ = std::make_unique<SignalConditioner>(
         GetBlock(configuration, role_datatypeadapter, 1, 1),
         GetBlock(configuration, role_inputfilter, 1, 1),
         GetBlock(configuration, role_resampler, 1, 1),
-        role_conditioner, "Signal_Conditioner");
+        role_conditioner);
     return conditioner_;
 }
 
@@ -265,9 +283,14 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetObservables(const Confi
     const std::string empty_implementation;
     std::string implementation = configuration->property("Observables.implementation", empty_implementation);
     LOG(INFO) << "Getting Observables with implementation " << implementation;
+    if (implementation != "Hybrid_Observables")
+        {
+            LOG(WARNING) << "Error in configuration file: please set Observables.implementation=Hybrid_Observables";
+        }
     unsigned int Galileo_channels = configuration->property("Channels_1B.count", 0);
     Galileo_channels += configuration->property("Channels_5X.count", 0);
     Galileo_channels += configuration->property("Channels_7X.count", 0);
+    Galileo_channels += configuration->property("Channels_E6.count", 0);
     unsigned int GPS_channels = configuration->property("Channels_1C.count", 0);
     GPS_channels += configuration->property("Channels_2S.count", 0);
     GPS_channels += configuration->property("Channels_L5.count", 0);
@@ -294,9 +317,14 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetPVT(const Configuration
     const std::string empty_implementation;
     std::string implementation = configuration->property("PVT.implementation", empty_implementation);
     LOG(INFO) << "Getting PVT with implementation " << implementation;
+    if (implementation != "RTKLIB_PVT")
+        {
+            LOG(WARNING) << "Error in configuration file: please set PVT.implementation=RTKLIB_PVT";
+        }
     unsigned int Galileo_channels = configuration->property("Channels_1B.count", 0);
     Galileo_channels += configuration->property("Channels_5X.count", 0);
     Galileo_channels += configuration->property("Channels_7X.count", 0);
+    Galileo_channels += configuration->property("Channels_E6.count", 0);
     unsigned int GPS_channels = configuration->property("Channels_1C.count", 0);
     GPS_channels += configuration->property("Channels_2S.count", 0);
     GPS_channels += configuration->property("Channels_L5.count", 0);
@@ -386,6 +414,7 @@ std::unique_ptr<std::vector<std::unique_ptr<GNSSBlockInterface>>> GNSSBlockFacto
     const unsigned int Channels_B1_count = configuration->property("Channels_B1.count", 0);
     const unsigned int Channels_B3_count = configuration->property("Channels_B3.count", 0);
     const unsigned int Channels_7X_count = configuration->property("Channels_7X.count", 0);
+    const unsigned int Channels_E6_count = configuration->property("Channels_E6.count", 0);
 
     const unsigned int total_channels = Channels_1C_count +
                                         Channels_1B_count +
@@ -396,7 +425,8 @@ std::unique_ptr<std::vector<std::unique_ptr<GNSSBlockInterface>>> GNSSBlockFacto
                                         Channels_L5_count +
                                         Channels_B1_count +
                                         Channels_B3_count +
-                                        Channels_7X_count;
+                                        Channels_7X_count +
+                                        Channels_E6_count;
 
     auto channels = std::make_unique<std::vector<std::unique_ptr<GNSSBlockInterface>>>(total_channels);
     try
@@ -466,6 +496,18 @@ std::unique_ptr<std::vector<std::unique_ptr<GNSSBlockInterface>>> GNSSBlockFacto
                     channel_absolute_id++;
                 }
 
+            // **************** GALILEO E6 (B/C HAS) CHANNELS **************
+            LOG(INFO) << "Getting " << Channels_E6_count << " GALILEO E6 (B/C HAS) channels";
+
+            for (unsigned int i = 0; i < Channels_E6_count; i++)
+                {
+                    // Store the channel into the vector of channels
+                    channels->at(channel_absolute_id) = GetChannel(configuration,
+                        std::string("E6"),
+                        channel_absolute_id,
+                        queue);
+                    channel_absolute_id++;
+                }
 
             // **************** GLONASS L1 C/A CHANNELS ************************
             LOG(INFO) << "Getting " << Channels_1G_count << " GLONASS L1 C/A channels";
@@ -946,6 +988,12 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                 out_streams);
             block = std::move(block_);
         }
+    else if (implementation == "Galileo_E1_PCPS_QuickSync_Ambiguous_Acquisition")
+        {
+            std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE1PcpsQuickSyncAmbiguousAcquisition>(configuration, role, in_streams,
+                out_streams);
+            block = std::move(block_);
+        }
     else if (implementation == "Galileo_E5a_Noncoherent_IQ_Acquisition_CAF")
         {
             std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE5aNoncoherentIQAcquisitionCaf>(configuration, role, in_streams,
@@ -964,9 +1012,9 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                 out_streams);
             block = std::move(block_);
         }
-    else if (implementation == "Galileo_E1_PCPS_QuickSync_Ambiguous_Acquisition")
+    else if (implementation == "Galileo_E6_PCPS_Acquisition")
         {
-            std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE1PcpsQuickSyncAmbiguousAcquisition>(configuration, role, in_streams,
+            std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE6PcpsAcquisition>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
@@ -1096,6 +1144,12 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                 out_streams);
             block = std::move(block_);
         }
+    else if (implementation == "Galileo_E6_DLL_PLL_Tracking")
+        {
+            std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE6DllPllTracking>(configuration, role, in_streams,
+                out_streams);
+            block = std::move(block_);
+        }
     else if (implementation == "GLONASS_L1_CA_DLL_PLL_Tracking")
         {
             std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GlonassL1CaDllPllTracking>(configuration, role, in_streams,
@@ -1192,18 +1246,18 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                 out_streams);
             block = std::move(block_);
         }
-    else if (implementation == "Galileo_E1B_Telemetry_Decoder")
-        {
-            std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE1BTelemetryDecoder>(configuration, role, in_streams,
-                out_streams);
-            block = std::move(block_);
-        }
     else if (implementation == "SBAS_L1_Telemetry_Decoder")
         {
             std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<SbasL1TelemetryDecoder>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
+    else if (implementation == "Galileo_E1B_Telemetry_Decoder")
+        {
+            std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE1BTelemetryDecoder>(configuration, role, in_streams,
+                out_streams);
+            block = std::move(block_);
+        }
     else if (implementation == "Galileo_E5a_Telemetry_Decoder")
         {
             std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE5aTelemetryDecoder>(configuration, role, in_streams,
@@ -1216,6 +1270,12 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                 out_streams);
             block = std::move(block_);
         }
+    else if (implementation == "Galileo_E6_Telemetry_Decoder")
+        {
+            std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE6TelemetryDecoder>(configuration, role, in_streams,
+                out_streams);
+            block = std::move(block_);
+        }
     else if (implementation == "GLONASS_L1_CA_Telemetry_Decoder")
         {
             std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GlonassL1CaTelemetryDecoder>(configuration, role, in_streams,
@@ -1376,6 +1436,12 @@ std::unique_ptr<AcquisitionInterface> GNSSBlockFactory::GetAcqBlock(
                 out_streams);
             block = std::move(block_);
         }
+    else if (implementation == "Galileo_E6_PCPS_Acquisition")
+        {
+            std::unique_ptr<AcquisitionInterface> block_ = std::make_unique<GalileoE6PcpsAcquisition>(configuration, role, in_streams,
+                out_streams);
+            block = std::move(block_);
+        }
     else if (implementation == "GLONASS_L1_CA_PCPS_Acquisition")
         {
             std::unique_ptr<AcquisitionInterface> block_ = std::make_unique<GlonassL1CaPcpsAcquisition>(configuration, role, in_streams,
@@ -1509,6 +1575,12 @@ std::unique_ptr<TrackingInterface> GNSSBlockFactory::GetTrkBlock(
                 out_streams);
             block = std::move(block_);
         }
+    else if (implementation == "Galileo_E6_DLL_PLL_Tracking")
+        {
+            std::unique_ptr<TrackingInterface> block_ = std::make_unique<GalileoE6DllPllTracking>(configuration, role, in_streams,
+                out_streams);
+            block = std::move(block_);
+        }
     else if (implementation == "GPS_L2_M_DLL_PLL_Tracking")
         {
             std::unique_ptr<TrackingInterface> block_ = std::make_unique<GpsL2MDllPllTracking>(configuration, role, in_streams,
@@ -1647,6 +1719,12 @@ std::unique_ptr<TelemetryDecoderInterface> GNSSBlockFactory::GetTlmBlock(
                 out_streams);
             block = std::move(block_);
         }
+    else if (implementation == "Galileo_E6_Telemetry_Decoder")
+        {
+            std::unique_ptr<TelemetryDecoderInterface> block_ = std::make_unique<GalileoE6TelemetryDecoder>(configuration, role, in_streams,
+                out_streams);
+            block = std::move(block_);
+        }
     else if (implementation == "GPS_L2C_Telemetry_Decoder")
         {
             std::unique_ptr<TelemetryDecoderInterface> block_ = std::make_unique<GpsL2CTelemetryDecoder>(configuration, role, in_streams,
