@@ -7,13 +7,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -35,6 +32,12 @@
 #include <utility>  // for pair
 #include <vector>   // for vector
 
+/** \addtogroup Core
+ * \{ */
+/** \addtogroup System_Parameters
+ * \{ */
+
+
 /*!
  * \brief This class decodes a GLONASS GNAV Data message as described in GLONASS ICD (Edition 5.1)
  * \note Code added as part of GSoC 2017 program
@@ -213,4 +216,7 @@ private:
     bool flag_TOW_new{};  // Flag indicating when a new TOW has been computed
 };
 
-#endif
+
+/** \} */
+/** \} */
+#endif  // GNSS_SDR_GLONASS_GNAV_NAVIGATION_MESSAGE_H
