@@ -3,39 +3,20 @@
  * \brief  Implementation of the Gnss_Satellite class
  * \author Carles Fernandez-Prades, 2012. cfernandez(at)cttc.es
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "gnss_satellite.h"
 #include <glog/logging.h>
-
-
-Gnss_Satellite::Gnss_Satellite()
-{
-    Gnss_Satellite::reset();
-}
+#include <utility>
 
 
 Gnss_Satellite::Gnss_Satellite(const std::string& system_, uint32_t PRN_)
@@ -47,17 +28,8 @@ Gnss_Satellite::Gnss_Satellite(const std::string& system_, uint32_t PRN_)
 }
 
 
-Gnss_Satellite::~Gnss_Satellite() = default;
-
-
 void Gnss_Satellite::reset()
 {
-    system_set = {"GPS", "Glonass", "SBAS", "Galileo", "Beidou"};
-    satelliteSystem["GPS"] = "G";
-    satelliteSystem["Glonass"] = "R";
-    satelliteSystem["SBAS"] = "S";
-    satelliteSystem["Galileo"] = "E";
-    satelliteSystem["Beidou"] = "C";
     PRN = 0;
     system = std::string("");
     block = std::string("");
@@ -69,8 +41,14 @@ std::ostream& operator<<(std::ostream& out, const Gnss_Satellite& sat)  // outpu
 {
     std::string tag;
     std::string tag2;
-    if (sat.get_system() == "Galileo") tag = "E";
-    if (sat.get_PRN() < 10) tag2 = "0";
+    if (sat.get_system() == "Galileo")
+        {
+            tag = "E";
+        }
+    if (sat.get_PRN() < 10)
+        {
+            tag2 = "0";
+        }
     out << sat.get_system() << " PRN " << tag << tag2 << sat.get_PRN() << " (Block " << sat.get_block() << ")";
     return out;
 }
@@ -83,29 +61,57 @@ bool operator==(const Gnss_Satellite& sat1, const Gnss_Satellite& sat2)
         {
             if (sat1.get_PRN() == sat2.get_PRN())
                 {
-                    equal = true;
+                    if (sat1.get_rf_link() == sat2.get_rf_link())
+                        {
+                            equal = true;
+                        }
                 }
         }
     return equal;
 }
 
-/*
-Gnss_Satellite& Gnss_Satellite::operator=(const Gnss_Satellite &rhs) {
 
+// Copy constructor
+Gnss_Satellite::Gnss_Satellite(const Gnss_Satellite& other) noexcept
+{
+    *this = other;
+}
+
+
+// Copy assignment operator
+Gnss_Satellite& Gnss_Satellite::operator=(const Gnss_Satellite& rhs)
+{
     // Only do assignment if RHS is a different object from this.
-    if (this != &rhs) {
-            // Deallocate, allocate new space, copy values...
-            const std::string system_ = rhs.get_system();
-            const uint32_t PRN_ = rhs.get_PRN();
-            const std::string block_ = rhs.get_block();
-           // const int32_t rf_link_ = 0;
-            this->set_system(system_);
-            this->set_PRN(PRN_);
-            this->set_block(system_, PRN_);
-            //this.rf_link = rf_link_;
-    }
+    if (this != &rhs)
+        {
+            this->system = rhs.system;
+            this->PRN = rhs.PRN;
+            this->block = rhs.block;
+            this->rf_link = rhs.rf_link;
+        }
     return *this;
-}*/
+}
+
+
+// Move constructor
+Gnss_Satellite::Gnss_Satellite(Gnss_Satellite&& other) noexcept
+{
+    *this = std::move(other);
+}
+
+
+// Move assignment operator
+Gnss_Satellite& Gnss_Satellite::operator=(Gnss_Satellite&& other) noexcept
+{
+    if (this != &other)
+        {
+            this->system = other.get_system();
+            this->PRN = other.get_PRN();
+            this->block = other.get_block();
+            this->rf_link = other.get_rf_link();
+        }
+    return *this;
+}
 
 
 void Gnss_Satellite::set_system(const std::string& system_)
@@ -182,30 +188,15 @@ void Gnss_Satellite::set_PRN(uint32_t PRN_)
         }
     else if (system == "SBAS")
         {
-            if (PRN_ == 120)
+            if ((PRN_ == 120)      // EGNOS Test Platform.Inmarsat 3-F2 (Atlantic Ocean Region-East)
+                || (PRN_ == 123)   // EGNOS Operational Platform. Astra 5B
+                || (PRN_ == 131)   // WAAS Eutelsat 117 West B
+                || (PRN_ == 135)   // WAAS Galaxy 15
+                || (PRN_ == 136)   // EGNOS Operational Platform. SES-5 (a.k.a. Sirius 5 or Astra 4B)
+                || (PRN_ == 138))  // WAAS Anik F1R
                 {
                     PRN = PRN_;
-                }  // EGNOS Test Platform.Inmarsat 3-F2 (Atlantic Ocean Region-East)
-            else if (PRN_ == 123)
-                {
-                    PRN = PRN_;
-                }  // EGNOS Operational Platform. Astra 5B
-            else if (PRN_ == 131)
-                {
-                    PRN = PRN_;
-                }  // WAAS Eutelsat 117 West B
-            else if (PRN_ == 135)
-                {
-                    PRN = PRN_;
-                }  // WAAS Galaxy 15
-            else if (PRN_ == 136)
-                {
-                    PRN = PRN_;
-                }  // EGNOS Operational Platform. SES-5 (a.k.a. Sirius 5 or Astra 4B)
-            else if (PRN_ == 138)
-                {
-                    PRN = PRN_;
-                }  // WAAS Anik F1R
+                }
             else
                 {
                     DLOG(INFO) << "This PRN is not defined";
@@ -224,6 +215,19 @@ void Gnss_Satellite::set_PRN(uint32_t PRN_)
                     PRN = PRN_;
                 }
         }
+    else if (system == "Beidou")
+        {
+            if (PRN_ < 1 or PRN_ > 63)
+                {
+                    DLOG(INFO) << "This PRN is not defined";
+                    PRN = 0;
+                }
+            else
+                {
+                    PRN = PRN_;
+                }
+        }
+
     else
         {
             DLOG(INFO) << "System " << system << " is not defined";
@@ -235,17 +239,22 @@ void Gnss_Satellite::set_PRN(uint32_t PRN_)
 int32_t Gnss_Satellite::get_rf_link() const
 {
     // Get satellite's rf link. Identifies the GLONASS Frequency Channel
-    int32_t rf_link_;
-    rf_link_ = rf_link;
+    int32_t rf_link_ = rf_link;
     return rf_link_;
 }
 
 
+void Gnss_Satellite::set_rf_link(int32_t rf_link_)
+{
+    // Set satellite's rf link. Identifies the GLONASS Frequency Channel
+    rf_link = rf_link_;
+}
+
+
 uint32_t Gnss_Satellite::get_PRN() const
 {
     // Get satellite's PRN
-    uint32_t PRN_;
-    PRN_ = PRN;
+    uint32_t PRN_ = PRN;
     return PRN_;
 }
 
@@ -253,8 +262,7 @@ uint32_t Gnss_Satellite::get_PRN() const
 std::string Gnss_Satellite::get_system() const
 {
     // Get the satellite system {"GPS", "Glonass", "SBAS", "Galileo", "Beidou"}
-    std::string system_;
-    system_ = system;
+    std::string system_ = system;
     return system_;
 }
 
@@ -269,8 +277,7 @@ std::string Gnss_Satellite::get_system_short() const
 std::string Gnss_Satellite::get_block() const
 {
     // Get the satellite block
-    std::string block_;
-    block_ = block;
+    std::string block_ = block;
     return block_;
 }
 
@@ -293,7 +300,7 @@ std::string Gnss_Satellite::what_block(const std::string& system_, uint32_t PRN_
                     block_ = std::string("IIF");  // Plane E
                     break;
                 case 4:
-                    block_ = std::string("Unknown");
+                    block_ = std::string("III");  // Plane A
                     break;
                 case 5:
                     block_ = std::string("IIR-M");  // Plane E
@@ -323,7 +330,7 @@ std::string Gnss_Satellite::what_block(const std::string& system_, uint32_t PRN_
                     block_ = std::string("IIR");  // Plane F
                     break;
                 case 14:
-                    block_ = std::string("IIR");  // Plane F
+                    block_ = std::string("Decommissioned");  // Plane F
                     break;
                 case 15:
                     block_ = std::string("IIR-M");  // Plane F
@@ -335,7 +342,7 @@ std::string Gnss_Satellite::what_block(const std::string& system_, uint32_t PRN_
                     block_ = std::string("IIR-M");  // Plane C
                     break;
                 case 18:
-                    block_ = std::string("IIR");  // Plane E
+                    block_ = std::string("III");  // Plane D
                     break;
                 case 19:
                     block_ = std::string("IIR");  // Plane D
@@ -350,7 +357,7 @@ std::string Gnss_Satellite::what_block(const std::string& system_, uint32_t PRN_
                     block_ = std::string("IIR");  // Plane E
                     break;
                 case 23:
-                    block_ = std::string("IIR");  // Plane F
+                    block_ = std::string("III");  // Plane E
                     break;
                 case 24:
                     block_ = std::string("IIF");  // Plane A
@@ -387,7 +394,7 @@ std::string Gnss_Satellite::what_block(const std::string& system_, uint32_t PRN_
     if (system_ == "Glonass")
         {
             // Info from http://www.sdcm.ru/smglo/grupglo?version=eng&site=extern
-            // See also http://www.glonass-center.ru/en/GLONASS/
+            // See also https://www.glonass-iac.ru/en/GLONASS/
             switch (PRN_)
                 {
                 case 1:
@@ -518,7 +525,7 @@ std::string Gnss_Satellite::what_block(const std::string& system_, uint32_t PRN_
         }
     if (system_ == "Galileo")
         {
-            // Check http://en.wikipedia.org/wiki/List_of_Galileo_satellites and https://www.gsc-europa.eu/system-status/Constellation-Information
+            // Check https://en.wikipedia.org/wiki/List_of_Galileo_satellites and https://www.gsc-europa.eu/system-status/Constellation-Information
             switch (PRN_)
                 {
                 case 1:
@@ -603,6 +610,153 @@ std::string Gnss_Satellite::what_block(const std::string& system_, uint32_t PRN_
                     block_ = std::string("Unknown(Simulated)");
                 }
         }
+    if (system_ == "Beidou")
+        {
+            // Check https://en.wikipedia.org/wiki/List_of_BeiDou_satellites
+            switch (PRN_)
+                {
+                case 1:
+                    block_ = std::string("BeiDou-2 GEO01*");  // GEO 140.0°E; launched 2010/01/16 (Retired)
+                    break;
+                case 2:
+                    block_ = std::string("BeiDou-2 GEO06");  // GEO 80°E; launched 2012/10/25
+                    break;
+                case 3:
+                    block_ = std::string("BeiDou-2 GEO07");  // GEO 110.5°E; launched 2016/06/12
+                    break;
+                case 4:
+                    block_ = std::string("BeiDou-2 GEO04");  // GEO 160.0°E; launched 2010/10/31
+                    break;
+                case 5:
+                    block_ = std::string("BeiDou-2 GEO05");  // GEO 58.75°E; launched 2012/02/24
+                    break;
+                case 6:
+                    block_ = std::string("BeiDou-2 IGSO01");  // 55° inclination IGSO 118°E; launched 2010/07/31
+                    break;
+                case 7:
+                    block_ = std::string("BeiDou-2 IGSO02");  // 55° inclination IGSO 118°E; launched 2010/12/17
+                    break;
+                case 8:
+                    block_ = std::string("BeiDou-2 IGSO03");  // 55° inclination IGSO 118°E; launched 2011/04/09
+                    break;
+                case 9:
+                    block_ = std::string("BeiDou-2 IGSO04");  // 55° inclination IGSO 95°E; launched 2011/07/27
+                    break;
+                case 10:
+                    block_ = std::string("BeiDou-2 IGSO05");  // 55° inclination IGSO 118°E; launched 2011/12/01
+                    break;
+                case 11:
+                    block_ = std::string("BeiDou-2 MEO03*");  // Slot A07; launched 2012/04/29 (Retired)
+                    break;
+                case 12:
+                    block_ = std::string("BeiDou-2 MEO04*");  // Slot A08; launched 2012/04/29 (Retired)
+                    break;
+                case 13:
+                    block_ = std::string("BeiDou-2 IGSO06");  // launched 2016/03/30
+                    break;
+                case 14:
+                    block_ = std::string("BeiDou-2 MEO06*");  // launched 2012/09/19 (Retired)
+                    break;
+                case 16:
+                    block_ = std::string("BeiDou-2 IGSO07");  // launched 2018/07/10
+                    break;
+                case 18:
+                    block_ = std::string("BeiDou-3 GEOG8");  // launched 2019/05/17
+                    break;
+                case 19:
+                    block_ = std::string("BeiDou-3 MEO01");  // Slot B07; launched 2017/11/05
+                    break;
+                case 20:
+                    block_ = std::string("BeiDou-3 MEO02");  // Slot B05; launched 2017/11/05
+                    break;
+                case 21:
+                    block_ = std::string("BeiDou-3 MEO03");  // Slot B0?; launched 2018/02/12
+                    break;
+                case 22:
+                    block_ = std::string("BeiDou-3 MEO04");  // Slot B06; launched 2018/02/12
+                    break;
+                case 23:
+                    block_ = std::string("BeiDou-3 MEO05");  // Slot C07; launched 2018/07/29
+                    break;
+                case 24:
+                    block_ = std::string("BeiDou-3 MEO06");  // Slot C01; launched 2018/07/29
+                    break;
+                case 25:
+                    block_ = std::string("BeiDou-3 MEO11");  // Slot C08; launched 2018/08/24
+                    break;
+                case 26:
+                    block_ = std::string("BeiDou-3 MEO12");  // Slot C02; launched 2018/08/24
+                    break;
+                case 27:
+                    block_ = std::string("BeiDou-3 3M3");  // Slot A04; launched 2018/01/11
+                    break;
+                case 28:
+                    block_ = std::string("BeiDou-3 3M4");  // Slot A05; launched 2018/01/11
+                    break;
+                case 29:
+                    block_ = std::string("BeiDou-3 3M7");  // Slot A02; launched 2018/03/29
+                    break;
+                case 30:
+                    block_ = std::string("BeiDou-3 3M8");  // Slot A03; launched 2018/03/29
+                    break;
+                case 32:
+                    block_ = std::string("BeiDou-3 MEO13");  // Slot B01; launched 2018/09/19
+                    break;
+                case 33:
+                    block_ = std::string("BeiDou-3 MEO14");  // Slot B03; launched 2018/09/19
+                    break;
+                case 34:
+                    block_ = std::string("BeiDou-3 MEO15");  // Slot B03; launched 2018/10/15
+                    break;
+                case 35:
+                    block_ = std::string("BeiDou-3 MEO16");  // Slot B03; launched 2018/10/15
+                    break;
+                case 36:
+                    block_ = std::string("BeiDou-3 MEO17");  // Slot B03; launched 2018/11/18
+                    break;
+                case 37:
+                    block_ = std::string("BeiDou-3 MEO18");  // Slot B03; launched 2018/11/18
+                    break;
+                case 38:
+                    block_ = std::string("BeiDou-3 IGSOI1");  // launched 2019/04/20
+                    break;
+                case 39:
+                    block_ = std::string("BeiDou-3 IGSOI2");  // launched 2019/04/20
+                    break;
+                case 40:
+                    block_ = std::string("BeiDou-3 IGSOI3");  // launched 2019/11/04
+                    break;
+                case 41:
+                    block_ = std::string("BeiDou-3 MEO19");  // Slot B02, launched 2019/12/16
+                    break;
+                case 42:
+                    block_ = std::string("BeiDou-3 MEO20");  // Slot B04, launched 2019/12/16
+                    break;
+                case 43:
+                    block_ = std::string("BeiDou-3 MEO21");  // Slot A06, launched 2019/11/23
+                    break;
+                case 44:
+                    block_ = std::string("BeiDou-3 MEO22");  // Slot A08, launched 2019/11/23
+                    break;
+                case 45:
+                    block_ = std::string("BeiDou-3 MEO23");  // Slot C03, launched 2019/09/22
+                    break;
+                case 46:
+                    block_ = std::string("BeiDou-3 MEO24");  // Slot C05, launched 2019/09/22
+                    break;
+                case 59:
+                    block_ = std::string("BeiDou-3 GEOG1");  // launched 2018/11/01
+                    break;
+                case 60:
+                    block_ = std::string("BeiDou-3 GEOG2");  // launched 2020/03/20
+                    break;
+                case 61:
+                    block_ = std::string("BeiDou-3 GEOG3");  // launched 2020/06/2023
+                    break;
+                default:
+                    block_ = std::string("Unknown(Simulated)");
+                }
+        }
     return block_;
 }
 
