@@ -3,29 +3,15 @@
  * \brief Implements Unit Test for the FirFilter class.
  * \author Luis Esteve, 2012. luis(at)epsilon-formacion.com
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include <gflags/gflags.h>
@@ -39,16 +25,17 @@
 #else
 #include <gnuradio/analog/sig_source_c.h>
 #endif
+#include "concurrent_queue.h"
 #include "file_signal_source.h"
 #include "fir_filter.h"
 #include "gnss_block_factory.h"
 #include "gnss_block_interface.h"
+#include "gnss_sdr_make_unique.h"
 #include "gnss_sdr_valve.h"
 #include "in_memory_configuration.h"
 #include "interleaved_byte_to_complex_byte.h"
 #include "interleaved_short_to_complex_short.h"
 #include <gnuradio/blocks/null_sink.h>
-#include <gnuradio/msg_queue.h>
 #include <gtest/gtest.h>
 
 
@@ -59,18 +46,18 @@ class FirFilterTest : public ::testing::Test
 protected:
     FirFilterTest()
     {
-        queue = gr::msg_queue::make(0);
+        queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
         item_size = sizeof(gr_complex);
         config = std::make_shared<InMemoryConfiguration>();
     }
-    ~FirFilterTest() = default;
+    ~FirFilterTest() override = default;
 
     void init();
     void configure_cbyte_cbyte();
     void configure_cbyte_gr_complex();
     void configure_gr_complex_gr_complex();
     void configure_cshort_cshort();
-    boost::shared_ptr<gr::msg_queue> queue;
+    std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue;
     gr::top_block_sptr top_block;
     std::shared_ptr<InMemoryConfiguration> config;
     size_t item_size;
@@ -99,7 +86,7 @@ void FirFilterTest::init()
 
     config->set_property("InputFilter.filter_type", "bandpass");
     config->set_property("InputFilter.grid_density", "16");
-    //config->set_property("InputFilter.dump", "true");
+    // config->set_property("InputFilter.dump", "true");
 }
 
 
@@ -135,19 +122,26 @@ TEST_F(FirFilterTest, InstantiateGrComplexGrComplex)
 {
     init();
     configure_gr_complex_gr_complex();
-    std::unique_ptr<FirFilter> filter(new FirFilter(config.get(), "InputFilter", 1, 1));
+    auto filter = std::make_unique<FirFilter>(config.get(), "InputFilter", 1, 1);
     int res = 0;
-    if (filter) res = 1;
+    if (filter)
+        {
+            res = 1;
+        }
     ASSERT_EQ(1, res);
 }
 
+
 TEST_F(FirFilterTest, InstantiateCshortCshort)
 {
     init();
     configure_cshort_cshort();
-    std::unique_ptr<FirFilter> filter(new FirFilter(config.get(), "InputFilter", 1, 1));
+    auto filter = std::make_unique<FirFilter>(config.get(), "InputFilter", 1, 1);
     int res = 0;
-    if (filter) res = 1;
+    if (filter)
+        {
+            res = 1;
+        }
     ASSERT_EQ(1, res);
 }
 
@@ -156,9 +150,12 @@ TEST_F(FirFilterTest, InstantiateCbyteCbyte)
 {
     init();
     configure_cbyte_cbyte();
-    std::unique_ptr<FirFilter> filter(new FirFilter(config.get(), "InputFilter", 1, 1));
+    auto filter = std::make_unique<FirFilter>(config.get(), "InputFilter", 1, 1);
     int res = 0;
-    if (filter) res = 1;
+    if (filter)
+        {
+            res = 1;
+        }
     ASSERT_EQ(1, res);
 }
 
@@ -167,9 +164,12 @@ TEST_F(FirFilterTest, InstantiateCbyteGrComplex)
 {
     init();
     configure_cbyte_gr_complex();
-    std::unique_ptr<FirFilter> filter(new FirFilter(config.get(), "InputFilter", 1, 1));
+    auto filter = std::make_unique<FirFilter>(config.get(), "InputFilter", 1, 1);
     int res = 0;
-    if (filter) res = 1;
+    if (filter)
+        {
+            res = 1;
+        }
     ASSERT_EQ(1, res);
 }
 
@@ -177,19 +177,20 @@ TEST_F(FirFilterTest, InstantiateCbyteGrComplex)
 TEST_F(FirFilterTest, ConnectAndRun)
 {
     int fs_in = 4000000;
-    std::chrono::time_point<std::chrono::system_clock> start, end;
+    std::chrono::time_point<std::chrono::system_clock> start;
+    std::chrono::time_point<std::chrono::system_clock> end;
     std::chrono::duration<double> elapsed_seconds(0);
     top_block = gr::make_top_block("Fir filter test");
 
     init();
     configure_gr_complex_gr_complex();
-    std::shared_ptr<FirFilter> filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
+    auto filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
     item_size = sizeof(gr_complex);
     ASSERT_NO_THROW({
         filter->connect(top_block);
-        boost::shared_ptr<gr::block> source = gr::analog::sig_source_c::make(fs_in, gr::analog::GR_SIN_WAVE, 1000, 1, gr_complex(0));
-        boost::shared_ptr<gr::block> valve = gnss_sdr_make_valve(sizeof(gr_complex), nsamples, queue);
-        boost::shared_ptr<gr::block> null_sink = gr::blocks::null_sink::make(item_size);
+        auto source = gr::analog::sig_source_c::make(fs_in, gr::analog::GR_SIN_WAVE, 1000, 1, gr_complex(0));
+        auto valve = gnss_sdr_make_valve(sizeof(gr_complex), nsamples, queue.get());
+        auto null_sink = gr::blocks::null_sink::make(item_size);
 
         top_block->connect(source, 0, valve, 0);
         top_block->connect(valve, 0, filter->get_left_block(), 0);
@@ -202,20 +203,21 @@ TEST_F(FirFilterTest, ConnectAndRun)
         end = std::chrono::system_clock::now();
         elapsed_seconds = end - start;
     }) << "Failure running the top_block.";
-    std::cout << "Filtered " << nsamples << " samples in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Filtered " << nsamples << " samples in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
 
 
 TEST_F(FirFilterTest, ConnectAndRunGrcomplex)
 {
-    std::chrono::time_point<std::chrono::system_clock> start, end;
+    std::chrono::time_point<std::chrono::system_clock> start;
+    std::chrono::time_point<std::chrono::system_clock> end;
     std::chrono::duration<double> elapsed_seconds(0);
     top_block = gr::make_top_block("Fir filter test");
 
     init();
     configure_gr_complex_gr_complex();
-    std::shared_ptr<FirFilter> filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
-    std::shared_ptr<InMemoryConfiguration> config2 = std::make_shared<InMemoryConfiguration>();
+    auto filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
+    auto config2 = std::make_shared<InMemoryConfiguration>();
 
     config2->set_property("Test_Source.samples", std::to_string(nsamples));
     config2->set_property("Test_Source.sampling_frequency", "4000000");
@@ -229,10 +231,10 @@ TEST_F(FirFilterTest, ConnectAndRunGrcomplex)
     ASSERT_NO_THROW({
         filter->connect(top_block);
 
-        boost::shared_ptr<FileSignalSource> source(new FileSignalSource(config2.get(), "Test_Source", 0, 1, queue));
+        auto source = std::make_shared<FileSignalSource>(config2.get(), "Test_Source", 0, 1, queue.get());
         source->connect(top_block);
 
-        boost::shared_ptr<gr::block> null_sink = gr::blocks::null_sink::make(item_size);
+        auto null_sink = gr::blocks::null_sink::make(item_size);
 
         top_block->connect(source->get_right_block(), 0, filter->get_left_block(), 0);
         top_block->connect(filter->get_right_block(), 0, null_sink, 0);
@@ -244,19 +246,21 @@ TEST_F(FirFilterTest, ConnectAndRunGrcomplex)
         end = std::chrono::system_clock::now();
         elapsed_seconds = end - start;
     }) << "Failure running the top_block.";
-    std::cout << "Filtered " << nsamples << " gr_complex samples in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Filtered " << nsamples << " gr_complex samples in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
 
+
 TEST_F(FirFilterTest, ConnectAndRunCshorts)
 {
-    std::chrono::time_point<std::chrono::system_clock> start, end;
+    std::chrono::time_point<std::chrono::system_clock> start;
+    std::chrono::time_point<std::chrono::system_clock> end;
     std::chrono::duration<double> elapsed_seconds(0);
     top_block = gr::make_top_block("Fir filter test");
 
     init();
     configure_cshort_cshort();
-    std::shared_ptr<FirFilter> filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
-    std::shared_ptr<InMemoryConfiguration> config2 = std::make_shared<InMemoryConfiguration>();
+    auto filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
+    auto config2 = std::make_shared<InMemoryConfiguration>();
 
     config2->set_property("Test_Source.samples", std::to_string(nsamples));
     config2->set_property("Test_Source.sampling_frequency", "4000000");
@@ -270,11 +274,11 @@ TEST_F(FirFilterTest, ConnectAndRunCshorts)
     ASSERT_NO_THROW({
         filter->connect(top_block);
 
-        boost::shared_ptr<FileSignalSource> source(new FileSignalSource(config2.get(), "Test_Source", 0, 1, queue));
+        auto source = std::make_shared<FileSignalSource>(config2.get(), "Test_Source", 0, 1, queue.get());
         source->connect(top_block);
 
         interleaved_short_to_complex_short_sptr ishort_to_cshort_ = make_interleaved_short_to_complex_short();
-        boost::shared_ptr<gr::block> null_sink = gr::blocks::null_sink::make(item_size);
+        auto null_sink = gr::blocks::null_sink::make(item_size);
 
         top_block->connect(source->get_right_block(), 0, ishort_to_cshort_, 0);
         top_block->connect(ishort_to_cshort_, 0, filter->get_left_block(), 0);
@@ -287,20 +291,21 @@ TEST_F(FirFilterTest, ConnectAndRunCshorts)
         end = std::chrono::system_clock::now();
         elapsed_seconds = end - start;
     }) << "Failure running the top_block.";
-    std::cout << "Filtered " << nsamples << " std::complex<int16_t> samples in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Filtered " << nsamples << " std::complex<int16_t> samples in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
 
 
 TEST_F(FirFilterTest, ConnectAndRunCbytes)
 {
-    std::chrono::time_point<std::chrono::system_clock> start, end;
+    std::chrono::time_point<std::chrono::system_clock> start;
+    std::chrono::time_point<std::chrono::system_clock> end;
     std::chrono::duration<double> elapsed_seconds(0);
     top_block = gr::make_top_block("Fir filter test");
 
     init();
     configure_cbyte_cbyte();
-    std::shared_ptr<FirFilter> filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
-    std::shared_ptr<InMemoryConfiguration> config2 = std::make_shared<InMemoryConfiguration>();
+    auto filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
+    auto config2 = std::make_shared<InMemoryConfiguration>();
 
     config2->set_property("Test_Source.samples", std::to_string(nsamples));
     config2->set_property("Test_Source.sampling_frequency", "4000000");
@@ -314,11 +319,11 @@ TEST_F(FirFilterTest, ConnectAndRunCbytes)
     ASSERT_NO_THROW({
         filter->connect(top_block);
 
-        boost::shared_ptr<FileSignalSource> source(new FileSignalSource(config2.get(), "Test_Source", 0, 1, queue));
+        auto source = std::make_shared<FileSignalSource>(config2.get(), "Test_Source", 0, 1, queue.get());
         source->connect(top_block);
 
         interleaved_byte_to_complex_byte_sptr ibyte_to_cbyte_ = make_interleaved_byte_to_complex_byte();
-        boost::shared_ptr<gr::block> null_sink = gr::blocks::null_sink::make(item_size);
+        auto null_sink = gr::blocks::null_sink::make(item_size);
 
         top_block->connect(source->get_right_block(), 0, ibyte_to_cbyte_, 0);
         top_block->connect(ibyte_to_cbyte_, 0, filter->get_left_block(), 0);
@@ -331,20 +336,21 @@ TEST_F(FirFilterTest, ConnectAndRunCbytes)
         end = std::chrono::system_clock::now();
         elapsed_seconds = end - start;
     }) << "Failure running the top_block.";
-    std::cout << "Filtered " << nsamples << " std::complex<int8_t> samples in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Filtered " << nsamples << " std::complex<int8_t> samples in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
 
 
 TEST_F(FirFilterTest, ConnectAndRunCbyteGrcomplex)
 {
-    std::chrono::time_point<std::chrono::system_clock> start, end;
+    std::chrono::time_point<std::chrono::system_clock> start;
+    std::chrono::time_point<std::chrono::system_clock> end;
     std::chrono::duration<double> elapsed_seconds(0);
     top_block = gr::make_top_block("Fir filter test");
 
     init();
     configure_cbyte_gr_complex();
-    std::shared_ptr<FirFilter> filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
-    std::shared_ptr<InMemoryConfiguration> config2 = std::make_shared<InMemoryConfiguration>();
+    auto filter = std::make_shared<FirFilter>(config.get(), "InputFilter", 1, 1);
+    auto config2 = std::make_shared<InMemoryConfiguration>();
 
     config2->set_property("Test_Source.samples", std::to_string(nsamples));
     config2->set_property("Test_Source.sampling_frequency", "4000000");
@@ -358,11 +364,11 @@ TEST_F(FirFilterTest, ConnectAndRunCbyteGrcomplex)
     ASSERT_NO_THROW({
         filter->connect(top_block);
 
-        boost::shared_ptr<FileSignalSource> source(new FileSignalSource(config2.get(), "Test_Source", 0, 1, queue));
+        auto source = std::make_shared<FileSignalSource>(config2.get(), "Test_Source", 0, 1, queue.get());
         source->connect(top_block);
 
         interleaved_byte_to_complex_byte_sptr ibyte_to_cbyte_ = make_interleaved_byte_to_complex_byte();
-        boost::shared_ptr<gr::block> null_sink = gr::blocks::null_sink::make(item_size);
+        auto null_sink = gr::blocks::null_sink::make(item_size);
 
         top_block->connect(source->get_right_block(), 0, ibyte_to_cbyte_, 0);
         top_block->connect(ibyte_to_cbyte_, 0, filter->get_left_block(), 0);
@@ -375,5 +381,5 @@ TEST_F(FirFilterTest, ConnectAndRunCbyteGrcomplex)
         end = std::chrono::system_clock::now();
         elapsed_seconds = end - start;
     }) << "Failure running the top_block.";
-    std::cout << "Filtered " << nsamples << " samples in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Filtered " << nsamples << " samples in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
