@@ -5,13 +5,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -23,6 +20,7 @@
 #include <chrono>
 #include <complex>
 #include <cstdint>
+#include <thread>
 #ifdef GR_GREATER_38
 #include <gnuradio/analog/sig_source.h>
 #else
@@ -54,6 +52,14 @@ protected:
     }
     ~NotchFilterTest() override = default;
 
+    bool stop = false;
+    std::thread ch_thread;
+    void start_queue();
+    void wait_message();
+    void process_message();
+    void stop_queue();
+    pmt::pmt_t message;
+
     void init();
     void configure_gr_complex_gr_complex();
     std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue;
@@ -64,6 +70,36 @@ protected:
 };
 
 
+void NotchFilterTest::start_queue()
+{
+    stop = false;
+    ch_thread = std::thread(&NotchFilterTest::wait_message, this);
+}
+
+
+void NotchFilterTest::wait_message()
+{
+    while (!stop)
+        {
+            queue->wait_and_pop(message);
+            process_message();
+        }
+}
+
+
+void NotchFilterTest::process_message()
+{
+    stop_queue();
+    top_block->stop();
+}
+
+
+void NotchFilterTest::stop_queue()
+{
+    stop = true;
+}
+
+
 void NotchFilterTest::init()
 {
     config->set_property("InputFilter.pfa", "0.01");
@@ -116,13 +152,14 @@ TEST_F(NotchFilterTest, ConnectAndRun)
         top_block->connect(valve, 0, filter->get_left_block(), 0);
         top_block->connect(filter->get_right_block(), 0, null_sink, 0);
     }) << "Failure connecting the top_block.";
-
+    start_queue();
     EXPECT_NO_THROW({
         start = std::chrono::system_clock::now();
         top_block->run();  // Start threads and wait
         end = std::chrono::system_clock::now();
         elapsed_seconds = end - start;
     }) << "Failure running the top_block.";
+    ch_thread.join();
     std::cout << "Filtered " << nsamples << " samples in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
 
@@ -158,12 +195,13 @@ TEST_F(NotchFilterTest, ConnectAndRunGrcomplex)
         top_block->connect(source->get_right_block(), 0, filter->get_left_block(), 0);
         top_block->connect(filter->get_right_block(), 0, null_sink, 0);
     }) << "Failure connecting the top_block.";
-
+    start_queue();
     EXPECT_NO_THROW({
         start = std::chrono::system_clock::now();
         top_block->run();  // Start threads and wait
         end = std::chrono::system_clock::now();
         elapsed_seconds = end - start;
     }) << "Failure running the top_block.";
+    ch_thread.join();
     std::cout << "Filtered " << nsamples << " gr_complex samples in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
