@@ -4,37 +4,24 @@
  * \author Carles Fernandez-Prades, 2015. cfernandez(at)cttc.es
  *
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2015  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <http://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
+
+#include "Galileo_INAV.h"
+#include "rtcm.h"
 #include <memory>
 #include <thread>
-#include "rtcm.h"
-#include "Galileo_E1.h"
 
-TEST(Rtcm_Test, Hex_to_bin)
+TEST(RtcmTest, HexToBin)
 {
     auto rtcm = std::make_shared<Rtcm>();
 
@@ -64,7 +51,7 @@ TEST(Rtcm_Test, Hex_to_bin)
 }
 
 
-TEST(Rtcm_Test, Bin_to_hex)
+TEST(RtcmTest, BinToHex)
 {
     auto rtcm = std::make_shared<Rtcm>();
 
@@ -98,33 +85,32 @@ TEST(Rtcm_Test, Bin_to_hex)
 }
 
 
-
-TEST(Rtcm_Test, Hex_to_int)
+TEST(RtcmTest, HexToInt)
 {
     auto rtcm = std::make_shared<Rtcm>();
 
     std::string test1 = "2A";
-    long int test1_int = rtcm->hex_to_int(test1);
-    long int expected1 = 42;
+    int64_t test1_int = rtcm->hex_to_int(test1);
+    int64_t expected1 = 42;
     EXPECT_EQ(expected1, test1_int);
 }
 
 
-TEST(Rtcm_Test, Hex_to_uint)
+TEST(RtcmTest, HexToUint)
 {
     auto rtcm = std::make_shared<Rtcm>();
-    long unsigned int expected1 = 42;
-    EXPECT_EQ(expected1,  rtcm->hex_to_uint(rtcm->bin_to_hex("00101010")));
+    uint64_t expected1 = 42;
+    EXPECT_EQ(expected1, rtcm->hex_to_uint(rtcm->bin_to_hex("00101010")));
 }
 
 
-TEST(Rtcm_Test, Bin_to_double)
+TEST(RtcmTest, BinToDouble)
 {
     auto rtcm = std::make_shared<Rtcm>();
 
     std::bitset<4> test1(5);
-    long int test1_int = static_cast<long int>(rtcm->bin_to_double(test1.to_string()));
-    long int expected1 = 5;
+    int64_t test1_int = static_cast<int64_t>(rtcm->bin_to_double(test1.to_string()));
+    int64_t expected1 = 5;
     EXPECT_EQ(expected1, test1_int);
 
     std::bitset<4> test2(-5);
@@ -135,33 +121,33 @@ TEST(Rtcm_Test, Bin_to_double)
 }
 
 
-TEST(Rtcm_Test, Bin_to_uint)
+TEST(RtcmTest, BinToUint)
 {
     auto rtcm = std::make_shared<Rtcm>();
-    long unsigned int expected1 = 42;
+    uint32_t expected1 = 42;
     EXPECT_EQ(expected1, rtcm->bin_to_uint("00101010"));
-    long unsigned int expected2 = 214;
+    uint32_t expected2 = 214;
     EXPECT_EQ(expected2, rtcm->bin_to_uint("11010110"));
 }
 
 
-TEST(Rtcm_Test, Bin_to_int)
+TEST(RtcmTest, BinToInt)
 {
     auto rtcm = std::make_shared<Rtcm>();
-    long unsigned int expected1 = 42;
+    int32_t expected1 = 42;
     EXPECT_EQ(expected1, rtcm->bin_to_int("00101010"));
-    long unsigned int expected2 = -42;
+    int32_t expected2 = -42;
     EXPECT_EQ(expected2, rtcm->bin_to_int("11010110"));
 }
 
 
-TEST(Rtcm_Test, Bin_to_binary_data)
+TEST(RtcmTest, BinToBinaryData)
 {
     auto rtcm = std::make_shared<Rtcm>();
     std::string bin_str("1101101011010110");
     std::string data_str = rtcm->bin_to_binary_data(bin_str);
 
-    std::string test_binary = data_str.substr(0,1);
+    std::string test_binary = data_str.substr(0, 1);
     std::string test_bin = rtcm->binary_data_to_bin(test_binary);
     std::string test_hex = rtcm->bin_to_hex(test_bin);
     EXPECT_EQ(0, test_hex.compare("DA"));
@@ -171,7 +157,7 @@ TEST(Rtcm_Test, Bin_to_binary_data)
 }
 
 
-TEST(Rtcm_Test, Check_CRC)
+TEST(RtcmTest, CheckCRC)
 {
     auto rtcm = std::make_shared<Rtcm>();
     bool expected_true = true;
@@ -186,7 +172,7 @@ TEST(Rtcm_Test, Check_CRC)
 }
 
 
-TEST(Rtcm_Test, MT1001)
+TEST(RtcmTest, MT1001)
 {
     auto rtcm = std::make_shared<Rtcm>();
     Gps_Ephemeris gps_eph = Gps_Ephemeris();
@@ -198,7 +184,7 @@ TEST(Rtcm_Test, MT1001)
 
     std::string sig = "1C";
     gnss_synchro.System = *sys.c_str();
-    std::memcpy((void*)gnss_synchro.Signal, sig.c_str(), 3);
+    std::memcpy(static_cast<void*>(gnss_synchro.Signal), sig.c_str(), 3);
     gnss_synchro.Pseudorange_m = 20000000.0;
     double obs_time = 25.0;
     std::map<int, Gnss_Synchro> pseudoranges;
@@ -209,7 +195,7 @@ TEST(Rtcm_Test, MT1001)
 }
 
 
-TEST(Rtcm_Test, MT1005)
+TEST(RtcmTest, MT1005)
 {
     auto rtcm = std::make_shared<Rtcm>();
     std::string reference_msg = rtcm->print_MT1005_test();
@@ -232,7 +218,7 @@ TEST(Rtcm_Test, MT1005)
     EXPECT_EQ(expected_false, glonass);
     EXPECT_EQ(expected_false, galileo);
 
-    EXPECT_EQ(2003, ref_id);
+    EXPECT_EQ(static_cast<unsigned int>(2003), ref_id);
     EXPECT_DOUBLE_EQ(1114104.5999, ecef_x);
     EXPECT_DOUBLE_EQ(-4850729.7108, ecef_y);
     EXPECT_DOUBLE_EQ(3975521.4643, ecef_z);
@@ -246,15 +232,14 @@ TEST(Rtcm_Test, MT1005)
     EXPECT_EQ(expected_false, glonass);
     EXPECT_EQ(expected_false, galileo);
 
-    EXPECT_EQ(2003, ref_id);
+    EXPECT_EQ(static_cast<unsigned int>(2003), ref_id);
     EXPECT_DOUBLE_EQ(1114104.5999, ecef_x);
     EXPECT_DOUBLE_EQ(-4850729.7108, ecef_y);
     EXPECT_DOUBLE_EQ(3975521.4643, ecef_z);
 }
 
 
-
-TEST(Rtcm_Test, MT1019)
+TEST(RtcmTest, MT1019)
 {
     auto rtcm = std::make_shared<Rtcm>();
     bool expected_true = true;
@@ -264,27 +249,61 @@ TEST(Rtcm_Test, MT1019)
 
     gps_eph.i_satellite_PRN = 3;
     gps_eph.d_IODC = 4;
-    gps_eph.d_e_eccentricity = 2.0 * E_LSB;
+    gps_eph.d_e_eccentricity = 2.0 * ECCENTRICITY_LSB;
     gps_eph.b_fit_interval_flag = true;
     std::string tx_msg = rtcm->print_MT1019(gps_eph);
 
     EXPECT_EQ(0, rtcm->read_MT1019(tx_msg, gps_eph_read));
-    EXPECT_EQ(3, gps_eph_read.i_satellite_PRN);
+    EXPECT_EQ(static_cast<unsigned int>(3), gps_eph_read.i_satellite_PRN);
     EXPECT_DOUBLE_EQ(4, gps_eph_read.d_IODC);
-    EXPECT_DOUBLE_EQ( 2.0 * E_LSB, gps_eph_read.d_e_eccentricity);
+    EXPECT_DOUBLE_EQ(2.0 * ECCENTRICITY_LSB, gps_eph_read.d_e_eccentricity);
     EXPECT_EQ(expected_true, gps_eph_read.b_fit_interval_flag);
     EXPECT_EQ(1, rtcm->read_MT1019(rtcm->bin_to_binary_data(rtcm->hex_to_bin("FFFFFFFFFFF")), gps_eph_read));
 }
 
 
-TEST(Rtcm_Test, MT1029)
+TEST(RtcmTest, MT1020)
+{
+    auto rtcm = std::make_shared<Rtcm>();
+
+    // Objects to populate the ephemeris and utc fields
+    Glonass_Gnav_Ephemeris gnav_ephemeris = Glonass_Gnav_Ephemeris();
+    Glonass_Gnav_Utc_Model gnav_utc_model = Glonass_Gnav_Utc_Model();
+    // Objects read, used for comparison
+    Glonass_Gnav_Ephemeris gnav_ephemeris_read = Glonass_Gnav_Ephemeris();
+    Glonass_Gnav_Utc_Model gnav_utc_model_read = Glonass_Gnav_Utc_Model();
+
+    // Perform data read and print of special values types
+    gnav_ephemeris.d_P_1 = 15;
+    // Bit distribution per fields
+    gnav_ephemeris.d_t_k = 7560;
+    // Glonass signed values
+    gnav_ephemeris.d_VXn = -0.490900039672852;
+    // Bit distribution per fields dependent on other factors
+    gnav_ephemeris.d_t_b = 8100;
+    // Binary flag representation
+    gnav_ephemeris.d_P_3 = true;
+
+    std::string tx_msg = rtcm->print_MT1020(gnav_ephemeris, gnav_utc_model);
+
+    EXPECT_EQ(0, rtcm->read_MT1020(tx_msg, gnav_ephemeris_read, gnav_utc_model_read));
+    EXPECT_EQ(gnav_ephemeris.d_P_1, gnav_ephemeris_read.d_P_1);
+    EXPECT_TRUE(gnav_ephemeris.d_t_b - gnav_ephemeris_read.d_t_b < FLT_EPSILON);
+    EXPECT_TRUE(gnav_ephemeris.d_VXn - gnav_ephemeris_read.d_VXn < FLT_EPSILON);
+    EXPECT_TRUE(gnav_ephemeris.d_t_k - gnav_ephemeris.d_t_k < FLT_EPSILON);
+    EXPECT_EQ(gnav_ephemeris.d_P_3, gnav_ephemeris_read.d_P_3);
+    EXPECT_EQ(1, rtcm->read_MT1020(rtcm->bin_to_binary_data(rtcm->hex_to_bin("FFFFFFFFFFF")), gnav_ephemeris_read, gnav_utc_model_read));
+}
+
+
+TEST(RtcmTest, MT1029)
 {
     auto rtcm = std::make_shared<Rtcm>();
     std::string s_test("UTF-8 проверка wörter");
     unsigned int ref_id = 23;
     double obs_time = 0;
     Gps_Ephemeris gps_eph = Gps_Ephemeris();
-    std::string m1029 = rtcm->bin_to_hex(rtcm->binary_data_to_bin(rtcm->print_MT1029(ref_id, gps_eph,  obs_time, s_test)));
+    std::string m1029 = rtcm->bin_to_hex(rtcm->binary_data_to_bin(rtcm->print_MT1029(ref_id, gps_eph, obs_time, s_test)));
     std::string encoded_text = m1029.substr(24, 60);
     std::string expected_encoded_text("5554462D3820D0BFD180D0BED0B2D0B5D180D0BAD0B02077C3B672746572");
     EXPECT_EQ(0, expected_encoded_text.compare(encoded_text));
@@ -295,7 +314,7 @@ TEST(Rtcm_Test, MT1029)
 }
 
 
-TEST(Rtcm_Test, MT1045)
+TEST(RtcmTest, MT1045)
 {
     auto rtcm = std::make_shared<Rtcm>();
     bool expected_true = true;
@@ -304,24 +323,25 @@ TEST(Rtcm_Test, MT1045)
     Galileo_Ephemeris gal_eph_read = Galileo_Ephemeris();
 
     gal_eph.i_satellite_PRN = 5;
-    gal_eph.OMEGA_dot_3 = 53.0 * OMEGA_dot_3_LSB;
+    gal_eph.OMEGA_dot_3 = 53.0 * OMEGA_DOT_3_LSB;
     gal_eph.E5a_DVS = true;
 
     std::string tx_msg = rtcm->print_MT1045(gal_eph);
 
     EXPECT_EQ(0, rtcm->read_MT1045(tx_msg, gal_eph_read));
     EXPECT_EQ(expected_true, gal_eph_read.E5a_DVS);
-    EXPECT_DOUBLE_EQ( 53.0 * OMEGA_dot_3_LSB, gal_eph_read.OMEGA_dot_3);
-    EXPECT_EQ(5, gal_eph_read.i_satellite_PRN);
+    EXPECT_DOUBLE_EQ(53.0 * OMEGA_DOT_3_LSB, gal_eph_read.OMEGA_dot_3);
+    EXPECT_EQ(static_cast<unsigned int>(5), gal_eph_read.i_satellite_PRN);
     EXPECT_EQ(1, rtcm->read_MT1045(rtcm->bin_to_binary_data(rtcm->hex_to_bin("FFFFFFFFFFF")), gal_eph_read));
 }
 
 
-TEST(Rtcm_Test, MSMCell)
+TEST(RtcmTest, MSMCell)
 {
     auto rtcm = std::make_shared<Rtcm>();
     Gps_Ephemeris gps_eph = Gps_Ephemeris();
     Galileo_Ephemeris gal_eph = Galileo_Ephemeris();
+    // Glonass_Gnav_Ephemeris glo_gnav_eph = Glonass_Gnav_Ephemeris();
     std::map<int, Gnss_Synchro> pseudoranges;
 
     Gnss_Synchro gnss_synchro;
@@ -329,15 +349,18 @@ TEST(Rtcm_Test, MSMCell)
     Gnss_Synchro gnss_synchro3;
     Gnss_Synchro gnss_synchro4;
     Gnss_Synchro gnss_synchro5;
+    Gnss_Synchro gnss_synchro6;
 
     gnss_synchro.PRN = 4;
     gnss_synchro2.PRN = 8;
     gnss_synchro3.PRN = 32;
     gnss_synchro4.PRN = 10;
     gnss_synchro5.PRN = 10;
+    gnss_synchro6.PRN = 10;
 
     std::string gps = "G";
     std::string gal = "E";
+    std::string glo = "R";
 
     std::string c1 = "1C";
     std::string s2 = "2S";
@@ -348,24 +371,28 @@ TEST(Rtcm_Test, MSMCell)
     gnss_synchro3.System = *gps.c_str();
     gnss_synchro4.System = *gal.c_str();
     gnss_synchro5.System = *gps.c_str();
+    gnss_synchro6.System = *glo.c_str();
 
-    std::memcpy((void*)gnss_synchro.Signal, x5.c_str(), 3);
-    std::memcpy((void*)gnss_synchro2.Signal, s2.c_str(), 3);
-    std::memcpy((void*)gnss_synchro3.Signal, c1.c_str(), 3);
-    std::memcpy((void*)gnss_synchro4.Signal, x5.c_str(), 3);
-    std::memcpy((void*)gnss_synchro5.Signal, c1.c_str(), 3);
+    std::memcpy(reinterpret_cast<void*>(gnss_synchro.Signal), x5.c_str(), 3);
+    std::memcpy(reinterpret_cast<void*>(gnss_synchro2.Signal), s2.c_str(), 3);
+    std::memcpy(reinterpret_cast<void*>(gnss_synchro3.Signal), c1.c_str(), 3);
+    std::memcpy(reinterpret_cast<void*>(gnss_synchro4.Signal), x5.c_str(), 3);
+    std::memcpy(reinterpret_cast<void*>(gnss_synchro5.Signal), c1.c_str(), 3);
+    std::memcpy(reinterpret_cast<void*>(gnss_synchro6.Signal), c1.c_str(), 3);
 
     gnss_synchro.Pseudorange_m = 20000000.0;
     gnss_synchro2.Pseudorange_m = 20001010.0;
     gnss_synchro3.Pseudorange_m = 24002020.0;
     gnss_synchro4.Pseudorange_m = 20003010.1;
     gnss_synchro5.Pseudorange_m = 22003010.1;
+    gnss_synchro6.Pseudorange_m = 22003010.1;
 
     pseudoranges.insert(std::pair<int, Gnss_Synchro>(1, gnss_synchro));
     pseudoranges.insert(std::pair<int, Gnss_Synchro>(2, gnss_synchro2));
     pseudoranges.insert(std::pair<int, Gnss_Synchro>(3, gnss_synchro3));
     pseudoranges.insert(std::pair<int, Gnss_Synchro>(4, gnss_synchro4));
     pseudoranges.insert(std::pair<int, Gnss_Synchro>(5, gnss_synchro5));
+    pseudoranges.insert(std::pair<int, Gnss_Synchro>(6, gnss_synchro5));
 
     unsigned int ref_id = 1234;
     unsigned int clock_steering_indicator = 0;
@@ -377,76 +404,82 @@ TEST(Rtcm_Test, MSMCell)
 
     gps_eph.i_satellite_PRN = gnss_synchro2.PRN;
     gal_eph.i_satellite_PRN = gnss_synchro.PRN;
+    // glo_gnav_eph.i_satellite_PRN = gnss_synchro.PRN;
 
     std::string MSM1 = rtcm->print_MSM_1(gps_eph,
-            {},
-            gal_eph,
-            obs_time,
-            pseudoranges,
-            ref_id,
-            clock_steering_indicator,
-            external_clock_indicator,
-            smooth_int,
-            divergence_free,
-            more_messages);
+        {},
+        gal_eph,
+        {},
+        obs_time,
+        pseudoranges,
+        ref_id,
+        clock_steering_indicator,
+        external_clock_indicator,
+        smooth_int,
+        divergence_free,
+        more_messages);
 
     std::string MSM1_bin = rtcm->binary_data_to_bin(MSM1);
     unsigned int Nsat = 4;
     unsigned int Nsig = 3;
     unsigned int size_header = 14;
     unsigned int size_msg_length = 10;
-    EXPECT_EQ(0, MSM1_bin.substr(size_header + size_msg_length + 169, Nsat * Nsig).compare("001010101100")); // check cell mask
+    EXPECT_EQ(0, MSM1_bin.substr(size_header + size_msg_length + 169, Nsat * Nsig).compare("001010101100"));  // check cell mask
 
     std::map<int, Gnss_Synchro> pseudoranges2;
+    pseudoranges2.insert(std::pair<int, Gnss_Synchro>(1, gnss_synchro6));
     pseudoranges2.insert(std::pair<int, Gnss_Synchro>(1, gnss_synchro5));
     pseudoranges2.insert(std::pair<int, Gnss_Synchro>(2, gnss_synchro4));
     pseudoranges2.insert(std::pair<int, Gnss_Synchro>(3, gnss_synchro3));
     pseudoranges2.insert(std::pair<int, Gnss_Synchro>(4, gnss_synchro2));
     pseudoranges2.insert(std::pair<int, Gnss_Synchro>(5, gnss_synchro));
+    pseudoranges2.insert(std::pair<int, Gnss_Synchro>(6, gnss_synchro));
     std::string MSM1_2 = rtcm->print_MSM_1(gps_eph,
-             {},
-             gal_eph,
-             obs_time,
-             pseudoranges2,
-             ref_id,
-             clock_steering_indicator,
-             external_clock_indicator,
-             smooth_int,
-             divergence_free,
-             more_messages);
+        {},
+        gal_eph,
+        {},
+        obs_time,
+        pseudoranges2,
+        ref_id,
+        clock_steering_indicator,
+        external_clock_indicator,
+        smooth_int,
+        divergence_free,
+        more_messages);
     std::string MSM1_bin_2 = rtcm->binary_data_to_bin(MSM1_2);
-    EXPECT_EQ(0, MSM1_bin_2.substr(size_header + size_msg_length + 169, Nsat * Nsig).compare("001010101100")); // check cell mask
+    EXPECT_EQ(0, MSM1_bin_2.substr(size_header + size_msg_length + 169, Nsat * Nsig).compare("001010001100"));  // check cell mask
 
-    Gnss_Synchro gnss_synchro6;
-    gnss_synchro6.PRN = 10;
-    gnss_synchro6.System = *gps.c_str();
-    std::memcpy((void*)gnss_synchro6.Signal, s2.c_str(), 3);
-    gnss_synchro6.Pseudorange_m = 24000000.0;
+    Gnss_Synchro gnss_synchro7;
+    gnss_synchro7.PRN = 10;
+    gnss_synchro7.System = *gps.c_str();
+    std::memcpy(reinterpret_cast<void*>(gnss_synchro7.Signal), s2.c_str(), 3);
+    gnss_synchro7.Pseudorange_m = 24000000.0;
 
     std::map<int, Gnss_Synchro> pseudoranges3;
     pseudoranges3.insert(std::pair<int, Gnss_Synchro>(1, gnss_synchro));
     pseudoranges3.insert(std::pair<int, Gnss_Synchro>(2, gnss_synchro2));
-    pseudoranges3.insert(std::pair<int, Gnss_Synchro>(3, gnss_synchro6));
+    pseudoranges3.insert(std::pair<int, Gnss_Synchro>(3, gnss_synchro7));
     pseudoranges3.insert(std::pair<int, Gnss_Synchro>(4, gnss_synchro4));
     pseudoranges3.insert(std::pair<int, Gnss_Synchro>(5, gnss_synchro5));
 
     std::string MSM1_3 = rtcm->print_MSM_1(gps_eph,
-                {},
-                gal_eph,
-                obs_time,
-                pseudoranges3,
-                ref_id,
-                clock_steering_indicator,
-                external_clock_indicator,
-                smooth_int,
-                divergence_free,
-                more_messages);
+        {},
+        gal_eph,
+        {},
+        obs_time,
+        pseudoranges3,
+        ref_id,
+        clock_steering_indicator,
+        external_clock_indicator,
+        smooth_int,
+        divergence_free,
+        more_messages);
     std::string MSM1_bin_3 = rtcm->binary_data_to_bin(MSM1_3);
-    EXPECT_EQ(0, MSM1_bin_3.substr(size_header + size_msg_length + 169, (Nsat-1) * Nsig).compare("001010111")); // check cell mask
+    EXPECT_EQ(0, MSM1_bin_3.substr(size_header + size_msg_length + 169, (Nsat - 1) * Nsig).compare("001010111"));  // check cell mask
 }
 
 
-TEST(Rtcm_Test, MSM1)
+TEST(RtcmTest, MSM1)
 {
     auto rtcm = std::make_shared<Rtcm>();
     bool expected_true = true;
@@ -473,10 +506,10 @@ TEST(Rtcm_Test, MSM1)
     gnss_synchro3.System = *sys.c_str();
     gnss_synchro4.System = *sys.c_str();
 
-    std::memcpy((void*)gnss_synchro.Signal, sig.c_str(), 3);
-    std::memcpy((void*)gnss_synchro2.Signal, sig.c_str(), 3);
-    std::memcpy((void*)gnss_synchro3.Signal, sig2.c_str(), 3);
-    std::memcpy((void*)gnss_synchro4.Signal, sig2.c_str(), 3);
+    std::memcpy(static_cast<void*>(gnss_synchro.Signal), sig.c_str(), 3);
+    std::memcpy(static_cast<void*>(gnss_synchro2.Signal), sig.c_str(), 3);
+    std::memcpy(static_cast<void*>(gnss_synchro3.Signal), sig2.c_str(), 3);
+    std::memcpy(static_cast<void*>(gnss_synchro4.Signal), sig2.c_str(), 3);
 
     gnss_synchro.Pseudorange_m = 20000000.0;
     gnss_synchro2.Pseudorange_m = 20001010.0;
@@ -499,15 +532,15 @@ TEST(Rtcm_Test, MSM1)
     gps_eph.i_satellite_PRN = gnss_synchro.PRN;
 
     std::string MSM1 = rtcm->print_MSM_1(gps_eph,
-            {}, {},
-            obs_time,
-            pseudoranges,
-            ref_id,
-            clock_steering_indicator,
-            external_clock_indicator,
-            smooth_int,
-            divergence_free,
-            more_messages);
+        {}, {}, {},
+        obs_time,
+        pseudoranges,
+        ref_id,
+        clock_steering_indicator,
+        external_clock_indicator,
+        smooth_int,
+        divergence_free,
+        more_messages);
 
     EXPECT_EQ(expected_true, rtcm->check_CRC(MSM1));
 
@@ -521,23 +554,23 @@ TEST(Rtcm_Test, MSM1)
     unsigned int data_size = MSM1_bin.length() - size_header - size_msg_length - size_crc;
     EXPECT_EQ(expected_true, upper_bound >= data_size);
     EXPECT_EQ(0, MSM1_bin.substr(0, size_header).compare("11010011000000"));
-    EXPECT_EQ(ref_id, rtcm->bin_to_uint( MSM1_bin.substr(size_header + size_msg_length + 12, 12)));
-    EXPECT_EQ(0, MSM1_bin.substr(size_header + size_msg_length + 169, Nsat * Nsig).compare("101101")); // check cell mask
+    EXPECT_EQ(ref_id, rtcm->bin_to_uint(MSM1_bin.substr(size_header + size_msg_length + 12, 12)));
+    EXPECT_EQ(0, MSM1_bin.substr(size_header + size_msg_length + 169, Nsat * Nsig).compare("101101"));  // check cell mask
 
-    double meters_to_miliseconds = GPS_C_m_s * 0.001;
+    double meters_to_miliseconds = SPEED_OF_LIGHT_M_S * 0.001;
     unsigned int rough_range_1 = static_cast<unsigned int>(std::floor(std::round(gnss_synchro.Pseudorange_m / meters_to_miliseconds / TWO_N10)) + 0.5) & 0x3FFu;
     unsigned int rough_range_2 = static_cast<unsigned int>(std::floor(std::round(gnss_synchro2.Pseudorange_m / meters_to_miliseconds / TWO_N10)) + 0.5) & 0x3FFu;
     unsigned int rough_range_4 = static_cast<unsigned int>(std::floor(std::round(gnss_synchro3.Pseudorange_m / meters_to_miliseconds / TWO_N10)) + 0.5) & 0x3FFu;
-    unsigned int read_pseudorange_1 = rtcm->bin_to_uint( MSM1_bin.substr(size_header + size_msg_length + 169 + Nsat * Nsig , 10));
-    unsigned int read_pseudorange_2 = rtcm->bin_to_uint( MSM1_bin.substr(size_header + size_msg_length + 169 + Nsat * Nsig + 10, 10));
-    unsigned int read_pseudorange_4 = rtcm->bin_to_uint( MSM1_bin.substr(size_header + size_msg_length + 169 + Nsat * Nsig + 20, 10));
+    unsigned int read_pseudorange_1 = rtcm->bin_to_uint(MSM1_bin.substr(size_header + size_msg_length + 169 + Nsat * Nsig, 10));
+    unsigned int read_pseudorange_2 = rtcm->bin_to_uint(MSM1_bin.substr(size_header + size_msg_length + 169 + Nsat * Nsig + 10, 10));
+    unsigned int read_pseudorange_4 = rtcm->bin_to_uint(MSM1_bin.substr(size_header + size_msg_length + 169 + Nsat * Nsig + 20, 10));
 
     EXPECT_EQ(rough_range_1, read_pseudorange_1);
     EXPECT_EQ(rough_range_2, read_pseudorange_2);
     EXPECT_EQ(rough_range_4, read_pseudorange_4);
 
-    int psrng4_s = static_cast<int>(std::round( (gnss_synchro3.Pseudorange_m  - std::round(gnss_synchro3.Pseudorange_m / meters_to_miliseconds / TWO_N10) * meters_to_miliseconds * TWO_N10)/ meters_to_miliseconds / TWO_N24));
-    int read_psrng4_s = rtcm->bin_to_int( MSM1_bin.substr(size_header + size_msg_length + 169 + (Nsat * Nsig) + 30 + 15 * 3, 15));
+    int psrng4_s = static_cast<int>(std::round((gnss_synchro3.Pseudorange_m - std::round(gnss_synchro3.Pseudorange_m / meters_to_miliseconds / TWO_N10) * meters_to_miliseconds * TWO_N10) / meters_to_miliseconds / TWO_N24));
+    int read_psrng4_s = rtcm->bin_to_int(MSM1_bin.substr(size_header + size_msg_length + 169 + (Nsat * Nsig) + 30 + 15 * 3, 15));
     EXPECT_EQ(psrng4_s, read_psrng4_s);
 
     std::map<int, Gnss_Synchro> pseudoranges2;
@@ -546,22 +579,22 @@ TEST(Rtcm_Test, MSM1)
     pseudoranges2.insert(std::pair<int, Gnss_Synchro>(3, gnss_synchro2));
     pseudoranges2.insert(std::pair<int, Gnss_Synchro>(4, gnss_synchro));
     std::string MSM1_2 = rtcm->print_MSM_1(gps_eph,
-            {}, {},
-            obs_time,
-            pseudoranges2,
-            ref_id,
-            clock_steering_indicator,
-            external_clock_indicator,
-            smooth_int,
-            divergence_free,
-            more_messages);
+        {}, {}, {},
+        obs_time,
+        pseudoranges2,
+        ref_id,
+        clock_steering_indicator,
+        external_clock_indicator,
+        smooth_int,
+        divergence_free,
+        more_messages);
     std::string MSM1_bin2 = rtcm->binary_data_to_bin(MSM1_2);
-    int read_psrng4_s_2 = rtcm->bin_to_int( MSM1_bin2.substr(size_header + size_msg_length + 169 + (Nsat * Nsig) + 30 + 15 * 3, 15));
+    int read_psrng4_s_2 = rtcm->bin_to_int(MSM1_bin2.substr(size_header + size_msg_length + 169 + (Nsat * Nsig) + 30 + 15 * 3, 15));
     EXPECT_EQ(psrng4_s, read_psrng4_s_2);
 }
 
 
-TEST(Rtcm_Test, InstantiateServer)
+TEST(RtcmTest, InstantiateServer)
 {
     auto rtcm = std::make_shared<Rtcm>();
     rtcm->run_server();
@@ -574,7 +607,7 @@ TEST(Rtcm_Test, InstantiateServer)
     std::string test6 = "0011";
     std::string test6_hex = rtcm->bin_to_hex(test6);
     EXPECT_EQ(0, test6_hex.compare("3"));
-    long unsigned int expected1 = 42;
+    uint64_t expected1 = 42;
     EXPECT_EQ(expected1, rtcm->bin_to_uint("00101010"));
     rtcm->run_server();
     std::string test4_bin = rtcm->hex_to_bin(test3);
@@ -585,7 +618,7 @@ TEST(Rtcm_Test, InstantiateServer)
 }
 
 
-TEST(Rtcm_Test, InstantiateServerWithoutClosing)
+TEST(RtcmTest, InstantiateServerWithoutClosing)
 {
     auto rtcm = std::make_shared<Rtcm>();
     rtcm->run_server();
@@ -595,7 +628,3 @@ TEST(Rtcm_Test, InstantiateServerWithoutClosing)
     std::string test3_bin = rtcm->hex_to_bin(test3);
     EXPECT_EQ(0, test3_bin.compare("11111111"));
 }
-
-
-
-
