@@ -4,18 +4,15 @@
  * \author Carles Fernandez-Prades 2018 cfernandez (at) cttc.cat
  *
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include <gnuradio/analog/sig_source_waveform.h>
@@ -38,10 +35,10 @@ TEST(MmseResamplerTest, InstantiationAndRunTestWarning)
     std::chrono::time_point<std::chrono::system_clock> start, end;
     std::chrono::duration<double> elapsed_seconds(0);
     int nsamples = 1000000;  // Number of samples to be computed
-    std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
-    gr::top_block_sptr top_block = gr::make_top_block("mmse_resampler_conditioner_cc_test");
-    boost::shared_ptr<gr::analog::sig_source_c> source = gr::analog::sig_source_c::make(fs_in, gr::analog::GR_SIN_WAVE, 1000.0, 1.0, gr_complex(0.0));
-    boost::shared_ptr<gr::block> valve = gnss_sdr_make_valve(sizeof(gr_complex), nsamples, queue);
+    auto queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
+    auto top_block = gr::make_top_block("mmse_resampler_conditioner_cc_test");
+    auto source = gr::analog::sig_source_c::make(fs_in, gr::analog::GR_SIN_WAVE, 1000.0, 1.0, gr_complex(0.0));
+    auto valve = gnss_sdr_make_valve(sizeof(gr_complex), nsamples, queue.get());
 
     std::shared_ptr<InMemoryConfiguration> config;
     config = std::make_shared<InMemoryConfiguration>();
@@ -49,9 +46,9 @@ TEST(MmseResamplerTest, InstantiationAndRunTestWarning)
     config->set_property("Resampler.sample_freq_in", std::to_string(fs_in));
     config->set_property("Resampler.sample_freq_out", std::to_string(fs_out));
 
-    std::shared_ptr<MmseResamplerConditioner> resampler = std::make_shared<MmseResamplerConditioner>(config.get(), "Resampler", 1, 1);
+    auto resampler = std::make_shared<MmseResamplerConditioner>(config.get(), "Resampler", 1, 1);
 
-    gr::blocks::null_sink::sptr sink = gr::blocks::null_sink::make(sizeof(gr_complex));
+    auto sink = gr::blocks::null_sink::make(sizeof(gr_complex));
 
     EXPECT_NO_THROW({
         resampler->connect(top_block);
@@ -68,7 +65,7 @@ TEST(MmseResamplerTest, InstantiationAndRunTestWarning)
         top_block->stop();
     }) << "Failure running direct_resampler_conditioner.";
 
-    std::cout << "Resampled " << nsamples << " samples in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Resampled " << nsamples << " samples in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
 
 
@@ -79,10 +76,10 @@ TEST(MmseResamplerTest, InstantiationAndRunTest2)
     std::chrono::time_point<std::chrono::system_clock> start, end;
     std::chrono::duration<double> elapsed_seconds(0);
     int nsamples = 1000000;  // Number of samples to be computed
-    std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
-    gr::top_block_sptr top_block = gr::make_top_block("mmse_resampler_conditioner_cc_test");
-    boost::shared_ptr<gr::analog::sig_source_c> source = gr::analog::sig_source_c::make(fs_in, gr::analog::GR_SIN_WAVE, 1000.0, 1.0, gr_complex(0.0));
-    boost::shared_ptr<gr::block> valve = gnss_sdr_make_valve(sizeof(gr_complex), nsamples, queue);
+    auto queue = std::make_shared<Concurrent_Queue<pmt::pmt_t>>();
+    auto top_block = gr::make_top_block("mmse_resampler_conditioner_cc_test");
+    auto source = gr::analog::sig_source_c::make(fs_in, gr::analog::GR_SIN_WAVE, 1000.0, 1.0, gr_complex(0.0));
+    auto valve = gnss_sdr_make_valve(sizeof(gr_complex), nsamples, queue.get());
 
     std::shared_ptr<InMemoryConfiguration> config;
     config = std::make_shared<InMemoryConfiguration>();
@@ -90,9 +87,9 @@ TEST(MmseResamplerTest, InstantiationAndRunTest2)
     config->set_property("Resampler.sample_freq_in", std::to_string(fs_in));
     config->set_property("GNSS-SDR.internal_fs_sps", std::to_string(fs_out));
 
-    std::shared_ptr<MmseResamplerConditioner> resampler = std::make_shared<MmseResamplerConditioner>(config.get(), "Resampler", 1, 1);
+    auto resampler = std::make_shared<MmseResamplerConditioner>(config.get(), "Resampler", 1, 1);
 
-    gr::blocks::null_sink::sptr sink = gr::blocks::null_sink::make(sizeof(gr_complex));
+    auto sink = gr::blocks::null_sink::make(sizeof(gr_complex));
 
     EXPECT_NO_THROW({
         resampler->connect(top_block);
@@ -109,5 +106,5 @@ TEST(MmseResamplerTest, InstantiationAndRunTest2)
         top_block->stop();
     }) << "Failure running direct_resampler_conditioner.";
 
-    std::cout << "Resampled " << nsamples << " samples in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Resampled " << nsamples << " samples in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
