@@ -4,38 +4,24 @@
  * \author Carles Fernandez-Prades, 2016. cfernandez(at)cttc.es
  *
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "GPS_L1_CA.h"
 #include "cpu_multicorrelator.h"
-#include "gps_sdr_signal_processing.h"
+#include "gps_sdr_signal_replica.h"
 #include <gflags/gflags.h>
 #include <gnuradio/gr_complex.h>
 #include <gtest/gtest.h>
-#include <volk_gnsssdr/volk_gnsssdr.h>
+#include <volk_gnsssdr/volk_gnsssdr_alloc.h>
 #include <chrono>
 #include <complex>
 #include <random>
@@ -45,7 +31,7 @@
 DEFINE_int32(cpu_multicorrelator_iterations_test, 100, "Number of averaged iterations in CPU multicorrelator test timing test");
 DEFINE_int32(cpu_multicorrelator_max_threads_test, 12, "Number of maximum concurrent correlators in CPU multicorrelator test timing test");
 
-void run_correlator_cpu(cpu_multicorrelator* correlator,
+void run_correlator_cpu(Cpu_Multicorrelator* correlator,
     float d_rem_carrier_phase_rad,
     float d_carrier_phase_step_rad,
     float d_code_phase_step_chips,
@@ -69,7 +55,7 @@ TEST(CpuMulticorrelatorTest, MeasureExecutionTime)
     std::chrono::duration<double> elapsed_seconds(0);
     int max_threads = FLAGS_cpu_multicorrelator_max_threads_test;
     std::vector<std::thread> thread_pool;
-    cpu_multicorrelator* correlator_pool[max_threads];
+    std::vector<Cpu_Multicorrelator*> correlator_pool(max_threads);
     unsigned int correlation_sizes[3] = {2048, 4096, 8192};
     double execution_times[3];
 
@@ -78,10 +64,10 @@ TEST(CpuMulticorrelatorTest, MeasureExecutionTime)
     gr_complex* d_correlator_outs;
 
     int d_n_correlator_taps = 3;
-    int d_vector_length = correlation_sizes[2];  //max correlation size to allocate all the necessary memory
+    int d_vector_length = correlation_sizes[2];  // max correlation size to allocate all the necessary memory
     float* d_local_code_shift_chips;
 
-    //allocate host memory
+    // allocate host memory
     // Get space for a vector with the C/A code replica sampled 1x/chip
     d_ca_code = static_cast<gr_complex*>(volk_gnsssdr_malloc(static_cast<int>(GPS_L1_CA_CODE_LENGTH_CHIPS) * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
     in_cpu = static_cast<gr_complex*>(volk_gnsssdr_malloc(2 * d_vector_length * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
@@ -100,11 +86,11 @@ TEST(CpuMulticorrelatorTest, MeasureExecutionTime)
     d_local_code_shift_chips[1] = 0.0;
     d_local_code_shift_chips[2] = d_early_late_spc_chips;
 
-    //--- Perform initializations ------------------------------
+    // -- Perform initializations ------------------------------
 
-    //local code resampler on GPU
+    // local code resampler on GPU
     // generate local reference (1 sample per chip)
-    gps_l1_ca_code_gen_complex(d_ca_code, 1, 0);
+    gps_l1_ca_code_gen_complex(own::span<gr_complex>(d_ca_code, static_cast<int>(GPS_L1_CA_CODE_LENGTH_CHIPS) * sizeof(gr_complex)), 1, 0);
     // generate inut signal
     std::random_device r;
     std::default_random_engine e1(r());
@@ -116,7 +102,7 @@ TEST(CpuMulticorrelatorTest, MeasureExecutionTime)
 
     for (int n = 0; n < max_threads; n++)
         {
-            correlator_pool[n] = new cpu_multicorrelator();
+            correlator_pool[n] = new Cpu_Multicorrelator();
             correlator_pool[n]->init(d_vector_length, d_n_correlator_taps);
             correlator_pool[n]->set_input_output_vectors(d_correlator_outs, in_cpu);
             correlator_pool[n]->set_local_code_and_taps(static_cast<int>(GPS_L1_CA_CODE_LENGTH_CHIPS), d_ca_code, d_local_code_shift_chips);
@@ -131,9 +117,9 @@ TEST(CpuMulticorrelatorTest, MeasureExecutionTime)
         for (int correlation_sizes_idx = 0; correlation_sizes_idx < 3; correlation_sizes_idx++) {
             for (int current_max_threads = 1; current_max_threads < (max_threads + 1); current_max_threads++)
                 {
-                    std::cout << "Running " << current_max_threads << " concurrent correlators" << std::endl;
+                    std::cout << "Running " << current_max_threads << " concurrent correlators\n";
                     start = std::chrono::system_clock::now();
-                    //create the concurrent correlator threads
+                    // create the concurrent correlator threads
                     for (int current_thread = 0; current_thread < current_max_threads; current_thread++)
                         {
                             thread_pool.push_back(std::thread(run_correlator_cpu,
@@ -144,7 +130,7 @@ TEST(CpuMulticorrelatorTest, MeasureExecutionTime)
                                 d_rem_code_phase_chips,
                                 correlation_sizes[correlation_sizes_idx]));
                         }
-                    //wait the threads to finish they work and destroy the thread objects
+                    // wait the threads to finish they work and destroy the thread objects
                     for (auto& t : thread_pool)
                         {
                             t.join();
@@ -154,7 +140,7 @@ TEST(CpuMulticorrelatorTest, MeasureExecutionTime)
                     elapsed_seconds = end - start;
                     execution_times[correlation_sizes_idx] = elapsed_seconds.count() / static_cast<double>(FLAGS_cpu_multicorrelator_iterations_test);
                     std::cout << "CPU Multicorrelator execution time for length=" << correlation_sizes[correlation_sizes_idx]
-                              << " : " << execution_times[correlation_sizes_idx] << " [s]" << std::endl;
+                              << " : " << execution_times[correlation_sizes_idx] << " [s]\n";
                 }
         });
 
@@ -168,3 +154,96 @@ TEST(CpuMulticorrelatorTest, MeasureExecutionTime)
             correlator_pool[n]->free();
         }
 }
+
+
+TEST(CpuMulticorrelatorTest, MeasureExecutionTimeAlloc)
+{
+    std::chrono::time_point<std::chrono::system_clock> start, end;
+    std::chrono::duration<double> elapsed_seconds(0);
+    int max_threads = FLAGS_cpu_multicorrelator_max_threads_test;
+    std::vector<std::thread> thread_pool;
+    std::vector<Cpu_Multicorrelator*> correlator_pool(max_threads);
+    unsigned int correlation_sizes[3] = {2048, 4096, 8192};
+    double execution_times[3];
+
+    int d_n_correlator_taps = 3;
+    int d_vector_length = correlation_sizes[2];  // max correlation size to allocate all the necessary memory
+
+    // allocate host memory
+    // Get space for a vector with the C/A code replica sampled 1x/chip
+    volk_gnsssdr::vector<gr_complex> d_ca_code(static_cast<int>(GPS_L1_CA_CODE_LENGTH_CHIPS));
+    volk_gnsssdr::vector<gr_complex> in_cpu(2 * d_vector_length);
+
+    // correlator outputs (scalar)
+    d_n_correlator_taps = 3;  // Early, Prompt, and Late
+    volk_gnsssdr::vector<gr_complex> d_correlator_outs(d_n_correlator_taps, gr_complex(0.0, 0.0));
+    volk_gnsssdr::vector<float> d_local_code_shift_chips(d_n_correlator_taps);
+    // Set TAPs delay values [chips]
+    float d_early_late_spc_chips = 0.5;
+    d_local_code_shift_chips[0] = -d_early_late_spc_chips;
+    d_local_code_shift_chips[1] = 0.0;
+    d_local_code_shift_chips[2] = d_early_late_spc_chips;
+
+    // -- Perform initializations ------------------------------
+
+    // local code resampler on GPU
+    // generate local reference (1 sample per chip)
+    gps_l1_ca_code_gen_complex(d_ca_code, 1, 0);
+    // generate inut signal
+    std::random_device r;
+    std::default_random_engine e1(r());
+    std::uniform_real_distribution<float> uniform_dist(0, 1);
+    for (int n = 0; n < 2 * d_vector_length; n++)
+        {
+            in_cpu[n] = std::complex<float>(uniform_dist(e1), uniform_dist(e1));
+        }
+
+    for (int n = 0; n < max_threads; n++)
+        {
+            correlator_pool[n] = new Cpu_Multicorrelator();
+            correlator_pool[n]->init(d_vector_length, d_n_correlator_taps);
+            correlator_pool[n]->set_input_output_vectors(d_correlator_outs.data(), in_cpu.data());
+            correlator_pool[n]->set_local_code_and_taps(static_cast<int>(GPS_L1_CA_CODE_LENGTH_CHIPS), d_ca_code.data(), d_local_code_shift_chips.data());
+        }
+
+    float d_rem_carrier_phase_rad = 0.0;
+    float d_carrier_phase_step_rad = 0.1;
+    float d_code_phase_step_chips = 0.3;
+    float d_rem_code_phase_chips = 0.4;
+
+    EXPECT_NO_THROW(
+        for (int correlation_sizes_idx = 0; correlation_sizes_idx < 3; correlation_sizes_idx++) {
+            for (int current_max_threads = 1; current_max_threads < (max_threads + 1); current_max_threads++)
+                {
+                    std::cout << "Running " << current_max_threads << " concurrent correlators\n";
+                    start = std::chrono::system_clock::now();
+                    // create the concurrent correlator threads
+                    for (int current_thread = 0; current_thread < current_max_threads; current_thread++)
+                        {
+                            thread_pool.push_back(std::thread(run_correlator_cpu,
+                                correlator_pool[current_thread],
+                                d_rem_carrier_phase_rad,
+                                d_carrier_phase_step_rad,
+                                d_code_phase_step_chips,
+                                d_rem_code_phase_chips,
+                                correlation_sizes[correlation_sizes_idx]));
+                        }
+                    // wait the threads to finish they work and destroy the thread objects
+                    for (auto& t : thread_pool)
+                        {
+                            t.join();
+                        }
+                    thread_pool.clear();
+                    end = std::chrono::system_clock::now();
+                    elapsed_seconds = end - start;
+                    execution_times[correlation_sizes_idx] = elapsed_seconds.count() / static_cast<double>(FLAGS_cpu_multicorrelator_iterations_test);
+                    std::cout << "CPU Multicorrelator execution time for length=" << correlation_sizes[correlation_sizes_idx]
+                              << " : " << execution_times[correlation_sizes_idx] << " [s]\n";
+                }
+        });
+
+    for (int n = 0; n < max_threads; n++)
+        {
+            correlator_pool[n]->free();
+        }
+}
