@@ -6,33 +6,18 @@
  * \author Javier Arribas, 2017. jarribas(at)cttc.es
  *
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2012-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2012-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #include "GPS_L1_CA.h"
-#include "gnss_block_factory.h"
 #include "gnss_block_interface.h"
 #include "gnss_synchro.h"
 #include "gps_l1_ca_dll_pll_tracking_fpga.h"
@@ -59,6 +44,10 @@
 #include <iostream>
 #include <unistd.h>
 #include <utility>
+#if HAS_GENERIC_LAMBDA
+#else
+#include <boost/bind/bind.hpp>
+#endif
 #ifdef GR_GREATER_38
 #include <gnuradio/analog/sig_source.h>
 #else
@@ -70,7 +59,7 @@
 #define FIVE_SECONDS 5000000          // five seconds in microseconds
 
 void send_tracking_gps_input_samples(FILE *rx_signal_file,
-    int num_remaining_samples, const gr::top_block_sptr& top_block)
+    int num_remaining_samples, const gr::top_block_sptr &top_block)
 {
     int num_samples_transferred = 0;   // number of samples that have been transferred to the DMA so far
     static int flowgraph_stopped = 0;  // flag to indicate if the flowgraph is stopped already
@@ -79,14 +68,16 @@ void send_tracking_gps_input_samples(FILE *rx_signal_file,
     dma_descr = open("/dev/loop_tx", O_WRONLY);
     if (dma_descr < 0)
         {
-            printf("can't open loop device\n");
-            exit(1);
+            std::cerr << "Can't open loop device\n";
+            return;
         }
 
-    buffer_DMA = (char *)malloc(DMA_TRACK_TRANSFER_SIZE);
+    buffer_DMA = reinterpret_cast<char *>(malloc(DMA_TRACK_TRANSFER_SIZE));
     if (!buffer_DMA)
         {
-            fprintf(stderr, "Memory error!");
+            std::cerr << "Memory error!\n";
+            close(dma_descr);
+            return;
         }
 
     while (num_remaining_samples > 0)
@@ -102,7 +93,11 @@ void send_tracking_gps_input_samples(FILE *rx_signal_file,
                 }
             if (num_remaining_samples > DMA_TRACK_TRANSFER_SIZE)
                 {
-                    fread(buffer_DMA, DMA_TRACK_TRANSFER_SIZE, 1, rx_signal_file);
+                    size_t result = fread(buffer_DMA, DMA_TRACK_TRANSFER_SIZE, 1, rx_signal_file);
+                    if (result != DMA_TRACK_TRANSFER_SIZE)
+                        {
+                            std::cerr << "Error reading from DMA\n";
+                        }
 
                     assert(DMA_TRACK_TRANSFER_SIZE == write(dma_descr, &buffer_DMA[0], DMA_TRACK_TRANSFER_SIZE));
                     num_remaining_samples = num_remaining_samples - DMA_TRACK_TRANSFER_SIZE;
@@ -110,8 +105,11 @@ void send_tracking_gps_input_samples(FILE *rx_signal_file,
                 }
             else
                 {
-                    fread(buffer_DMA, num_remaining_samples, 1, rx_signal_file);
-
+                    size_t result = fread(buffer_DMA, num_remaining_samples, 1, rx_signal_file);
+                    if (static_cast<int>(result) != num_remaining_samples)
+                        {
+                            std::cerr << "Error reading from DMA\n";
+                        }
                     assert(num_remaining_samples == write(dma_descr, &buffer_DMA[0], num_remaining_samples));
                     num_samples_transferred = num_samples_transferred + num_remaining_samples;
                     num_remaining_samples = 0;
@@ -124,7 +122,7 @@ void send_tracking_gps_input_samples(FILE *rx_signal_file,
 
 
 // thread that sends the samples to the FPGA
-void sending_thread(gr::top_block_sptr top_block, const char *file_name)
+void sending_thread(const gr::top_block_sptr &top_block, const char *file_name)
 {
     // file descriptor
     FILE *rx_signal_file;  // file descriptor
@@ -133,7 +131,8 @@ void sending_thread(gr::top_block_sptr top_block, const char *file_name)
     rx_signal_file = fopen(file_name, "rb");
     if (!rx_signal_file)
         {
-            printf("Unable to open file!");
+            std::cerr << "Unable to open file!\n";
+            return;
         }
 
     fseek(rx_signal_file, 0, SEEK_END);
@@ -142,8 +141,8 @@ void sending_thread(gr::top_block_sptr top_block, const char *file_name)
 
     usleep(FIVE_SECONDS);  // wait for some time to give time to the other thread to program the device
 
-    //send_tracking_gps_input_samples(dma_descr, rx_signal_file, file_length);
-    send_tracking_gps_input_samples(rx_signal_file, file_length, std::move(top_block));
+    // send_tracking_gps_input_samples(dma_descr, rx_signal_file, file_length);
+    send_tracking_gps_input_samples(rx_signal_file, file_length, top_block);
 
     fclose(rx_signal_file);
 }
@@ -152,7 +151,7 @@ void sending_thread(gr::top_block_sptr top_block, const char *file_name)
 // ######## GNURADIO BLOCK MESSAGE RECEVER #########
 class GpsL1CADllPllTrackingTestFpga_msg_rx;
 
-using GpsL1CADllPllTrackingTestFpga_msg_rx_sptr = boost::shared_ptr<GpsL1CADllPllTrackingTestFpga_msg_rx>;
+using GpsL1CADllPllTrackingTestFpga_msg_rx_sptr = gnss_shared_ptr<GpsL1CADllPllTrackingTestFpga_msg_rx>;
 
 GpsL1CADllPllTrackingTestFpga_msg_rx_sptr GpsL1CADllPllTrackingTestFpga_msg_rx_make();
 
@@ -161,12 +160,12 @@ class GpsL1CADllPllTrackingTestFpga_msg_rx : public gr::block
 {
 private:
     friend GpsL1CADllPllTrackingTestFpga_msg_rx_sptr GpsL1CADllPllTrackingTestFpga_msg_rx_make();
-    void msg_handler_events(pmt::pmt_t msg);
+    void msg_handler_channel_events(const pmt::pmt_t &msg);
     GpsL1CADllPllTrackingTestFpga_msg_rx();
 
 public:
     int rx_message;
-    ~GpsL1CADllPllTrackingTestFpga_msg_rx();  //!< Default destructor
+    ~GpsL1CADllPllTrackingTestFpga_msg_rx() override;  //!< Default destructor
 };
 
 
@@ -177,16 +176,16 @@ GpsL1CADllPllTrackingTestFpga_msg_rx_sptr GpsL1CADllPllTrackingTestFpga_msg_rx_m
 }
 
 
-void GpsL1CADllPllTrackingTestFpga_msg_rx::msg_handler_events(pmt::pmt_t msg)
+void GpsL1CADllPllTrackingTestFpga_msg_rx::msg_handler_channel_events(const pmt::pmt_t &msg)
 {
     try
         {
-            int64_t message = pmt::to_long(std::move(msg));
+            int64_t message = pmt::to_long(msg);
             rx_message = message;
         }
-    catch (boost::bad_any_cast &e)
+    catch (const boost::bad_any_cast &e)
         {
-            LOG(WARNING) << "msg_handler_telemetry Bad any cast!";
+            LOG(WARNING) << "msg_handler_channel_events Bad any_cast: " << e.what();
             rx_message = 0;
         }
 }
@@ -198,9 +197,15 @@ GpsL1CADllPllTrackingTestFpga_msg_rx::GpsL1CADllPllTrackingTestFpga_msg_rx() : g
 {
     this->message_port_register_in(pmt::mp("events"));
     this->set_msg_handler(pmt::mp("events"),
-        boost::bind(
-            &GpsL1CADllPllTrackingTestFpga_msg_rx::msg_handler_events,
-            this, _1));
+#if HAS_GENERIC_LAMBDA
+        [this](auto &&PH1) { msg_handler_channel_events(PH1); });
+#else
+#if USE_BOOST_BIND_PLACEHOLDERS
+        boost::bind(&GpsL1CADllPllTrackingTestFpga_msg_rx::msg_handler_channel_events, this, boost::placeholders::_1));
+#else
+        boost::bind(&GpsL1CADllPllTrackingTestFpga_msg_rx::msg_handler_channel_events, this, _1));
+#endif
+#endif
     rx_message = 0;
 }
 
@@ -236,18 +241,16 @@ public:
 
     GpsL1CADllPllTrackingTestFpga()
     {
-        factory = std::make_shared<GNSSBlockFactory>();
         config = std::make_shared<InMemoryConfiguration>();
         item_size = sizeof(gr_complex);
         gnss_synchro = Gnss_Synchro();
     }
 
-    ~GpsL1CADllPllTrackingTestFpga() = default;
+    ~GpsL1CADllPllTrackingTestFpga() override = default;
 
     void configure_receiver();
 
     gr::top_block_sptr top_block;
-    std::shared_ptr<GNSSBlockFactory> factory;
     std::shared_ptr<InMemoryConfiguration> config;
     Gnss_Synchro gnss_synchro;
     size_t item_size;
@@ -270,7 +273,7 @@ int GpsL1CADllPllTrackingTestFpga::configure_generator()
         }
     p3 = std::string("-rinex_obs_file=") + FLAGS_filename_rinex_obs;               // RINEX 2.10 observation file output
     p4 = std::string("-sig_out_file=") + FLAGS_filename_raw_data;                  // Baseband signal output file. Will be stored in int8_t IQ multiplexed samples
-    p5 = std::string("-sampling_freq=") + std::to_string(baseband_sampling_freq);  //Baseband sampling frequency [MSps]
+    p5 = std::string("-sampling_freq=") + std::to_string(baseband_sampling_freq);  // Baseband sampling frequency [MSps]
     return 0;
 }
 
@@ -284,17 +287,19 @@ int GpsL1CADllPllTrackingTestFpga::generate_signal()
 
     int pid;
     if ((pid = fork()) == -1)
-        perror("fork err");
+        {
+            perror("fork err");
+        }
     else if (pid == 0)
         {
             execv(&generator_binary[0], parmList);
-            std::cout << "Return not expected. Must be an execv err." << std::endl;
+            std::cout << "Return not expected. Must be an execv err.\n";
             std::terminate();
         }
 
     waitpid(pid, &child_status, 0);
 
-    std::cout << "Signal and Observables RINEX and RAW files created." << std::endl;
+    std::cout << "Signal and Observables RINEX and RAW files created.\n";
     return 0;
 }
 
@@ -310,8 +315,6 @@ void GpsL1CADllPllTrackingTestFpga::configure_receiver()
     config->set_property("GNSS-SDR.internal_fs_sps",
         std::to_string(baseband_sampling_freq));
     // Set Tracking
-    //config->set_property("Tracking_1C.implementation",
-    //        "GPS_L1_CA_DLL_PLL_C_Aid_Tracking_Fpga");
     config->set_property("Tracking_1C.implementation",
         "GPS_L1_CA_DLL_PLL_Tracking_Fpga");
     config->set_property("Tracking_1C.item_type", "cshort");
@@ -328,7 +331,7 @@ void GpsL1CADllPllTrackingTestFpga::configure_receiver()
 void GpsL1CADllPllTrackingTestFpga::check_results_doppler(arma::vec &true_time_s,
     arma::vec &true_value, arma::vec &meas_time_s, arma::vec &meas_value)
 {
-    //1. True value interpolation to match the measurement times
+    // 1. True value interpolation to match the measurement times
     arma::vec true_value_interp;
     arma::uvec true_time_s_valid = find(true_time_s > 0);
     true_time_s = true_time_s(true_time_s_valid);
@@ -338,27 +341,26 @@ void GpsL1CADllPllTrackingTestFpga::check_results_doppler(arma::vec &true_time_s
     meas_value = meas_value(meas_time_s_valid);
     arma::interp1(true_time_s, true_value, meas_time_s, true_value_interp);
 
-    //2. RMSE
+    // 2. RMSE
     arma::vec err;
-
     err = meas_value - true_value_interp;
     arma::vec err2 = arma::square(err);
     double rmse = sqrt(arma::mean(err2));
 
-    //3. Mean err and variance
+    // 3. Mean err and variance
     double error_mean = arma::mean(err);
     double error_var = arma::var(err);
 
-    // 5. Peaks
+    // 4. Peaks
     double max_error = arma::max(err);
     double min_error = arma::min(err);
 
-    //5. report
+    // 5. report
     std::streamsize ss = std::cout.precision();
     std::cout << std::setprecision(10) << "TRK Doppler RMSE=" << rmse
               << ", mean=" << error_mean << ", stdev=" << sqrt(error_var)
               << " (max,min)=" << max_error << "," << min_error << " [Hz]"
-              << std::endl;
+              << '\n';
     std::cout.precision(ss);
 }
 
@@ -367,7 +369,7 @@ void GpsL1CADllPllTrackingTestFpga::check_results_acc_carrier_phase(
     arma::vec &true_time_s, arma::vec &true_value, arma::vec &meas_time_s,
     arma::vec &meas_value)
 {
-    //1. True value interpolation to match the measurement times
+    // 1. True value interpolation to match the measurement times
     arma::vec true_value_interp;
     arma::uvec true_time_s_valid = find(true_time_s > 0);
     true_time_s = true_time_s(true_time_s_valid);
@@ -377,14 +379,14 @@ void GpsL1CADllPllTrackingTestFpga::check_results_acc_carrier_phase(
     meas_value = meas_value(meas_time_s_valid);
     arma::interp1(true_time_s, true_value, meas_time_s, true_value_interp);
 
-    //2. RMSE
+    // 2. RMSE
     arma::vec err;
 
     err = meas_value - true_value_interp;
     arma::vec err2 = arma::square(err);
     double rmse = sqrt(arma::mean(err2));
 
-    //3. Mean err and variance
+    // 3. Mean err and variance
     double error_mean = arma::mean(err);
     double error_var = arma::var(err);
 
@@ -392,12 +394,12 @@ void GpsL1CADllPllTrackingTestFpga::check_results_acc_carrier_phase(
     double max_error = arma::max(err);
     double min_error = arma::min(err);
 
-    //5. report
+    // 5. report
     std::streamsize ss = std::cout.precision();
     std::cout << std::setprecision(10) << "TRK acc carrier phase RMSE=" << rmse
               << ", mean=" << error_mean << ", stdev=" << sqrt(error_var)
               << " (max,min)=" << max_error << "," << min_error << " [Hz]"
-              << std::endl;
+              << '\n';
     std::cout.precision(ss);
 }
 
@@ -406,7 +408,7 @@ void GpsL1CADllPllTrackingTestFpga::check_results_codephase(
     arma::vec &true_time_s, arma::vec &true_value, arma::vec &meas_time_s,
     arma::vec &meas_value)
 {
-    //1. True value interpolation to match the measurement times
+    // 1. True value interpolation to match the measurement times
     arma::vec true_value_interp;
     arma::uvec true_time_s_valid = find(true_time_s > 0);
     true_time_s = true_time_s(true_time_s_valid);
@@ -416,13 +418,13 @@ void GpsL1CADllPllTrackingTestFpga::check_results_codephase(
     meas_value = meas_value(meas_time_s_valid);
     arma::interp1(true_time_s, true_value, meas_time_s, true_value_interp);
 
-    //2. RMSE
+    // 2. RMSE
     arma::vec err;
     err = meas_value - true_value_interp;
     arma::vec err2 = arma::square(err);
     double rmse = sqrt(arma::mean(err2));
 
-    //3. Mean err and variance
+    // 3. Mean err and variance
     double error_mean = arma::mean(err);
     double error_var = arma::var(err);
 
@@ -430,12 +432,12 @@ void GpsL1CADllPllTrackingTestFpga::check_results_codephase(
     double max_error = arma::max(err);
     double min_error = arma::min(err);
 
-    //5. report
+    // 5. report
     std::streamsize ss = std::cout.precision();
     std::cout << std::setprecision(10) << "TRK code phase RMSE=" << rmse
               << ", mean=" << error_mean << ", stdev=" << sqrt(error_var)
               << " (max,min)=" << max_error << "," << min_error << " [Chips]"
-              << std::endl;
+              << '\n';
     std::cout.precision(ss);
 }
 
@@ -445,17 +447,18 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
     configure_generator();
 
     // DO not generate signal raw signal samples and observations RINEX file by default
-    //generate_signal();
+    // generate_signal();
 
-    std::chrono::time_point<std::chrono::system_clock> start, end;
+    std::chrono::time_point<std::chrono::system_clock> start;
+    std::chrono::time_point<std::chrono::system_clock> end;
     std::chrono::duration<double> elapsed_seconds(0);
 
     configure_receiver();
 
-    //open true observables log file written by the simulator
-    tracking_true_obs_reader true_obs_data;
+    // open true observables log file written by the simulator
+    Tracking_True_Obs_Reader true_obs_data;
     int test_satellite_PRN = FLAGS_test_satellite_PRN;
-    std::cout << "Testing satellite PRN=" << test_satellite_PRN << std::endl;
+    std::cout << "Testing satellite PRN=" << test_satellite_PRN << '\n';
     std::string true_obs_file = std::string("./gps_l1_ca_obs_prn");
     true_obs_file.append(std::to_string(test_satellite_PRN));
     true_obs_file.append(".dat");
@@ -469,10 +472,10 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
         << "Failure opening true observables file";
 
     top_block = gr::make_top_block("Tracking test");
-    //std::shared_ptr<GpsL1CaDllPllCAidTrackingFpga> tracking = std::make_shared<GpsL1CaDllPllCAidTrackingFpga> (config.get(), "Tracking_1C", 1, 1);
+    // std::shared_ptr<GpsL1CaDllPllCAidTrackingFpga> tracking = std::make_shared<GpsL1CaDllPllCAidTrackingFpga> (config.get(), "Tracking_1C", 1, 1);
     std::shared_ptr<GpsL1CaDllPllTrackingFpga> tracking = std::make_shared<GpsL1CaDllPllTrackingFpga>(config.get(), "Tracking_1C", 1, 1);
 
-    boost::shared_ptr<GpsL1CADllPllTrackingTestFpga_msg_rx> msg_rx = GpsL1CADllPllTrackingTestFpga_msg_rx_make();
+    auto msg_rx = GpsL1CADllPllTrackingTestFpga_msg_rx_make();
 
     // load acquisition data based on the first epoch of the true observations
     ASSERT_NO_THROW(
@@ -484,14 +487,14 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
         })
         << "Failure reading true observables file";
 
-    //restart the epoch counter
+    // restart the epoch counter
     true_obs_data.restart();
 
     std::cout << "Initial Doppler [Hz]=" << true_obs_data.doppler_l1_hz
               << " Initial code delay [Chips]=" << true_obs_data.prn_delay_chips
-              << std::endl;
+              << '\n';
 
-    gnss_synchro.Acq_delay_samples = (GPS_L1_CA_CODE_LENGTH_CHIPS - true_obs_data.prn_delay_chips / GPS_L1_CA_CODE_LENGTH_CHIPS) * baseband_sampling_freq * GPS_L1_CA_CODE_PERIOD;
+    gnss_synchro.Acq_delay_samples = (GPS_L1_CA_CODE_LENGTH_CHIPS - true_obs_data.prn_delay_chips / GPS_L1_CA_CODE_LENGTH_CHIPS) * baseband_sampling_freq * GPS_L1_CA_CODE_PERIOD_S;
     gnss_synchro.Acq_doppler_hz = true_obs_data.doppler_l1_hz;
     gnss_synchro.Acq_samplestamp_samples = 0;
 
@@ -534,7 +537,7 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
         {
             start = std::chrono::system_clock::now();
             top_block->run();  // Start threads and wait
-            //tracking->reset();// unlock the channel
+            // tracking->reset();  // unlock the channel
             end = std::chrono::system_clock::now();
             elapsed_seconds = end - start;
         })
@@ -543,10 +546,10 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
     // wait until child thread terminates
     t.join();
 
-    //check results
-    //load the true values
+    // check results
+    // load the true values
     int64_t nepoch = true_obs_data.num_epochs();
-    std::cout << "True observation epochs=" << nepoch << std::endl;
+    std::cout << "True observation epochs=" << nepoch << '\n';
 
     arma::vec true_timestamp_s = arma::zeros(nepoch, 1);
     arma::vec true_acc_carrier_phase_cycles = arma::zeros(nepoch, 1);
@@ -565,8 +568,8 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
             epoch_counter++;
         }
 
-    //load the measured values
-    tracking_dump_reader trk_dump;
+    // load the measured values
+    Tracking_Dump_Reader trk_dump;
     ASSERT_NO_THROW(
         {
             if (trk_dump.open_obs_file(std::string("./tracking_ch_0.dat")) == false)
@@ -577,7 +580,7 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
         << "Failure opening tracking dump file";
 
     nepoch = trk_dump.num_epochs();
-    std::cout << "Measured observation epochs=" << nepoch << std::endl;
+    std::cout << "Measured observation epochs=" << nepoch << '\n';
 
     arma::vec trk_timestamp_s = arma::zeros(nepoch, 1);
     arma::vec trk_acc_carrier_phase_cycles = arma::zeros(nepoch, 1);
@@ -588,7 +591,7 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
     while (trk_dump.read_binary_obs())
         {
             trk_timestamp_s(epoch_counter) = static_cast<double>(trk_dump.PRN_start_sample_count) / static_cast<double>(baseband_sampling_freq);
-            trk_acc_carrier_phase_cycles(epoch_counter) = trk_dump.acc_carrier_phase_rad / GPS_TWO_PI;
+            trk_acc_carrier_phase_cycles(epoch_counter) = trk_dump.acc_carrier_phase_rad / TWO_PI;
             trk_Doppler_Hz(epoch_counter) = trk_dump.carrier_doppler_hz;
 
             double delay_chips = GPS_L1_CA_CODE_LENGTH_CHIPS - GPS_L1_CA_CODE_LENGTH_CHIPS * (fmod((static_cast<double>(trk_dump.PRN_start_sample_count) + trk_dump.aux1) / static_cast<double>(baseband_sampling_freq), 1.0e-3) / 1.0e-3);
@@ -597,7 +600,7 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
             epoch_counter++;
         }
 
-    //Align initial measurements and cut the tracking pull-in transitory
+    // Align initial measurements and cut the tracking pull-in transitory
     double pull_in_offset_s = 1.0;
     arma::uvec initial_meas_point = arma::find(trk_timestamp_s >= (true_timestamp_s(0) + pull_in_offset_s), 1, "first");
 
@@ -612,5 +615,5 @@ TEST_F(GpsL1CADllPllTrackingTestFpga, ValidationOfResultsFpga)
         true_acc_carrier_phase_cycles, trk_timestamp_s,
         trk_acc_carrier_phase_cycles);
 
-    std::cout << "Signal tracking completed in " << elapsed_seconds.count() * 1e6 << " microseconds" << std::endl;
+    std::cout << "Signal tracking completed in " << elapsed_seconds.count() * 1e6 << " microseconds\n";
 }
